/****************************************************************************************/
/*                                                                                      */
/* IBM Confidential                                                                     */
/*                                                                                      */
/* Net.Commerce Source Materials                                                        */
/*                                                                                      */
/* (C) Copyright IBM Corp. 1996, 1997.                                                  */
/*                                                                                      */
/* The source code for this program is not published or otherwise divested of its trade */
/* secrets, irrespective of what has been deposited with the U.S. Copyright Office.     */
/*                                                                                      */
/****************************************************************************************/

#ifndef _ACCESS_CMDS_H_
#define _ACCESS_CMDS_H_


class __DLL_NCS_CMD__ CommandAccessBase : public NC_Command
{

public:
   CommandAccessBase() : _signal_func("") { }

   void operator delete( void* p ) { ::delete p; }

protected:
   void setSignalFunction(HttpResponse& Res, int rc)
   {
      String signal_function ;
      signal_function << "<SCRIPT LANGUAGE=\"JavaScript\">"
                      << _signal_func << "(\"" << rc << "\");"
                      << "</SCRIPT >" << endl;
      debug << indent << "Signal Function: " << signal_function << endl;
      Res.setDocument(signal_function);
   }
   
public:
   String _signal_func;
};


//////////////////////////////////////////////////////////////////////////////////////////
//
//  Command AccessModeAdd
//

class __DLL_NCS_CMD__ CommandAccessModeAdd : public CommandAccessBase
{

public:
   CommandAccessModeAdd() : _merchant_rn(""), _cmd_rn(""), _ssl(""), _protect("") { }
   ~CommandAccessModeAdd() { }

   void operator delete( void* p ) { ::delete p; }

public:
   virtual bool CheckParameters( const HttpRequest& Req, 
                                 HttpResponse& Res,
                                 NC_Environment& Env, 
                                 NC_Environment& Resources );
   virtual bool Process( const HttpRequest& Req,
                         HttpResponse& Res, 
                         NC_Environment& Env );

private:
   String _merchant_rn;
   String _cmd_rn;
   String _ssl;
   String _protect;
};


//////////////////////////////////////////////////////////////////////////////////////////
//
//  Command AccessModeUpdate
//

class __DLL_NCS_CMD__ CommandAccessModeUpdate : public CommandAccessBase
{

public:
   CommandAccessModeUpdate() : _refnum(""), _cmd_rn(""), _ssl(""), _protect("") { }
   ~CommandAccessModeUpdate() { }

   void operator delete( void* p ) { ::delete p; }

public:
   virtual bool CheckParameters( const HttpRequest& Req, 
                                 HttpResponse& Res,
                                 NC_Environment& Env, 
                                 NC_Environment& Resources );
   virtual bool Process( const HttpRequest& Req,
                         HttpResponse& Res, 
                         NC_Environment& Env );

private:
   String _refnum;
   String _cmd_rn;
   String _ssl;
   String _protect;
};


//////////////////////////////////////////////////////////////////////////////////////////
//
//  Command AccessModeDelete
//

class __DLL_NCS_CMD__ CommandAccessModeDelete : public CommandAccessBase
{

public:
   CommandAccessModeDelete() : _refnum("") { }
   ~CommandAccessModeDelete() { }

   void operator delete( void* p ) { ::delete p; }

public:
   virtual bool CheckParameters( const HttpRequest& Req, 
                                 HttpResponse& Res,
                                 NC_Environment& Env, 
                                 NC_Environment& Resources );
   virtual bool Process( const HttpRequest& Req,
                         HttpResponse& Res, 
                         NC_Environment& Env );

private:
   String _refnum;
};


//////////////////////////////////////////////////////////////////////////////////////////
//
//  Command AccessGroupAdd
//

class __DLL_NCS_CMD__ CommandAccessGroupAdd : public CommandAccessBase
{

public:
   CommandAccessGroupAdd() : _merchant_rn(""), _name(""), _desc("") { }
   ~CommandAccessGroupAdd() { }

   void operator delete( void* p ) { ::delete p; }

public:
   virtual bool CheckParameters( const HttpRequest& Req, 
                                 HttpResponse& Res,
                                 NC_Environment& Env, 
                                 NC_Environment& Resources );
   virtual bool Process( const HttpRequest& Req,
                         HttpResponse& Res, 
                         NC_Environment& Env );

private:
   String _merchant_rn;
   String _name;
   String _desc;
};


//////////////////////////////////////////////////////////////////////////////////////////
//
//  Command AccessGroupUpdate
//

class __DLL_NCS_CMD__ CommandAccessGroupUpdate : public CommandAccessBase
{

public:
   CommandAccessGroupUpdate() : _refnum(""), _name(""), _desc("") { }
   ~CommandAccessGroupUpdate() { }

   void operator delete( void* p ) { ::delete p; }

public:
   virtual bool CheckParameters( const HttpRequest& Req, 
                                 HttpResponse& Res,
                                 NC_Environment& Env, 
                                 NC_Environment& Resources );
   virtual bool Process( const HttpRequest& Req,
                         HttpResponse& Res, 
                         NC_Environment& Env );

private:
   String _refnum;
   String _name;
   String _desc;
};


//////////////////////////////////////////////////////////////////////////////////////////
//
//  Command AccessGroupDelete
//

class __DLL_NCS_CMD__ CommandAccessGroupDelete : public CommandAccessBase
{

public:
   CommandAccessGroupDelete() : _refnum("") { }
   ~CommandAccessGroupDelete() { }

   void operator delete( void* p ) { ::delete p; }

public:
   virtual bool CheckParameters( const HttpRequest& Req, 
                                 HttpResponse& Res,
                                 NC_Environment& Env, 
                                 NC_Environment& Resources );
   virtual bool Process( const HttpRequest& Req,
                         HttpResponse& Res, 
                         NC_Environment& Env );

private:
   String _refnum;
};


//////////////////////////////////////////////////////////////////////////////////////////
//
//  Command AccessGroupAddCommand
//

class __DLL_NCS_CMD__ CommandAccessGroupAddCommand : public CommandAccessBase
{

public:
   CommandAccessGroupAddCommand() : _refnum("") { }
   ~CommandAccessGroupAddCommand() { }

   void operator delete( void* p ) { ::delete p; }

public:
   virtual bool CheckParameters( const HttpRequest& Req, 
                                 HttpResponse& Res,
                                 NC_Environment& Env, 
                                 NC_Environment& Resources );
   virtual bool Process( const HttpRequest& Req,
                         HttpResponse& Res, 
                         NC_Environment& Env );

private:
   String _refnum;
};


//////////////////////////////////////////////////////////////////////////////////////////
//
//  Command AccessGroupRemoveCommand
//

class __DLL_NCS_CMD__ CommandAccessGroupRemoveCommand : public CommandAccessBase
{

public:
   CommandAccessGroupRemoveCommand() : _refnum("") { }
   ~CommandAccessGroupRemoveCommand() { }

   void operator delete( void* p ) { ::delete p; }

public:
   virtual bool CheckParameters( const HttpRequest& Req, 
                                 HttpResponse& Res,
                                 NC_Environment& Env, 
                                 NC_Environment& Resources );
   virtual bool Process( const HttpRequest& Req,
                         HttpResponse& Res, 
                         NC_Environment& Env );

private:
   String _refnum;
};


//////////////////////////////////////////////////////////////////////////////////////////
//
//  Command AccessGroupAddUser
//

class __DLL_NCS_CMD__ CommandAccessGroupAddUser : public CommandAccessBase
{

public:
   CommandAccessGroupAddUser() : _refnum("") { }
   ~CommandAccessGroupAddUser() { }

   void operator delete( void* p ) { ::delete p; }

public:
   virtual bool CheckParameters( const HttpRequest& Req, 
                                 HttpResponse& Res,
                                 NC_Environment& Env, 
                                 NC_Environment& Resources );
   virtual bool Process( const HttpRequest& Req,
                         HttpResponse& Res, 
                         NC_Environment& Env );

private:
   String _refnum;
};


//////////////////////////////////////////////////////////////////////////////////////////
//
//  Command AccessGroupRemoveUser
//

class __DLL_NCS_CMD__ CommandAccessGroupRemoveUser : public CommandAccessBase
{

public:
   CommandAccessGroupRemoveUser() : _refnum("") { }
   ~CommandAccessGroupRemoveUser() { }

   void operator delete( void* p ) { ::delete p; }

public:
   virtual bool CheckParameters( const HttpRequest& Req, 
                                 HttpResponse& Res,
                                 NC_Environment& Env, 
                                 NC_Environment& Resources );
   virtual bool Process( const HttpRequest& Req,
                         HttpResponse& Res, 
                         NC_Environment& Env );

private:
   String _refnum;
};


//////////////////////////////////////////////////////////////////////////////////////////
//
//  Command UserAddAccessGroup
//

class __DLL_NCS_CMD__ CommandUserAddAccessGroup : public CommandAccessBase
{

public:
   CommandUserAddAccessGroup() : _refnum("") { }
   ~CommandUserAddAccessGroup() { }

   void operator delete( void* p ) { ::delete p; }

public:
   virtual bool CheckParameters( const HttpRequest& Req, 
                                 HttpResponse& Res,
                                 NC_Environment& Env, 
                                 NC_Environment& Resources );
   virtual bool Process( const HttpRequest& Req,
                         HttpResponse& Res, 
                         NC_Environment& Env );

private:
   String _refnum;
};


//////////////////////////////////////////////////////////////////////////////////////////
//
//  Command UserRemoveAccessGroup
//

class __DLL_NCS_CMD__ CommandUserRemoveAccessGroup : public CommandAccessBase
{

public:
   CommandUserRemoveAccessGroup() : _refnum("") { }
   ~CommandUserRemoveAccessGroup() { }

   void operator delete( void* p ) { ::delete p; }

public:
   virtual bool CheckParameters( const HttpRequest& Req, 
                                 HttpResponse& Res,
                                 NC_Environment& Env, 
                                 NC_Environment& Resources );
   virtual bool Process( const HttpRequest& Req,
                         HttpResponse& Res, 
                         NC_Environment& Env );

private:
   String _refnum;
};



#endif
