/****************************************************************************************/
/*                                                                                      */
/* IBM Confidential                                                                     */
/*                                                                                      */
/* Net.Commerce Source Materials                                                        */
/*                                                                                      */
/* (C) Copyright IBM Corp. 1996, 1997.                                                  */
/*                                                                                      */
/* The source code for this program is not published or otherwise divested of its trade */
/* secrets, irrespective of what has been deposited with the U.S. Copyright Office.     */
/*                                                                                      */
/****************************************************************************************/

#ifndef _RESETPWD_H_
#define _RESETPWD_H_



//////////////////////////////////////////////////////////////////////////////////////////
//
// User Command : CommandLogon.
//
//////////////////////////////////////////////////////////////////////////////////////////

class __DLL_NCS_CMD__ CommandResetPassword : public NC_Command
 {
   static ClassName _STR_ThisClass;
   #if !defined(AS400)
   const static StringWithOwnership _IS_REGISTERED_FLAG;
   #endif
     
   public:
       CommandResetPassword() : _LogId          (_STR_EMPTY_),
                                _OldPassword    (_STR_EMPTY_),
                                _NewPassword    (_STR_EMPTY_),
                                _AdminPassword  (_STR_EMPTY_),
                                _Url            (_STR_EMPTY_),
                                _ChallengeAnswer(_STR_EMPTY_),
                                _MerchantRefNum (_STR_EMPTY_)
              
       { }
    void  operator delete( void* p )     { ::delete p; }


   public:    
       virtual bool CheckParameters(const HttpRequest& Req, HttpResponse& Res,
                                    NC_Environment& Env, NC_Environment& Resources);    
       virtual bool Process        (const HttpRequest& Req, HttpResponse& Res, NC_Environment& Env);
    
   public:
       
       static bool LogIdIsValid (const String & LogId);

   private:
       bool   CheckParametersForGuest            (const HttpRequest& Req, HttpResponse  & Res, NC_Environment& Env           , const String  & MerchantRefNum );
       bool   CheckParametersForAdmin            (const HttpRequest& Req, NC_Environment& Env, const String  & MerchantRefNum, User * Administrator,  User * U, NC_Environment& Resources);
       bool   CheckParametersForRegisteredShopper(const HttpRequest& Req, NC_Environment& Env, const String  & MerchantRefNum, User * U                       );             
       bool   SendNewPwdToUser                   (const HttpRequest& Req, HttpResponse  & Res, NC_Environment& Env           , const String & NewPwd, User * U);

       String GenerateRandomAlphaNumericString   (const int          Len                             );
       bool   UserEmailExists                    (NC_Environment&    Env, User *          U  , const String  & ErrTaskName);
       bool   NewPasswordIsValid                 (const HttpRequest& Req, NC_Environment& Env, const String  & TaskName   );
     
       // String BuildPwdResetMsg                   (      Address * A     , const String& NewPwd );  

   protected:

    String   _LogId          ;   
    String   _OldPassword    ;
    String   _NewPassword    ;
    String   _AdminPassword  ;
    String   _Url            ;
    String   _ChallengeAnswer;       
    String   _MerchantRefNum ;

   private:

       static const StringWithOwnership _AlphaNumericSet;
       static const int                 _PWD_LENGTH;
    
 };


/////////////////////////////////////////////////////////////////////////////////////////////////////
//
/////////////////////////////////////////////////////////////////////////////////////////////////////
class __DLL_NCS_CMD__ ResetPasswordForm : public NC_Command
 {
   static const ClassName _STR_ThisClass;

   public:
       ResetPasswordForm(void) : _LogId(_STR_EMPTY_) { }
    ~ResetPasswordForm() {  }
    void  operator delete( void* p ) { ::delete p; }

   public:
    virtual bool CheckParameters(const HttpRequest& Req, HttpResponse& Res,
                                 NC_Environment& Env, NC_Environment& Resources);
    virtual bool Process        (const HttpRequest& Req, HttpResponse& Res, NC_Environment& Env);

   protected:
       String _LogId;
 };


/////////////////////////////////////////////////////////////////////////////////////////////////////
//
/////////////////////////////////////////////////////////////////////////////////////////////////////
class __DLL_NCS_CMD__ AdminPasswordForm : public NC_Command
 {
   static const ClassName _STR_ThisClass;

   public:
    AdminPasswordForm(void)  { }
    ~AdminPasswordForm() {  }
    void  operator delete( void* p ) { ::delete p; }

   public:
    virtual bool CheckParameters(const HttpRequest& Req, HttpResponse& Res,
                                 NC_Environment& Env, NC_Environment& Resources);
    virtual bool Process        (const HttpRequest& Req, HttpResponse& Res, NC_Environment& Env);
 };


class UserManager : public NC_Void
{
public:

    UserManager(const String & LogId);
    ~UserManager();

    User * getUser         () { return _User; }
    bool   SetUserPassword (const String & NewPassword);    

private:
    bool   Write();

private:
    
    UserHome _UHome;
    User *   _User;

};

#endif


