/****************************************************************************************/
/*                                                                                      */
/* Licensed Materials - Property of IBM                              			    */
/*                                                                   			    */
/* 5697-D24                                                           			    */
/*                                                                  			    */
/* (c)  Copyright  IBM Corp.  1998, 1999.      All Rights Reserved   			    */
/*                                                                   			    */
/* US Government Users Restricted Rights - Use, duplication or       			    */
/* disclosure restricted by GSA ADP Schedule Contract with IBM Corp. 			    */
/*                                                                                      */
/****************************************************************************************/
//////////////////////////////////////////////////////////////////////////////////////////
// YYMMDD  F/D#   WHO    Description
// ---------------------------------------------------------------------------------------
// 980504  33789  RML
//////////////////////////////////////////////////////////////////////////////////////////
#ifndef NCDirectoryMapper_h
#define NCDirectoryMapper_h

#include <ldap.h>

// really should have abstract class for directories
// but, in NC 4, this will be java code (JNDI?) so 
// this is temporary solution
// Also, should probably keep an open connection to LDAP server

class NCDirectoryMapper {

private:

    LDAP	*ld;

	inline bool CHECK_STATUS_RC(const char *nme, int rc){  if(rc != LDAP_SUCCESS) { debug << "Error calling " <<nme << ": " << ldap_err2string( rc ) << "\n"; } return rc == LDAP_SUCCESS; }
	inline bool CHECK_STATUS_BOOL(const char *nme, bool rc){  if(rc != TRUE) { debug << "Error calling " <<nme << "\n"; } return rc; }

	inline bool Init(const char * hostName, int port) 
	{ 
		return CHECK_STATUS_BOOL("ldap_init", ((ld = ldap_init( hostName, port )) != NULL));		
	}

public:

	inline bool Init(const String& hostName, int port) 
	{ 
		return (Init(hostName.c_str(), port));
	}

	
	inline void Term() 
	{
		CHECK_STATUS_RC("ldap_unbind", ldap_unbind( ld )); 
	} 

	inline bool Bind(const char * userName, const char * pwd)
	{
		int rc = ldap_simple_bind_s( ld, userName, pwd);		
		return CHECK_STATUS_RC("ldap_simple_bind_s", rc);
	}

	inline bool Bind(const String& userName, const String& pwd) 
	{ 
		return Bind(userName.c_str(), pwd.c_str()); 
	}
	
	inline bool Bind() 
	{ 
		return Bind(NULL, NULL); 
	} 
	
	bool Map(const String& name, const StringArray& directoryAttribs, const StringArray& shopperAttribs, NVPHash& map); 

};
#endif

