#ifndef _cat_view_schema_h_
#define _cat_view_schema_h_


/*********************************************************************/
/*                                                                   */
/* Licensed Materials - Property of IBM                              */
/*                                                                   */
/* 5697-D24                                                          */
/*                                                                   */
/* (C) Copyright IBM Corp. 1996, 1999. All Rights Reserved           */
/*                                                                   */
/* US Government Users Restricted Rights - Use, duplication or       */
/* disclosure restricted by GSA, ADP Schedule Contract with IBM Corp.*/
/*                                                                   */
/*********************************************************************/
//////////////////////////////////////////////////////////////////////////////////////////
// Change History
//////////////////////////////////////////////////////////////////////////////////////////
// YYMMDD  F/D#   WHO    Description
// ---------------------------------------------------------------------------------------
// 980727  d26082 lam    Catalog Architect.
//
//////////////////////////////////////////////////////////////////////////////////////////


class StaticSQL;

class __DLL_NCS_OBJ__ CategoryView : public SQL_Schema
 {
   // These two lines are for the static SQL implementation.  They must be put in
   // all files that use this.
   friend class StaticSQL;
   friend class CategoryViewHome;

   #if !defined(AS400)
   static const ClassName _STR_ThisClass;  // Strings used for tracing and debugging
   #endif

   public:
    CategoryView(DataBase& DB);

   public: // Schema column names
    static const StringWithOwnership _COL_TNAME                   ;
    static const StringWithOwnership _COL_MERCHANT_REF_NUM        ;
    static const StringWithOwnership _COL_CATEGORY_REF_NUM        ;
    static const StringWithOwnership _COL_SHOPPER_GROUP_REF_NUM   ;
    static const StringWithOwnership _COL_DISPLAY                 ;
    static const StringWithOwnership _COL_DESCRIPTION             ;
    static const StringWithOwnership _COL_FIELD1                  ;
    static const StringWithOwnership _COL_FIELD2                  ;
// d26082 start
    static const StringWithOwnership _COL_OBJECT_ID           ;
// d26082 end

   public: // Get functions
    const String& getMerchantRefNum    (bool Real=true) { return SQL_Schema::getValue(_COL_MERCHANT_REF_NUM     , Real); }
    const String& getCategoryRefNum    (bool Real=true) { return SQL_Schema::getValue(_COL_CATEGORY_REF_NUM     , Real); }
    const String& getShopperGroupRefNum(bool Real=true) { return SQL_Schema::getValue(_COL_SHOPPER_GROUP_REF_NUM, Real); }
    const String& getDisplay           (bool Real=true) { return SQL_Schema::getValue(_COL_DISPLAY              , Real); }
    const String& getDescription       (bool Real=true) { return SQL_Schema::getValue(_COL_DESCRIPTION          , Real); }
    const String& getField1            (bool Real=true) { return SQL_Schema::getValue(_COL_FIELD1               , Real); }
    const String& getField2            (bool Real=true) { return SQL_Schema::getValue(_COL_FIELD2               , Real); }
// d26082 start
    const String& getObjectid         (bool Real=true) { return SQL_Schema::getValue(_COL_OBJECT_ID        , Real); }
// d26082 end

   public: // Set functions
    void setMerchantRefNum    (const String& MerchantRefNum    ) { SQL_Schema::setValue(_COL_MERCHANT_REF_NUM        ,MerchantRefNum    ); }
    void setCategoryRefNum    (const String& CategoryRefNum    ) { SQL_Schema::setValue(_COL_CATEGORY_REF_NUM        ,CategoryRefNum    ); }
    void setShopperGroupRefNum(const String& ShopperGroupRefNum) { SQL_Schema::setValue(_COL_SHOPPER_GROUP_REF_NUM   ,ShopperGroupRefNum); }
    void setDisplay           (const String& Display           ) { SQL_Schema::setValue(_COL_DISPLAY                 ,Display           ); }
    void setDescription       (const String& Description       ) { SQL_Schema::setValue(_COL_DESCRIPTION             ,Description       ); }
    void setField1            (const String& Field1            ) { SQL_Schema::setValue(_COL_FIELD1                  ,Field1            ); }
    void setField2            (const String& Field2            ) { SQL_Schema::setValue(_COL_FIELD2                  ,Field2            ); }
// d26082 start
    void setObjectid         (const String& Objectid         ) { SQL_Schema::setValue(_COL_OBJECT_ID           ,Objectid         ); }
// d26082 end

 };



class __DLL_NCS_OBJ__ CategoryViewHome : public SQL_SchemaMap<CategoryView>
 {
   #if !defined(AS400)
   static const ClassName _STR_ThisClass;  // Strings used for tracing and debugging
   #endif

   public:
    CategoryViewHome(DataBase& DB) : SQL_SchemaMap<CategoryView>(DB) { }


   public:
    CategoryView* Create(const String& MerchantRefNum, const String& ShopperGroupRefNum,
                         const String& CategoryRefNum, const String& Display,
                         const NVPHash& NameValuePairs);
    CategoryView* Create(const String& MerchantRefNum, const String& ShopperGroupRefNum,
                         const String& CategoryRefNum, const String& Display);

    CategoryView* Lookup(const String& MerchantRefNum, const String& ShopperGroupRefNum,
                         const String& CategoryRefNum, const NVPHash& NameValuePairs);
    CategoryView* Lookup(const String& MerchantRefNum, const String& ShopperGroupRefNum,
                         const String& CategoryRefNum);
 };



#endif

