
/*********************************************************************/
/*                                                                   */
/* Licensed Materials - Property of IBM                              */
/*                                                                   */
/* 5697-D24                                                          */
/*                                                                   */
/* (C) Copyright IBM Corp. 1996, 1999. All Rights Reserved           */
/*                                                                   */
/* US Government Users Restricted Rights - Use, duplication or       */
/* disclosure restricted by GSA, ADP Schedule Contract with IBM Corp.*/
/*                                                                   */
/*********************************************************************/

#ifndef _MERCHANT_SCHEMA_H_
#define _MERCHANT_SCHEMA_H_

class StaticSQL;

class __DLL_NCS_OBJ__ Merchant : public SQL_Schema
 {
   // These two lines are for the static SQL implementation.  They must be put in
   // all files that use this.
   friend class StaticSQL;
   friend class MerchantHome;

   #if !defined(AS400)
   static const ClassName _STR_ThisClass;  // Strings used for tracing and debugging
   #endif

   public:
    Merchant(DataBase& DB);

   public: // Schema column names
    static const StringWithOwnership _COL_TNAME               ;
    static const StringWithOwnership _COL_REF_NUM             ;
    static const StringWithOwnership _COL_NAME                ;
    static const StringWithOwnership _COL_CNTCT_LAST_NAME     ;
    static const StringWithOwnership _COL_CNTCT_FIRST_NAME    ;
    static const StringWithOwnership _COL_CNTCT_MIDDLE_NAME   ;
    static const StringWithOwnership _COL_CNTCT_TITLE         ;
    static const StringWithOwnership _COL_CNTCT_PHONE1        ;
    static const StringWithOwnership _COL_CNTCT_PHONE2        ;
    static const StringWithOwnership _COL_CNTCT_FAX           ;
    static const StringWithOwnership _COL_CNTCT_MAIL1         ;
    static const StringWithOwnership _COL_CNTCT_MAIL2         ;
    static const StringWithOwnership _COL_MER_PHONE           ;
    static const StringWithOwnership _COL_MER_ADDR1           ;
    static const StringWithOwnership _COL_MER_ADDR2           ;
    static const StringWithOwnership _COL_MER_ADDR3           ;
    static const StringWithOwnership _COL_MER_CITY            ;
    static const StringWithOwnership _COL_MER_STATE           ;
    static const StringWithOwnership _COL_MER_COUNTRY         ;
    static const StringWithOwnership _COL_MER_ZIP_CODE        ;
    static const StringWithOwnership _COL_STORE_NAME          ;
    static const StringWithOwnership _COL_STORE_DESC          ;
    static const StringWithOwnership _COL_STORE_CATEGORY      ;
    static const StringWithOwnership _COL_STORE_IMAGE         ;
    static const StringWithOwnership _COL_STORE_HTML_HEADER   ;
    static const StringWithOwnership _COL_STORE_HTML_FOOTER   ;
    static const StringWithOwnership _COL_STORE_HTML_BASE     ;
    static const StringWithOwnership _COL_CURRENCY            ;
    static const StringWithOwnership _COL_FIELD1              ;
    static const StringWithOwnership _COL_FIELD2              ;
    static const StringWithOwnership _COL_OBJECT_ID           ;

   public: // Get functions
    const String& getRefNum           (bool Real=true) { return SQL_Schema::getValue(_COL_REF_NUM          , Real); }
    const String& getName             (bool Real=true) { return SQL_Schema::getValue(_COL_NAME             , Real); }
    const String& getContactLastName  (bool Real=true) { return SQL_Schema::getValue(_COL_CNTCT_LAST_NAME  , Real); }
    const String& getContactFirstName (bool Real=true) { return SQL_Schema::getValue(_COL_CNTCT_FIRST_NAME , Real); }
    const String& getContactMiddleName(bool Real=true) { return SQL_Schema::getValue(_COL_CNTCT_MIDDLE_NAME, Real); }
    const String& getContactTitle     (bool Real=true) { return SQL_Schema::getValue(_COL_CNTCT_TITLE      , Real); }
    const String& getContactPhone1    (bool Real=true) { return SQL_Schema::getValue(_COL_CNTCT_PHONE1     , Real); }
    const String& getContactPhone2    (bool Real=true) { return SQL_Schema::getValue(_COL_CNTCT_PHONE2     , Real); }
    const String& getContactFax       (bool Real=true) { return SQL_Schema::getValue(_COL_CNTCT_FAX        , Real); }
    const String& getContactMail1     (bool Real=true) { return SQL_Schema::getValue(_COL_CNTCT_MAIL1      , Real); }
    const String& getContactMail2     (bool Real=true) { return SQL_Schema::getValue(_COL_CNTCT_MAIL2      , Real); }
    const String& getPhone            (bool Real=true) { return SQL_Schema::getValue(_COL_MER_PHONE        , Real); }
    const String& getAddress1         (bool Real=true) { return SQL_Schema::getValue(_COL_MER_ADDR1        , Real); }
    const String& getAddress2         (bool Real=true) { return SQL_Schema::getValue(_COL_MER_ADDR2        , Real); }
    const String& getAddress3         (bool Real=true) { return SQL_Schema::getValue(_COL_MER_ADDR3        , Real); }
    const String& getCity             (bool Real=true) { return SQL_Schema::getValue(_COL_MER_CITY         , Real); }
    const String& getState            (bool Real=true) { return SQL_Schema::getValue(_COL_MER_STATE        , Real); }
    const String& getCountry          (bool Real=true) { return SQL_Schema::getValue(_COL_MER_COUNTRY      , Real); }
    const String& getZipCode          (bool Real=true) { return SQL_Schema::getValue(_COL_MER_ZIP_CODE     , Real); }
    const String& getStoreName        (bool Real=true) { return SQL_Schema::getValue(_COL_STORE_NAME       , Real); }
    const String& getStoreDescription (bool Real=true) { return SQL_Schema::getValue(_COL_STORE_DESC       , Real); }
    const String& getStoreCategory    (bool Real=true) { return SQL_Schema::getValue(_COL_STORE_CATEGORY   , Real); }
    const String& getStoreImage       (bool Real=true) { return SQL_Schema::getValue(_COL_STORE_IMAGE      , Real); }
    const String& getStoreHeader      (bool Real=true) { return SQL_Schema::getValue(_COL_STORE_HTML_HEADER, Real); }
    const String& getStoreFooter      (bool Real=true) { return SQL_Schema::getValue(_COL_STORE_HTML_FOOTER, Real); }
    const String& getStoreBase        (bool Real=true) { return SQL_Schema::getValue(_COL_STORE_HTML_BASE  , Real); }
    const String& getCurrency         (bool Real=true) { return SQL_Schema::getValue(_COL_CURRENCY         , Real); }
    const String& getField1           (bool Real=true) { return SQL_Schema::getValue(_COL_FIELD1           , Real); }
    const String& getField2           (bool Real=true) { return SQL_Schema::getValue(_COL_FIELD2           , Real); }
    const String& getObjectid         (bool Real=true) { return SQL_Schema::getValue(_COL_OBJECT_ID        , Real); }

   public: // Set functions
    void setRefNum           (const String& RefNum           ) { SQL_Schema::setValue(_COL_REF_NUM             ,RefNum           ); }
    void setName             (const String& Name             ) { SQL_Schema::setValue(_COL_NAME                ,Name             ); }
    void setContactLastName  (const String& ContactLastName  ) { SQL_Schema::setValue(_COL_CNTCT_LAST_NAME     ,ContactLastName  ); }
    void setContactFirstName (const String& ContactFirstName ) { SQL_Schema::setValue(_COL_CNTCT_FIRST_NAME    ,ContactFirstName ); }
    void setContactMiddleName(const String& ContactMiddleName) { SQL_Schema::setValue(_COL_CNTCT_MIDDLE_NAME   ,ContactMiddleName); }
    void setContactTitle     (const String& ContactTitle     ) { SQL_Schema::setValue(_COL_CNTCT_TITLE         ,ContactTitle     ); }
    void setContactPhone1    (const String& ContactPhone1    ) { SQL_Schema::setValue(_COL_CNTCT_PHONE1        ,ContactPhone1    ); }
    void setContactPhone2    (const String& ContactPhone2    ) { SQL_Schema::setValue(_COL_CNTCT_PHONE2        ,ContactPhone2    ); }
    void setContactFax       (const String& ContactFax       ) { SQL_Schema::setValue(_COL_CNTCT_FAX           ,ContactFax       ); }
    void setContactMail1     (const String& ContactMail1     ) { SQL_Schema::setValue(_COL_CNTCT_MAIL1         ,ContactMail1     ); }
    void setContactMail2     (const String& ContactMail2     ) { SQL_Schema::setValue(_COL_CNTCT_MAIL2         ,ContactMail2     ); }
    void setPhone            (const String& Phone            ) { SQL_Schema::setValue(_COL_MER_PHONE           ,Phone            ); }
    void setAddress1         (const String& Address1         ) { SQL_Schema::setValue(_COL_MER_ADDR1           ,Address1         ); }
    void setAddress2         (const String& Address2         ) { SQL_Schema::setValue(_COL_MER_ADDR2           ,Address2         ); }
    void setAddress3         (const String& Address3         ) { SQL_Schema::setValue(_COL_MER_ADDR3           ,Address3         ); }
    void setCity             (const String& City             ) { SQL_Schema::setValue(_COL_MER_CITY            ,City             ); }
    void setState            (const String& State            ) { SQL_Schema::setValue(_COL_MER_STATE           ,State            ); }
    void setCountry          (const String& Country          ) { SQL_Schema::setValue(_COL_MER_COUNTRY         ,Country          ); }
    void setZipCode          (const String& ZipCode          ) { SQL_Schema::setValue(_COL_MER_ZIP_CODE        ,ZipCode          ); }
    void setStoreName        (const String& StoreName        ) { SQL_Schema::setValue(_COL_STORE_NAME          ,StoreName        ); }
    void setStoreDescription (const String& StoreDescription ) { SQL_Schema::setValue(_COL_STORE_DESC          ,StoreDescription ); }
    void setStoreCategory    (const String& StoreCategory    ) { SQL_Schema::setValue(_COL_STORE_CATEGORY      ,StoreCategory    ); }
    void setStoreImage       (const String& StoreImage       ) { SQL_Schema::setValue(_COL_STORE_IMAGE         ,StoreImage       ); }
    void setStoreHeader      (const String& StoreHeader      ) { SQL_Schema::setValue(_COL_STORE_HTML_HEADER   ,StoreHeader      ); }
    void setStoreFooter      (const String& StoreFooter      ) { SQL_Schema::setValue(_COL_STORE_HTML_FOOTER   ,StoreFooter      ); }
    void setStoreBase        (const String& StoreBase        ) { SQL_Schema::setValue(_COL_STORE_HTML_BASE     ,StoreBase        ); }
    void setCurrency         (const String& Currency         ) { SQL_Schema::setValue(_COL_CURRENCY            ,Currency         ); }
    void setField1           (const String& Field1           ) { SQL_Schema::setValue(_COL_FIELD1              ,Field1           ); }
    void setField2           (const String& Field2           ) { SQL_Schema::setValue(_COL_FIELD2              ,Field2           ); }
    void setObjectid         (const String& Objectid         ) { SQL_Schema::setValue(_COL_OBJECT_ID           ,Objectid         ); }
 };


class __DLL_NCS_OBJ__ MerchantHome : public SQL_SchemaMap<Merchant>
 {
   #if !defined(AS400)
   static const ClassName _STR_ThisClass;  // Strings used for tracing and debugging
   #endif

   public:
    MerchantHome(DataBase& DB) : SQL_SchemaMap<Merchant>(DB) { }

   public:
    Merchant* Create(const String& ContactLastName, const String& ContactFirstName,
                     const String& ContactPhone1, const String& Phone, const String& City,
                     const String& State, const String& Country, const String& StoreName,
                     const String& Currency, const NVPHash& NameValuePairs);
    Merchant* Create(const String& ContactLastName, const String& ContactFirstName,
                     const String& ContactPhone1, const String& Phone, const String& City,
                     const String& State, const String& Country, const String& StoreName,
                     const String& Currency);

    Merchant* Lookup(const String& RefNum, const NVPHash& NameValuePairs);
    Merchant* Lookup(const String& RefNum);
 };




#endif


