/*********************************************************************/
/*                                                                   */
/* Licensed Materials - Property of IBM                              */
/*                                                                   */
/* 5697-D24                                                          */
/*                                                                   */
/* (C) Copyright IBM Corp. 1996, 1999. All Rights Reserved           */
/*                                                                   */
/* US Government Users Restricted Rights - Use, duplication or       */
/* disclosure restricted by GSA, ADP Schedule Contract with IBM Corp.*/
/*                                                                   */
/*********************************************************************/

#ifndef _PROD_ATTR_VAL_SCHEMA_H_
#define _PROD_ATTR_VAL_SCHEMA_H_


class StaticSQL;

class __DLL_NCS_OBJ__ SkuAttributeValue : public SQL_Schema
 {
   // These two lines are for the static SQL implementation.  They must be put in
   // all files that use this.
   friend class StaticSQL;
   friend class SkuAttributeValueHome;

   #if !defined(AS400)
   static const ClassName _STR_ThisClass;  // Strings used for tracing and debugging
   #endif

   public:
    SkuAttributeValue(DataBase& DB);

   public: // Schema column names
    static const StringWithOwnership _COL_TNAME           ;
    static const StringWithOwnership _COL_NAME            ;
    static const StringWithOwnership _COL_VALUE           ;
    static const StringWithOwnership _COL_SKU_REF_NUM     ;
    static const StringWithOwnership _COL_MERCHANT_REF_NUM;
    static const StringWithOwnership _COL_FIELD1          ;
    static const StringWithOwnership _COL_ATTRIBUTE_TYPE  ;
    static const StringWithOwnership _COL_OBJECT_ID       ;

   public: // Get functions
    const String& getName          (bool Real=true) { return SQL_Schema::getValue(_COL_NAME            , Real); }
    const String& getVal           (bool Real=true) { return SQL_Schema::getValue(_COL_VALUE           , Real); }
    const String& getSkuRefNum     (bool Real=true) { return SQL_Schema::getValue(_COL_SKU_REF_NUM     , Real); }
    const String& getMerchantRefNum(bool Real=true) { return SQL_Schema::getValue(_COL_MERCHANT_REF_NUM, Real); }
    const String& getField1        (bool Real=true) { return SQL_Schema::getValue(_COL_FIELD1          , Real); }
    const String& getAttributeType (bool Real=true) { return SQL_Schema::getValue(_COL_ATTRIBUTE_TYPE  , Real); }
    const String& getObjectid 	   (bool Real=true) { return SQL_Schema::getValue(_COL_OBJECT_ID       , Real); }

   public: // Set functions
    void setName          (const String& Name          ) { SQL_Schema::setValue(_COL_NAME            ,Name          ); }
    void setVal           (const String& Val           ) { SQL_Schema::setValue(_COL_VALUE           ,Val           ); }
    void setSkuRefNum     (const String& ProductRefNum ) { SQL_Schema::setValue(_COL_SKU_REF_NUM     ,ProductRefNum ); }
    void setMerchantRefNum(const String& MerchantRefNum) { SQL_Schema::setValue(_COL_MERCHANT_REF_NUM,MerchantRefNum); }
    void setField1        (const String& Field1        ) { SQL_Schema::setValue(_COL_FIELD1          ,Field1        ); }
    void setAttributeType (const String& AttributeType ) { SQL_Schema::setValue(_COL_ATTRIBUTE_TYPE  ,AttributeType ); }
    void setObjectid 	  (const String& Objectid      ) { SQL_Schema::setValue(_COL_OBJECT_ID       ,Objectid      ); }
 };



class __DLL_NCS_OBJ__ SkuAttributeValueHome : public SQL_SchemaMap<SkuAttributeValue>
 {
   #if !defined(AS400)
   static const ClassName _STR_ThisClass;  // Strings used for tracing and debugging
   #endif

   public:
    SkuAttributeValueHome(DataBase& DB) : SQL_SchemaMap<SkuAttributeValue>(DB) { }


   public:
    SkuAttributeValue* Create(const String& Name, const String& Val, const String& SkuRefNum,
                              const String& MerchantRefNum, const NVPHash& NameValuePairs);
    SkuAttributeValue* Create(const String& Name, const String& Val, const String& SkuRefNum,
                              const String& MerchantRefNum);

    SkuAttributeValue* Lookup(const String& Name, const String& SkuRefNum,
                              const NVPHash& NameValuePairs);
    SkuAttributeValue* Lookup(const String& Name, const String& SkuRefNum);

    String ResolveSku(const String& ParentProductRefNum,
                      const NVPHash& AttributeNameValuePairs);
 };



#endif
