
/*********************************************************************/
/*                                                                   */
/* Licensed Materials - Property of IBM                              */
/*                                                                   */
/* 5697-D24                                                          */
/*                                                                   */
/* (C) Copyright IBM Corp. 1996, 1999. All Rights Reserved           */
/*                                                                   */
/* US Government Users Restricted Rights - Use, duplication or       */
/* disclosure restricted by GSA, ADP Schedule Contract with IBM Corp.*/
/*                                                                   */
/*********************************************************************/

#ifndef _PRODUCT_SKU_SCHEMA_H_
#define _PRODUCT_SKU_SCHEMA_H_

class StaticSQL;

/////////////////////////////////////////////////////////////////////////////////////////
//
//  class SKU
//

class __DLL_NCS_OBJ__ SKU : public SQL_Schema
{
   #if !defined(AS400)
   static const ClassName _STR_ThisClass;  // Strings used for tracing and debugging
   #endif

protected:
   SKU(DataBase& DB);

public: // Schema column names
   static const StringWithOwnership _COL_TNAME               ;
   static const StringWithOwnership _COL_REF_NUM             ;
   static const StringWithOwnership _COL_PROD_REF_NUM        ;
   static const StringWithOwnership _COL_MERCHANT_REF_NUM    ;
   static const StringWithOwnership _COL_ID                  ;
   static const StringWithOwnership _COL_KNUTAG              ;
   static const StringWithOwnership _COL_SHIP_CODE           ;
   static const StringWithOwnership _COL_TAX_CODE            ;
   static const StringWithOwnership _COL_INVENTORY           ;
   static const StringWithOwnership _COL_AVAILABILITY_DATE   ;
   static const StringWithOwnership _COL_SPECIAL             ;
      static const StringWithOwnership _VAL_SPECIAL_SALE     ;
   static const StringWithOwnership _COL_TIME_LAST_UPDATED   ;
   static const StringWithOwnership _COL_FIELD1              ;
   static const StringWithOwnership _COL_FIELD2              ;
   static const StringWithOwnership _COL_FIELD3              ;
   static const StringWithOwnership _COL_FIELD4              ;
   static const StringWithOwnership _COL_FIELD5              ;
   static const StringWithOwnership _COL_PUBLISH          ;
      static const StringWithOwnership _VAL_PUBLISH_NOT   ;
      static const StringWithOwnership _VAL_PUBLISH_YES   ;
      static const StringWithOwnership _VAL_PUBLISH_DELETE;
   static const StringWithOwnership _COL_DISCOUNT_CODE   ;
   static const StringWithOwnership _COL_OBJECT_ID       ;

public: // Get functions
   const String& getRefNum          (bool Real=true) { return SQL_Schema::getValue(_COL_REF_NUM             , Real); }
   const String& getProdRefNum      (bool Real=true) { return SQL_Schema::getValue(_COL_PROD_REF_NUM        , Real); }
   const String& getMerchantRefNum  (bool Real=true) { return SQL_Schema::getValue(_COL_MERCHANT_REF_NUM    , Real); }
   const String& getName            (bool Real=true) { return SQL_Schema::getValue(_COL_ID                  , Real); }
   const String& getKnuTag          (bool Real=true) { return SQL_Schema::getValue(_COL_KNUTAG              , Real); }
   const String& getShipCode        (bool Real=true) { return SQL_Schema::getValue(_COL_SHIP_CODE           , Real); }
   const String& getTaxCode         (bool Real=true) { return SQL_Schema::getValue(_COL_TAX_CODE            , Real); }
   const String& getInventory       (bool Real=true) { return SQL_Schema::getValue(_COL_INVENTORY           , Real); }
   const String& getAvailability    (bool Real=true) { return SQL_Schema::getValue(_COL_AVAILABILITY_DATE   , Real); }
   const String& getSpecial         (bool Real=true) { return SQL_Schema::getValue(_COL_SPECIAL             , Real); }
            bool isOnSale           (bool Real=true) { return SQL_Schema::getValue(_COL_SPECIAL, Real) == _VAL_SPECIAL_SALE        ; }
   const String& getLastUpdate      (bool Real=true) { return SQL_Schema::getValue(_COL_TIME_LAST_UPDATED   , Real); }
   const String& getField1          (bool Real=true) { return SQL_Schema::getValue(_COL_FIELD1              , Real); }
   const String& getField2          (bool Real=true) { return SQL_Schema::getValue(_COL_FIELD2              , Real); }
   const String& getField3          (bool Real=true) { return SQL_Schema::getValue(_COL_FIELD3              , Real); }
   const String& getField4          (bool Real=true) { return SQL_Schema::getValue(_COL_FIELD4              , Real); }
   const String& getField5          (bool Real=true) { return SQL_Schema::getValue(_COL_FIELD5              , Real); }
   const String& getPublish         (bool Real=true) { return SQL_Schema::getValue(_COL_PUBLISH             , Real); }
            bool isNotPublished     (bool Real=true) { return SQL_Schema::getValue(_COL_PUBLISH, Real) == _VAL_PUBLISH_NOT         ; }
            bool isPublished        (bool Real=true) { return SQL_Schema::getValue(_COL_PUBLISH, Real) == _VAL_PUBLISH_YES         ; }
            bool isMarkedForDelete  (bool Real=true) { return SQL_Schema::getValue(_COL_PUBLISH, Real) == _VAL_PUBLISH_DELETE      ; }
   const String& getDiscountCode    (bool Real=true) { return SQL_Schema::getValue(_COL_DISCOUNT_CODE       , Real); }
   const String& getObjectid        (bool Real=true) { return SQL_Schema::getValue(_COL_OBJECT_ID           , Real); }

public: // Set functions
   void setRefNum          (const String& RefNum          ) { SQL_Schema::setValue(_COL_REF_NUM             ,RefNum          ); }
   void setProdRefNum      (const String& ProdRefNum      ) { SQL_Schema::setValue(_COL_PROD_REF_NUM        ,ProdRefNum      ); }
   void setMerchantRefNum  (const String& MerchantRefNum  ) { SQL_Schema::setValue(_COL_MERCHANT_REF_NUM    ,MerchantRefNum  ); }
   void setName            (const String& Name            ) { SQL_Schema::setValue(_COL_ID                  ,Name            ); }
   void setKnuTag          (const String& KnuTag          ) { SQL_Schema::setValue(_COL_KNUTAG              ,KnuTag          ); }
   void setShipCode        (const String& ShipCode        ) { SQL_Schema::setValue(_COL_SHIP_CODE           ,ShipCode        ); }
   void setTaxCode         (const String& TaxCode         ) { SQL_Schema::setValue(_COL_TAX_CODE            ,TaxCode         ); }
   void setInventory       (const String& Inventory       ) { SQL_Schema::setValue(_COL_INVENTORY           ,Inventory       ); }
   void setAvailability    (const String& Availability    ) { SQL_Schema::setValue(_COL_AVAILABILITY_DATE   ,Availability    ); }
   void setSpecial         (const String& Special         ) { SQL_Schema::setValue(_COL_SPECIAL             ,Special         ); }
   void setLastUpdate      (const String& LastUpdate      ) { SQL_Schema::setValue(_COL_TIME_LAST_UPDATED   ,LastUpdate      ); }
   void setField1          (const String& Field1          ) { SQL_Schema::setValue(_COL_FIELD1              ,Field1          ); }
   void setField2          (const String& Field2          ) { SQL_Schema::setValue(_COL_FIELD2              ,Field2          ); }
   void setField3          (const String& Field3          ) { SQL_Schema::setValue(_COL_FIELD3              ,Field3          ); }
   void setField4          (const String& Field4          ) { SQL_Schema::setValue(_COL_FIELD4              ,Field4          ); }
   void setField5          (const String& Field5          ) { SQL_Schema::setValue(_COL_FIELD5              ,Field5          ); }
   void setPublish         (const String& Publish         ) { SQL_Schema::setValue(_COL_PUBLISH             ,Publish         ); }
   void setDiscountCode    (const String& DiscountCode    ) { SQL_Schema::setValue(_COL_DISCOUNT_CODE       ,DiscountCode    ); }
   void setObjectid        (const String& Objectid        ) { SQL_Schema::setValue(_COL_OBJECT_ID           ,Objectid        ); }

public:
   const Product* getParent(void) { return _Product; }
   getAttributesValues(void);

protected:
   Product* _Product;
};


class __DLL_NCS_OBJ__ SKU_Hard : public SKU
{
   // These two lines are for the static SQL implementation.  They must be put in
   // all files that use this.
   friend class StaticSQL;
   friend class SKU_HardHome;

   #if !defined(AS400)
   static const ClassName _STR_ThisClass;  // Strings used for tracing and debugging
   #endif

public:
   SKU_Hard(DataBase& DB);

public: // Schema column names
   static const StringWithOwnership _COL_TNAME       ;
   static const StringWithOwnership _COL_WEIGHT      ;
   static const StringWithOwnership _COL_WEIGHT_UNIT ;
   static const StringWithOwnership _COL_LENGTH      ;
   static const StringWithOwnership _COL_WIDTH       ;
   static const StringWithOwnership _COL_HEIGHT      ;
   static const StringWithOwnership _COL_MEASURE_UNIT;

public: // Get functions
   const String& getWeight         (bool Real=true) { return SQL_Schema::getValue(_COL_WEIGHT      , Real); }
   const String& getWeightUnit     (bool Real=true) { return SQL_Schema::getValue(_COL_WEIGHT_UNIT , Real); }
   const String& getLength         (bool Real=true) { return SQL_Schema::getValue(_COL_LENGTH      , Real); }
   const String& getWidth          (bool Real=true) { return SQL_Schema::getValue(_COL_WIDTH       , Real); }
   const String& getHeight         (bool Real=true) { return SQL_Schema::getValue(_COL_HEIGHT      , Real); }
   const String& getMeasurementUnit(bool Real=true) { return SQL_Schema::getValue(_COL_MEASURE_UNIT, Real); }

public: // Set functions
   void setWeight         (const String& Weight         ) { SQL_Schema::setValue(_COL_WEIGHT         ,Weight         ); }
   void setWeightUnit     (const String& WeightUnit     ) { SQL_Schema::setValue(_COL_WEIGHT_UNIT    ,WeightUnit     ); }
   void setLength         (const String& Length         ) { SQL_Schema::setValue(_COL_LENGTH         ,Length         ); }
   void setWidth          (const String& Width          ) { SQL_Schema::setValue(_COL_WIDTH          ,Width          ); }
   void setHeight         (const String& Height         ) { SQL_Schema::setValue(_COL_HEIGHT         ,Height         ); }
   void setMeasurementUnit(const String& MeasurementUnit) { SQL_Schema::setValue(_COL_MEASURE_UNIT   ,MeasurementUnit); }
};


class __DLL_NCS_OBJ__ SKU_HardHome : public SQL_SchemaMap<SKU_Hard>
{
   #if !defined(AS400)
   static const ClassName _STR_ThisClass;  // Strings used for tracing and debugging
   #endif

public:
   SKU_HardHome(DataBase& DB) : SQL_SchemaMap<SKU_Hard>(DB) { }


public:
   SKU_Hard* Create(const String& ProdRefNum, const String& MerchantRefNum, const String& Name,
                    const NVPHash& NameValuePairs );
   SKU_Hard* Create(const String& ProdRefNum, const String& MerchantRefNum, const String& Name);

   SKU_Hard* Lookup(const String& RefNum, const NVPHash& NameValuePairs);
   SKU_Hard* Lookup(const String& RefNum);

   SKU_Hard* LookupByMerchantAndName(const String& MerchantRefNum, const String& Name,
                                     const NVPHash& NameValuePairs);
   SKU_Hard* LookupByMerchantAndName(const String& MerchantRefNum, const String& Name);
};



/////////////////////////////////////////////////////////////////////////////////////////
//
//  class SKUDescription
//

class __DLL_NCS_OBJ__ SKUDescription : public SQL_Schema
{
   #if !defined(AS400)
   static const ClassName _STR_ThisClass;  // Strings used for tracing and debugging
   #endif
   friend class SKUDescriptionHome;

public:
   SKUDescription(DataBase& DB);

public: // Schema column names
   static const StringWithOwnership _COL_TNAME            ;
   static const StringWithOwnership _COL_SKU_REF_NUM      ;
   static const StringWithOwnership _COL_URL_LINK         ;
   static const StringWithOwnership _COL_SHORT_DESC       ;
   static const StringWithOwnership _COL_LONG_DESC1       ;
   static const StringWithOwnership _COL_LONG_DESC2       ;
   static const StringWithOwnership _COL_LONG_DESC3       ;
   static const StringWithOwnership _COL_LARGE_IMAGE      ;
   static const StringWithOwnership _COL_SMALL_IMAGE      ;
   static const StringWithOwnership _COL_PUBLISH          ;
      static const StringWithOwnership _VAL_PUBLISH_NOT   ;
      static const StringWithOwnership _VAL_PUBLISH_YES   ;
      static const StringWithOwnership _VAL_PUBLISH_DELETE;

public: // Get functions
   const String& getSKURefNum       (bool Real=true) { return SQL_Schema::getValue(_COL_SKU_REF_NUM         , Real); }
   const String& getLink            (bool Real=true) { return SQL_Schema::getValue(_COL_URL_LINK            , Real); }
   const String& getShortDescription(bool Real=true) { return SQL_Schema::getValue(_COL_SHORT_DESC          , Real); }
   const String& getLongDescription1(bool Real=true) { return SQL_Schema::getValue(_COL_LONG_DESC1          , Real); }
   const String& getLongDescription2(bool Real=true) { return SQL_Schema::getValue(_COL_LONG_DESC2          , Real); }
   const String& getLongDescription3(bool Real=true) { return SQL_Schema::getValue(_COL_LONG_DESC3          , Real); }
   const String& getLargeImage      (bool Real=true) { return SQL_Schema::getValue(_COL_LARGE_IMAGE         , Real); }
   const String& getSmallImage      (bool Real=true) { return SQL_Schema::getValue(_COL_SMALL_IMAGE         , Real); }
   const String& getPublish         (bool Real=true) { return SQL_Schema::getValue(_COL_PUBLISH             , Real); }
            bool isNotPublished     (bool Real=true) { return SQL_Schema::getValue(_COL_PUBLISH, Real) == _VAL_PUBLISH_NOT         ; }
            bool isPublished        (bool Real=true) { return SQL_Schema::getValue(_COL_PUBLISH, Real) == _VAL_PUBLISH_YES         ; }
            bool isMarkedForDelete  (bool Real=true) { return SQL_Schema::getValue(_COL_PUBLISH, Real) == _VAL_PUBLISH_DELETE      ; }

public: // Set functions
   void setSkuRefNum       (const String& RefNum          ) { SQL_Schema::setValue(_COL_SKU_REF_NUM         ,RefNum          ); }
   void setLink            (const String& Link            ) { SQL_Schema::setValue(_COL_URL_LINK            ,Link            ); }
   void setShortDescription(const String& ShortDescription) { SQL_Schema::setValue(_COL_SHORT_DESC          ,ShortDescription); }
   void setLongDescription1(const String& LongDescription1) { SQL_Schema::setValue(_COL_LONG_DESC1          ,LongDescription1); }
   void setLongDescription2(const String& LongDescription2) { SQL_Schema::setValue(_COL_LONG_DESC2          ,LongDescription2); }
   void setLongDescription3(const String& LongDescription3) { SQL_Schema::setValue(_COL_LONG_DESC3          ,LongDescription3); }
   void setLargeImage      (const String& LargeImage      ) { SQL_Schema::setValue(_COL_LARGE_IMAGE         ,LargeImage      ); }
   void setSmallImage      (const String& SmallImage      ) { SQL_Schema::setValue(_COL_SMALL_IMAGE         ,SmallImage      ); }
   void setPublish         (const String& Publish         ) { SQL_Schema::setValue(_COL_PUBLISH             ,Publish         ); }
};

class __DLL_NCS_OBJ__ SKUDescriptionHome : public SQL_SchemaMap<SKUDescription>
 {
   #if !defined(AS400)
   static const ClassName _STR_ThisClass;  // Strings used for tracing and debugging
   #endif

   public:
    SKUDescriptionHome(DataBase& DB) : SQL_SchemaMap<SKUDescription>(DB) { }

   public:
    SKUDescription* Create(const String& SkuRefNum, const NVPHash& NameValuePairs);
    SKUDescription* Create(const String& SkuRefNum);

    SKUDescription* Lookup(const String& SkuRefNum, const NVPHash& NameValuePairs);
    SKUDescription* Lookup(const String& SkuRefNum);
 };


#endif
