#ifndef _schconfig_schema_h_
#define _schconfig_schema_h_
/*********************************************************************/
/* Licensed Materials - Property of IBM                              */
/*                                                                   */
/* 5697-D24                                                          */
/*                                                                   */
/* (c)  Copyright  IBM Corp.  1998, 1999.      All Rights Reserved   */
/*                                                                   */
/* US Government Users Restricted Rights - Use, duplication or       */
/* disclosure restricted by GSA ADP Schedule Contract with IBM Corp. */
/*********************************************************************/
///////////////////////////////////////////////////////////////////////
// This file is part of Net.Commerce                                 //
// Header file for SchConfig.                                               //
///////////////////////////////////////////////////////////////////////




class StaticSQL;

class __DLL_NCS_OBJ__ SchConfig : public SQL_Schema
 { 
   // These two lines are for the static SQL implementation.  They must be put in
   // all files that use this.
   friend class StaticSQL; 
   friend class SchConfigHome;

   #if !defined(AS400)
   static const ClassName _STR_ThisClass;  // Strings used for tracing and debugging
   #endif 

   public: 
     // Database against which the object is used. If LoadAll is true, the object loads 
     //all fields at once. Otherwise, loads the minimum set, and will load the others 
     //on demand
    SchConfig(DataBase& DB, bool LoadAll=true);

   public: // Schema column names
    static const StringWithOwnership _COL_TNAME   ;
    static const StringWithOwnership _COL_REF_NUM ;
    static const StringWithOwnership _COL_HOST    ;
    static const StringWithOwnership _COL_DELAY   ;
    static const StringWithOwnership _COL_ATTEMPTS;
    static const StringWithOwnership _COL_USER    ;
    static const StringWithOwnership _COL_PATHINFO;
    static const StringWithOwnership _COL_QUERY   ;
    static const StringWithOwnership _COL_START   ;
    static const StringWithOwnership _COL_INTERVAL;
    static const StringWithOwnership _COL_PRIORITY;
    static const StringWithOwnership _COL_SEQUENCE;
	static const StringWithOwnership _COL_MARK	  ;
    static const StringWithOwnership _VAL_MARK_DELETED;


   public: // Get functions
    
	bool isMarkDeleted (bool Real=true) { return getMark(Real) == _VAL_MARK_DELETED; }
   
	const String& getRefNum  (bool Real=true);
    const String& getHost    (bool Real=true);
    const String& getDelay   (bool Real=true);
    const String& getAttempts(bool Real=true);
    const String& getUser    (bool Real=true);
    const String& getPathInfo(bool Real=true);
    const String& getQuery   (bool Real=true);
    const String& getStart   (bool Real=true);
    const String& getInterval(bool Real=true);
    const String& getPriority(bool Real=true);
    const String& getSequence(bool Real=true);
	const String& getMark	 (bool Real=true);

   public: // Set functions
    void setRefNum  (const String& RefNum  );
    void setHost    (const String& Host    );
    void setDelay   (const String& Delay   );
    void setAttempts(const String& Attempts);
    void setUser    (const String& User    );
    void setPathInfo(const String& PathInfo);
    void setQuery   (const String& Query   );
    void setStart   (const String& Start   );
    void setInterval(const String& Interval);
    void setPriority(const String& Priority);
    void setSequence(const String& Sequence);
    void setMark	(const String& Mark	   );
 
};



class __DLL_NCS_OBJ__ SchConfigHome : public SQL_SchemaMap<SchConfig>
 { 
   static const ClassName _STR_ThisClass;  // Strings used for tracing and debugging 
   static const FuncName  _STR_Create; 
   static const FuncName  _STR_Lookup; 

   public: 
    SchConfigHome(DataBase& DB)  : SQL_SchemaMap<SchConfig>(DB) { }


   public: 
    SchConfig* Create(const String & UserRefNum, const String& PathInfo, const String & StartTime, const NVPHash& NameValuePairs);
    SchConfig* Lookup(const String& RefNum, const NVPHash& NameValuePairs);
    SchConfig* LookupByRefNbr(const String& RefNum, const NVPHash& NameValuePairs);
 };



class __DLL_NCS_OBJ__ SchConfigNVP : public NC_Void
 { 
   #if !defined(AS400)
   static const ClassName _STR_ThisClass;  // Strings used for tracing and debugging
   #endif 

   public: 
       static const StringWithOwnership _NVP_HOST ;
       static const StringWithOwnership _NVP_DELAY;
       static const StringWithOwnership _NVP_ATTEMPTS;
       static const StringWithOwnership _NVP_USER ;
       static const StringWithOwnership _NVP_PATHINFO;
       static const StringWithOwnership _NVP_QUERY;
       static const StringWithOwnership _NVP_START;
       static const StringWithOwnership _NVP_INTERVAL;
       static const StringWithOwnership _NVP_PRIORITY;
       static const StringWithOwnership _NVP_SEQUENCE;

   public: 
    static bool CreateSchemaNVP(const HttpRequest& Req, NC_Environment& Env,
                                const String& ErrorTask, const String& MerchantRefNum,
                                NVPHash& NameValuePairs
                               );
    static void SetThroughNVP  (const HttpRequest& Req, SchConfig* R);

 };



#endif

