#ifndef _userTraffic_schema_h_
#define _userTraffic_schema_h_
/*********************************************************************/
/* Licensed Materials - Property of IBM                              */
/*                                                                   */
/* 5697-D24                                                          */
/*                                                                   */
/* (c)  Copyright  IBM Corp.  1998, 1999.      All Rights Reserved   */
/*                                                                   */
/* US Government Users Restricted Rights - Use, duplication or       */
/* disclosure restricted by GSA ADP Schedule Contract with IBM Corp. */
/*********************************************************************/
///////////////////////////////////////////////////////////////////////
// This file is part of Net.Commerce                                 //
// Header file for UserTraffic.                                               //
///////////////////////////////////////////////////////////////////////




class StaticSQL;

class __DLL_NCS_OBJ__ UserTraffic : public SQL_Schema
 { 
   // These two lines are for the static SQL implementation.  They must be put in
   // all files that use this.
   friend class StaticSQL; 
   friend class UserTrafficHome;

   #if !defined(AS400)
   static const ClassName _STR_ThisClass;  // Strings used for tracing and debugging
   #endif 

   public: 
     // Database against which the object is used. If LoadAll is true, the object loads 
     //all fields at once. Otherwise, loads the minimum set, and will load the others 
     //on demand
    UserTraffic(DataBase& DB, bool LoadAll=true);

   public: // Schema column names
    static const StringWithOwnership _COL_TNAME           ;
    static const StringWithOwnership _COL_REF_NUM         ;
    static const StringWithOwnership _COL_SHOPPER_REF_NUM ;
    static const StringWithOwnership _COL_SESS_LOGIN_DATE ;
    static const StringWithOwnership _COL_REQ_DATE        ;
    static const StringWithOwnership _COL_REQ_REMOTE_ADDR ;
    static const StringWithOwnership _COL_REQ_CLIENT_METH ;
    static const StringWithOwnership _COL_REQ_SERVER_NAME ;
    static const StringWithOwnership _COL_REQ_SCRIPT      ;
    static const StringWithOwnership _COL_REQ_PATH_INFO   ;
    static const StringWithOwnership _COL_REQ_QUERY_STRING;
    static const StringWithOwnership _COL_REQ_BROWSER     ;
    static const StringWithOwnership _COL_REQ_REFERER_URL ;
    static const StringWithOwnership _COL_REQ_HTTPS       ;
    static const StringWithOwnership _COL_REQ_RESULT      ;
    static const StringWithOwnership _COL_REQ_REDIRECT    ;
    static const StringWithOwnership _COL_REQ_VIEWTASK    ;

   public: // Get functions
    const String& getRefNum       (bool Real=true);
    const String& getShopperRefNum(bool Real=true);
    const String& getLoginDate    (bool Real=true);
    const String& getRequestDate  (bool Real=true);
    const String& getRemoteAddr   (bool Real=true);
    const String& getClientMethod (bool Real=true);
    const String& getServerName   (bool Real=true);
    const String& getScriptName   (bool Real=true);
    const String& getPathInfo     (bool Real=true);
    const String& getQueryString  (bool Real=true);
    const String& getBrowserAgent (bool Real=true);
    const String& getRefererUrl   (bool Real=true);
    const String& getHTTPS        (bool Real=true);
    const String& getResult       (bool Real=true);
    const String& getRedirection  (bool Real=true);
    const String& getViewTask     (bool Real=true);

   public: // Set functions
    void setRefNum       (const String& RefNum       ) { SQL_Schema::setValue(_COL_REF_NUM         ,RefNum       ); }
    void setShopperRefNum(const String& ShopperRefNum) { SQL_Schema::setValue(_COL_SHOPPER_REF_NUM ,ShopperRefNum); }
    void setLoginDate    (const String& LoginDate    ) { SQL_Schema::setValue(_COL_SESS_LOGIN_DATE ,LoginDate    ); }
    void setRequestDate  (const String& RequestDate  ) { SQL_Schema::setValue(_COL_REQ_DATE        ,RequestDate  ); }
    void setRemoteAddr   (const String& RemoteAddr   ) { SQL_Schema::setValue(_COL_REQ_REMOTE_ADDR ,RemoteAddr   ); }
    void setClientMethod (const String& ClientMethod ) { SQL_Schema::setValue(_COL_REQ_CLIENT_METH ,ClientMethod ); }
    void setServerName   (const String& ServerName   ) { SQL_Schema::setValue(_COL_REQ_SERVER_NAME ,ServerName   ); }
    void setScriptName   (const String& ScriptName   ) { SQL_Schema::setValue(_COL_REQ_SCRIPT      ,ScriptName   ); }
    void setPathInfo     (const String& PathInfo     ) { SQL_Schema::setValue(_COL_REQ_PATH_INFO   ,PathInfo     ); }
    void setQueryString  (const String& QueryString  ) { SQL_Schema::setValue(_COL_REQ_QUERY_STRING,QueryString  ); }
    void setBrowserAgent (const String& BrowserAgent ) { SQL_Schema::setValue(_COL_REQ_BROWSER     ,BrowserAgent ); }
    void setRefererUrl   (const String& RefererUrl   ) { SQL_Schema::setValue(_COL_REQ_REFERER_URL ,RefererUrl   ); }
    void setHTTPS        (const String& HTTPS        ) { SQL_Schema::setValue(_COL_REQ_HTTPS       ,HTTPS        ); }
    void setResult       (const String& Result       ) { SQL_Schema::setValue(_COL_REQ_RESULT      ,Result       ); }
    void setRedirection  (const String& Redirection  ) { SQL_Schema::setValue(_COL_REQ_REDIRECT    ,Redirection  ); }
    void setViewTask     (const String& ViewTask     ) { SQL_Schema::setValue(_COL_REQ_VIEWTASK    ,ViewTask     ); }
 };



class __DLL_NCS_OBJ__ UserTrafficHome : public SQL_SchemaMap<UserTraffic>
 { 
   static const ClassName _STR_ThisClass;  // Strings used for tracing and debugging 
   static const FuncName  _STR_Create; 
   static const FuncName  _STR_Lookup; 

   public: 
    UserTrafficHome(DataBase& DB)  : SQL_SchemaMap<UserTraffic>(DB) { }


   public: 
    UserTraffic* Prepare(const NVPHash& NameValuePairs); // create an object, but don't write it to the database
    UserTraffic* Create(const NVPHash& NameValuePairs);
    UserTraffic* Lookup(const String& RefNum, const NVPHash& NameValuePairs);
 };



class __DLL_NCS_OBJ__ UserTrafficNVP : public NC_Void
 { 
   #if !defined(AS400)
   static const ClassName _STR_ThisClass;  // Strings used for tracing and debugging
   #endif
   public: 
    static const StringWithOwnership _NVP_REF_NUM      ;

   public: 
    static bool CreateSchemaNVP(const HttpRequest& Req, NC_Environment& Env,
                                const String& ErrorTask, const String& MerchantRefNum,
                                NVPHash& NameValuePairs
                               );
    static void SetThroughNVP  (const HttpRequest& Req, UserTraffic* R);

 };



#endif

