/*********************************************************************/
/*                                                                   */
/* IBM Confidential                                                  */
/*                                                                   */
/* Net.Commerce Source Materials                                     */
/*                                                                   */
/* (C) Copyright IBM Corp. 1997.                                     */
/*                                                                   */
/* The source code for this program is not published or otherwise    */
/* divested of its trade secrets, irrespective of what has been      */
/* deposited with the U.S. Copyright Office.                         */
/*                                                                   */
//=================================================================================================//
// User implementation file.                                                                    //
//                                                                                                 //
/////////////////////////////////////////////////////////////////////////////////////////////////////


class __DLL_NCS_API__ V2Api : public NC_Void
{

    static const ClassName _STR_ThisClass;

public:
    V2Api(const String &task_name, NCFPTR func_ptr);       
    

    virtual int Compare(const String* rhs) const 
	{
		return _TaskGivenName.Compare(*rhs); 
	};

    NCFPTR getFuncPtr() { return _FuncPtr; }

public:
    static const StringWithOwnership _STR_V2API_APIRFNBR;
    static const StringWithOwnership _STR_V2API_APIMERNBR;
    static const StringWithOwnership _STR_V2API_APIDLLNAME;
    static const StringWithOwnership _STR_V2API_APIFUNCNAME;
    static const StringWithOwnership _STR_V2API_T_NAME;

private:
    String _TaskGivenName;
    NCFPTR _FuncPtr;

};

class __DLL_NCS_API__ ApiFunctionLocator
{

    static const ClassName _STR_ThisClass;
    static const FuncName  _STR_FindApiFunc;
    static const FuncName  _STR_LoadApiDlls;

public:

    ApiFunctionLocator() {};
    static NCFPTR FindApiFunc(const String & task, const String & merchant = _STR_EMPTY_);

private:

    static bool LoadApiDlls();
    static void GenerateTaskGivenName(const String &task, const String &merchant, String &task_given_name)
    {
        task_given_name.Clean();
        task_given_name << task << '_' << merchant;
    }


private:
    static TemplateNC_PHash<V2Api, String> _ApiFuncHash;
    static TemplateNC_PHash<V2Api, String>::Iterator _I;
    static bool _DllsLoaded;
};



class __DLL_NCS_API__ ApiProxy : public NC_Api
 {
   protected:
     static const ClassName _STR_ThisClass;
     static const FuncName  _STR_RunV2Api;
  
   public:
    ApiProxy();    
    virtual ~ApiProxy();      

    void  operator delete( void* p ) { ::delete p; }   

   public:

       
    // Used for backward compatibility with V2 apis; populates Env collection with
    // error parameters (name - value pairs) set by V2 api 
    static void SetApiErrorParms(NC_Environment& Env, struct APIErrorStruct& Error, String& ErrCode, String& ErrField);    

   protected:       
    virtual bool RunV2Api(NCFPTR api_func_ptr,                 // pointer to api function
                                 NC_Environment& Env,          // NC environment
                                 int CallingCommand,           // Calling command id
                                 struct APIErrorStruct &Error, // error structure to be filled in by api in case of failure
                                 struct NVPairMapStruct &NVP) = 0;  // name-value pairs passed the the command calling this api

    // extracts shopper reference number from NC Environment (i.e., User object)
    // if fails throws an exception - error message string
    static void GetShopperRefNum(const NC_Environment& Env, long &ShopperRefNum);
    ///////////////////////////////////////////////////////////////////////////////////
    // Function   : ExtractVarFromEnv
    // Description: 
    //      Extracts variable identified with ENV_ITEM_NAME from NC_Environment 
    //      and converts it to long.
    //      If given variable is not part of the the environment or it can
    //      not be converted to long Val is set to BAD_ENV_VALUE
    // 
    // Input: 
    //          Env - NC environment
    //          ENV_ITEM_NAME - constant string identifying the name of env var
    // Output:
    //          Var  
    ////////////////////////////////////////////////////////////////////////////////////
    static void ExtractVarFromEnv(const NC_Environment &Env, const String &ENV_ITEM_NAME, long &Var);

    ///////////////////////////////////////////////////////////////////////////////////
    // Function   : ExtractVarFromEnv
    // Description: 
    //      Extracts variable identified with ENV_ITEM_NAME from NC_Environment 
    //      and converts it to double.
    //      If given variable is not part of the the environment or it can
    //      not be converted to double Val is set to BAD_ENV_VALUE
    // 
    // Input: 
    //          Env - NC environment
    //          ENV_ITEM_NAME - constant string identifying the name of env var
    // Output:
    //          Var  
    ////////////////////////////////////////////////////////////////////////////////////
    static void ExtractVarFromEnv(const NC_Environment &Env, const String &ENV_ITEM_NAME, double &Var);

    ///////////////////////////////////////////////////////////////////////////////////
    // Function   : ExtractVarFromEnv
    // Description: 
    //      Extracts variable identified with ENV_ITEM_NAME from NC_Environment 
    //      and converts it to (char *).
    //      If given variable is not part of the the environment Val is set to NULL    
    // 
    // Input: 
    //          Env - NC environment
    //          ENV_ITEM_NAME - constant string identifying the name of env var
    // Output:
    //          Var  (char *)
    ////////////////////////////////////////////////////////////////////////////////////
    static void ExtractVarFromEnv(const NC_Environment &Env, const String &ENV_ITEM_NAME, const char*& Var);
                              
    ///////////////////////////////////////////////////////////////////////////////////
    // Function   : UpdateEnvVar
    // Description: 
    //      Sets environment variable identified with ENV_ITEM_NAME with given Value 
    //
    // Input: 
    //          Env - NC environment
    //          ENV_ITEM_NAME - constant string identifying the name of env var
    // Output:
    //          Value  - specifies value to set Env variable
    ///////////////////////////////////////////////////////////////////////////////////
    static bool ApiProxy::UpdateEnvVar(const NC_Environment &Env, const String &ENV_ITEM_NAME, const double & Value);

    ///////////////////////////////////////////////////////////////////////////////////
    // Function   : GetCommandID
    // Description: 
    //      Returns id of the command calling this api. 
    //      Command ids are required by V1/V2 apis.
    // Output:
    //      Command id  in case of success
    //      0           could not find an id matching calling command
    ///////////////////////////////////////////////////////////////////////////////////
    static int GetCommandID();


   public:
    virtual bool Process(const HttpRequest& Req, HttpResponse& Res, NC_Environment& Env);
};
