/****************************************************************************************/
/*                                                                                      */
/* IBM Confidential                                                                     */
/*                                                                                      */
/* Net.Commerce Source Materials                                                        */
/*                                                                                      */
/* (C) Copyright IBM Corp. 1998.                                                        */
/*                                                                                      */
/* The source code for this program is not published or otherwise divested of its trade */
/* secrets, irrespective of what has been deposited with the U.S. Copyright Office.     */
/*                                                                                      */
/****************************************************************************************/

//=======================================================================================
// The order of the includes here is important! Do not move them around.
//=======================================================================================

#include "messages/np_msg.pch"
#include "messages/np_msg_src.h"
#include "api/api.pch"
#include <NetPerceptionsI.h>



//==============================================================================
//==============================================================================
#ifdef __TRACE_NCAPIS__
  typedef TraceYes Trace;
#else
  typedef TraceNo  Trace;
#endif
static Trace trace("NC_APIS ("__FILE__")");
//==============================================================================

#ifdef WIN32
typedef __int64 word64;
typedef unsigned __int64 uword64;
#define LONG_BIT (sizeof(long) * CHAR_BIT)
#define WORD_BIT (sizeof(uword64)/2)
#define strtoull(Str, Ptr, Base) _atoi64(Str)
#endif

#ifdef SOLARIS
typedef long long word64;
typedef unsigned long long uword64;
#endif

#define ull_to_LongLong(U,K) \
    (K).hi = ((U) >> LONG_BIT); (K).low = ((U) & ULONG_MAX);

#define LongLong_to_ull(K) \
      ((((uword64) (K).hi) << LONG_BIT) | ((uword64) (K).low))


//=========================================================
// Net Perception constants
//=========================================================

// These are default values.
static const char *_CSTR_DEFAULT_HOST = "localhost";
static const char *_CSTR_DEFAULT_SERVER = "prod";
static const char *_CSTR_DEFAULT_ROOT = "prod";
static const int _INT_DEFAULT_PORT = 9000;
static unsigned int orbix_diagnostic_level = 0;
static unsigned int orbix_max_connect_retries = 1;


//=========================================================
// Configuration Variables
//=========================================================
static const ConfField _STR_NP_ROOT("NP_ROOT");
static const ConfField _STR_NP_MODE("NP_MODE");
static const ConfField _STR_NP_HOST("NP_HOST");
static const ConfField _STR_NP_SERVER("NP_SERVER");


//=========================================================
// NC Environment Parameter Names
//    must match those used by calling commands
//=========================================================
static const StringWithOwnership
       _PARAM_NAME_RATING_HISTORY_PRODUCT_LIST("RATING_HISTORY_PRODUCT_LIST");
static const StringWithOwnership
       _PARAM_NAME_RATING_HISTORY_RATING_LIST("RATING_HISTORY_RATING_LIST");
static const StringWithOwnership _PARAM_NAME_PERS_RESULT_CODE("PERS_RESULT_CODE");
static const StringWithOwnership _PARAM_NAME_LIKERT_DIMENSION_NAME("LIKERT_DIMENSION_NAME");

//=========================================================
// NC Environment Parameter Values
//=========================================================

// None


class GL_GetRatingHistory :  public NC_Api
{
   static const ClassName _STR_ThisClass;


public:
    GL_GetRatingHistory() 
    {
        Trace::Tracer T(_STR_CONSTRUCTOR, _STR_ThisClass);
    }

    virtual ~GL_GetRatingHistory()
    {
        Trace::Tracer T(_STR_DESTRUCTOR, _STR_ThisClass);
    }

    void  operator delete( void* p ) { ::delete p; }

public:
    virtual bool Process(const HttpRequest& Req, HttpResponse& Res, NC_Environment& Env)
    {
        Trace::Tracer T(_STR_Process, _STR_ThisClass);

        //===========================================================
        // Get Overridable function parameters from the environment.
        //===========================================================

        // Result code
        String localResultCode;

        String *envResultCode = (String *) Env.Seek(_PARAM_NAME_PERS_RESULT_CODE);
        if (envResultCode == NULL)
        {
            envResultCode = &localResultCode;
        }
        else
        {
            envResultCode->Clean();
            envResultCode->Resize(64);
        }

    
        // Merchant RefNum 

        String* envMerchantRefNum = (String*) Env.Seek(_PARAM_NAME_MERCHANT_REF_NUM);
        if (envMerchantRefNum == NULL)
        {
            error << indent;
            error.nls(&_API_CANT_FIND_IN_ENV, _PARAM_NAME_MERCHANT_REF_NUM.c_str()) << endl;
            *envResultCode = "error";
            return false;
        }


        // Rating History Product list

        TemplateNC_PList<String, String>* envHistoryProductList = 
         (TemplateNC_PList<String, String>*) Env.Seek(_PARAM_NAME_RATING_HISTORY_PRODUCT_LIST);
        if (envHistoryProductList == NULL)
        {
            error << indent;
            error.nls(&_API_CANT_FIND_IN_ENV, _PARAM_NAME_RATING_HISTORY_PRODUCT_LIST.c_str())
             << endl;
            *envResultCode = "error";
            return false;
        }


        // Rating History Rating list

        TemplateNC_PList<String, String>* envHistoryRatingList = 
         (TemplateNC_PList<String, String>*) Env.Seek(_PARAM_NAME_RATING_HISTORY_RATING_LIST);
        if (envHistoryRatingList == NULL)
        {
            error << indent; error.nls(&_API_CANT_FIND_IN_ENV, _PARAM_NAME_RATING_HISTORY_RATING_LIST.c_str()) << endl;
            *envResultCode = "error";
            return false;
        }


        // Get the current shopper 

        User* envUser = (User*) Env.Seek(NC_Environment::_VAR_Shopper);
        if (envUser == NULL)
        {
            error << indent;
            error.nls(&_ERR_CANT_LOAD_SHOPPER) << endl;
            *envResultCode = "error";
            return false;
        }
        String shopperRefNum = envUser->getValue(User::_COL_REF_NUM);



        // Likert Dimension to be used
        String* envLikertDimensionName = (String*) Env.Seek(_PARAM_NAME_LIKERT_DIMENSION_NAME);
        if (envLikertDimensionName== NULL)
        {
            error << indent; 
            error.nls(&_API_CANT_FIND_IN_ENV, _PARAM_NAME_LIKERT_DIMENSION_NAME.c_str()) 
             << endl;
            *envResultCode = "error";
            return false;
        }
	

		//==============================================================
        // Read NetPerception Configuration variables given in Net.Commerce
		// configuration files
        //==============================================================
        String npHOST = Misc::CheckConfigurationVariable(_STR_NP_HOST, true);
        String npROOT = Misc::CheckConfigurationVariable(_STR_NP_ROOT, true);
        String npServer = Misc::CheckConfigurationVariable(_STR_NP_SERVER, true);

		if (npServer.IsEmpty()) npServer = _CSTR_DEFAULT_SERVER;
		if (npROOT.IsEmpty()) npROOT = _CSTR_DEFAULT_ROOT;
		if (npHOST.IsEmpty()) npHOST = _CSTR_DEFAULT_HOST;

        short result_code = 0;

        //==============================================================
        // Set NetPerception variables
        //==============================================================
        NetPerceptionsI::Root_var rootVar;
		NetPerceptionsI::RatingParticipantHandle rater;
        NetPerceptionsI::RatingParticipantHandle ratee;

        //==============================================================
        // NetPerceptions initialization code
        //==============================================================

		// Initialize ORB	
		int argc=0;
		char *t = new char[20];
		strcpy(t,"gl_get_rating_history");
	    CORBA::ORB_ptr theOrbPtr = CORBA::ORB_init(argc,&t, "Orbix");

        if (CORBA::is_nil(theOrbPtr)) {
            debug << indent;
			status.nls(&_NP_ERR_NO_ORB) << endl;
	        CORBA::release(theOrbPtr);
            *envResultCode = "pers_disabled";
            return true;
        }

        theOrbPtr->setDiagnostics(orbix_diagnostic_level);
        theOrbPtr->maxConnectRetries(orbix_max_connect_retries);

		String name_server;
		name_server = npROOT << ":" << npServer;
        try {
            rootVar = NetPerceptionsI::Root::_bind(name_server.c_str(), npHOST.c_str());
        }
        catch (...) {
            debug << indent;
			status.nls(&_NP_ERR_BIND, npROOT.c_str(), name_server.c_str(), npHOST.c_str()) << endl;
            *envResultCode = "pers_disabled";
            return true;
        }


		// locate container dimension
        NetPerceptionsI::ContainerDimension_var container_dimensionVar;
		try {
            container_dimensionVar =
                rootVar->locate_container_dimension(envLikertDimensionName->c_str());
        }
        catch (...) {
           debug  <<indent;
  	       status.nls(&_NP_ERR_LOCATE_LIKERT_CONTAINER,envLikertDimensionName->c_str()) << endl;
           *envResultCode = "pers_error";
		   return true;
        }
     

		// Get the rater and ratee domain's
        try {
            ratee.domain = container_dimensionVar->ratee_domain()->the_key();
            rater.domain = container_dimensionVar->rater_domain()->the_key();
        }
        catch (...) {
            debug << indent;
			status.nls(&_NP_ERR_SET_DOMAIN_KEY) << endl;
            *envResultCode =  "pers_error";
			return true;
        }


        const char *kcsMerchantRefNum = envMerchantRefNum->c_str();
        const char *kcsShopperRefNum = shopperRefNum.c_str();

        bool bGLTransactionOK = true;      // Assume failure for the moment




       //===============================================================
       // Net Perception transaction begins
       //===============================================================

	     // update ratee and rater variables
	 	 char *tmp;
		 uword64 _key = strtoull((envUser->getRefNum()).c_str(), &tmp, 0); ;
         ull_to_LongLong(_key, rater.key);
    
        //=======================================================================
        // Get the items rated by the user 
        //=======================================================================

		// Setup 5 buckets to sort the ratings into.  Currently there are only
        // 5 buckets.
        
        TemplateNC_PList<String, String> lvRatingBucket[5];
        int ratingNum;

        NetPerceptionsI::RatingParticipantHandleList_var rateesVar =
                    new NetPerceptionsI::RatingParticipantHandleList;
			              
	    try {
		    NetPerceptionsI::Dimension::RatingList_var ratingsVar = 
			 container_dimensionVar->rater_ratings(rater, rateesVar);
		    for (CORBA::ULong i = 0; i < ratingsVar->length(); i++) {

				long lt = (long) LongLong_to_ull(ratingsVar[i].the_ratee.key);

				debug << indent << "Net Perceptions: rating value for product " << 
					lt << " " << (long) ratingsVar[i].the_rating << endl;
				 
				ratingNum = ratingsVar[i].the_rating;

                String prod; prod << lt;
                // Let's make sure that rating is within our limits
                if ((ratingNum >= 1) && (ratingNum <=5))
                {
                    lvRatingBucket[ratingNum-1].Append(new String(prod));
                }
                else
                {
                    debug << indent << "NetPerceptions: Rating fetched does not fit into bucket" << endl;
                }
			} 
		}
        catch (...) {
            debug << indent;
		    status.nls(&_NP_ERR_SET_DOMAIN_KEY,(envUser->getRefNum()).c_str()) << endl;
            *envResultCode =  "pers_error";
			return true;
		}


        //=======================================================================
        // Build the return list from the rating buckets
        //=======================================================================

        String* thisElement;
        int listx;               // var in for loop
        TemplateNC_PList<String, String>::Iterator lvRL;

        for (listx = 5; listx >= 1; listx--)
        {
            lvRL = lvRatingBucket[listx-1].getIterator();
            lvRL.Begin();
            String listxStr;
            listxStr << listx;
            for (/* empty */ ; (thisElement = lvRL.getElement()) != NULL; ++lvRL)
            {
                envHistoryProductList->Append(new String(*thisElement));
                envHistoryRatingList->Append(new String(listxStr));
                debug << indent << "Appending rating <" << thisElement << ", " << listx << ">\n";
            }  // for lvRL
            lvRatingBucket[listx-1].Clean(true);
        }  // for listx

        //===============================================================
        // If we reach here, then the transaction is OK
        //===============================================================

        CORBA::release(theOrbPtr);
		*envResultCode="success";
        return bGLTransactionOK;
    }  // Process()
};

const ClassName GL_GetRatingHistory::_STR_ThisClass("GL_GetRatingHistory");

static bool X = NC_ApiManager::GetUniqueInstance().RegisterApi("IBM",
                                                               "NC",
                                                               "GL_GetRatingHistory",
                                                               1.0,
                                                               new GL_GetRatingHistory );

