/****************************************************************************************/
/*                                                                                      */
/* IBM Confidential                                                                     */
/*                                                                                      */
/* Net.Commerce Source Materials                                                        */
/*                                                                                      */
/* (C) Copyright IBM Corp. 1998.                                                        */
/*                                                                                      */
/* The source code for this program is not published or otherwise divested of its trade */
/* secrets, irrespective of what has been deposited with the U.S. Copyright Office.     */
/*                                                                                      */
/****************************************************************************************/


//=======================================================================================
// The order of the includes here is important! Do not move them around.
//=======================================================================================

#include "messages/np_msg.pch"
#include "messages/np_msg_src.h"
#include "api/api.pch"
#include <NetPerceptionsI.h>

//==============================================================================
//==============================================================================
#ifdef __TRACE_NCAPIS__
  typedef TraceYes Trace;
#else
  typedef TraceNo  Trace;
#endif
static Trace trace("NC_APIS ("__FILE__")");
//==============================================================================

#ifdef WIN32 // needed for ORBIX
#define USE_INIT
static int bootInit;
#endif

#ifdef WIN32
extern "C" char *optarg;
extern "C" int getopt(int argc, char *argv[], char *opstring);
typedef __int64 word64;
typedef unsigned __int64 uword64;
#define LONG_BIT (sizeof(long) * CHAR_BIT)
#define WORD_BIT (sizeof(uword64)/2)
#define strtoull(Str, Ptr, Base) _atoi64(Str)
#endif

#ifdef SOLARIS
typedef long long word64;
typedef unsigned long long uword64;
#endif

#define ull_to_LongLong(U,K) \
    (K).hi = ((U) >> LONG_BIT); (K).low = ((U) & ULONG_MAX);

#define LongLong_to_ull(K) \
      ((((uword64) (K).hi) << LONG_BIT) | ((uword64) (K).low))


//=========================================================
// Net Perception constants
//=========================================================

// These are default values.
static const char *_CSTR_DEFAULT_HOST = "localhost";
static const char *_CSTR_DEFAULT_SERVER = "prod";
static const char *_CSTR_DEFAULT_ROOT = "prod";
static const int _INT_DEFAULT_PORT = 9000;
static unsigned int orbix_diagnostic_level = 0;
static unsigned int orbix_max_connect_retries = 1;


//=========================================================
// Configuration Variables
//=========================================================
static const ConfField _STR_NP_ROOT("NP_ROOT");
static const ConfField _STR_NP_MODE("NP_MODE");
static const ConfField _STR_NP_HOST("NP_HOST");
static const ConfField _STR_NP_SERVER("NP_SERVER");


//=========================================================
// NC Environment Parameter Names
//    must match those used by calling commands
//=========================================================
static const StringWithOwnership
       _PARAM_NAME_RATING_HISTORY_PRODUCT_LIST("RATING_HISTORY_PRODUCT_LIST");
static const StringWithOwnership
       _PARAM_NAME_RATING_HISTORY_RATING_LIST("RATING_HISTORY_RATING_LIST");
static const StringWithOwnership _PARAM_NAME_PERS_RESULT_CODE("PERS_RESULT_CODE");
static const StringWithOwnership _PARAM_NAME_LIKERT_DIMENSION_NAME("LIKERT_DIMENSION_NAME");
static const StringWithOwnership _PARAM_NAME_INTEREST_DIMENSION_NAME("INTEREST_DIMENSION_NAME");
static const StringWithOwnership _PARAM_NAME_FROM_RANK("FROM_RANK");
static const StringWithOwnership _PARAM_NAME_TO_RANK("TO_RANK");
static const StringWithOwnership _PARAM_NAME_LIKERT_STRATEGY("LIKERT_PREDICTION_STRATEGY");
static const StringWithOwnership _PARAM_NAME_INTEREST_STRATEGY("INTEREST_PREDICTION_STRATEGY");

static const ConfField _CONF_FROM_RANK ("FROM_RANK");
static const ConfField _CONF_TO_RANK ("TO_RANK");

static const long nDefaultFromRank = 1;
static const long nDefaultToRank = 10;




class GL_GetRecProd : public NC_Api
{
    static const ClassName _STR_ThisClass;
   
public:
    GL_GetRecProd()
    {
        Trace::Tracer T(_STR_CONSTRUCTOR, _STR_ThisClass);
    }

    virtual ~GL_GetRecProd()
    {
        Trace::Tracer T(_STR_DESTRUCTOR, _STR_ThisClass);
    }

    void  operator delete( void* p ) { ::delete p; }

public:
    virtual bool Process(const HttpRequest& Req, HttpResponse& Res, NC_Environment& Env)
    {
        // Result code
        String localResultCode;

        String *envResultCode = (String *) Env.Seek(_PARAM_NAME_PERS_RESULT_CODE);
        if (envResultCode == NULL)
        {
            envResultCode = &localResultCode;
        }
        else
        {
            envResultCode->Clean();
            envResultCode->Resize(64);
        }

        //==========================================================
        // Get Overridable function parameters from the environment.
        //==========================================================

        // Merchant Reference Number

        String* envMerchantRefNum = (String*) Env.Seek(_PARAM_NAME_MERCHANT_REF_NUM);
        if (envMerchantRefNum == NULL)
        {
            error << indent;
            error.nls(&_API_CANT_FIND_IN_ENV, _PARAM_NAME_MERCHANT_REF_NUM.c_str()) << endl;
            *envResultCode = "error";
            return false;
        }


        // Recommended products list

        TemplateNC_PList<String, String>* envRecProdList =
        (TemplateNC_PList<String, String>*) Env.Seek(_PARAM_NAME_PRODUCT_REF_NUM_LIST);
        if(envRecProdList == NULL)
        {
            error << indent;
            error.nls(&_API_CANT_FIND_IN_ENV, _PARAM_NAME_PRODUCT_REF_NUM_LIST.c_str()) << endl;
            *envResultCode = "error";
            return false;
        }
        envRecProdList->Clean(true);


        // 'From rank' and 'to rank'

        String fromRank;
        long nFromRank;
        String toRank;
        long nToRank;

        fromRank.Clean();
        String* envFromRank = (String*) Env.Seek(_PARAM_NAME_FROM_RANK);
        // I rely on short-circuit evaluation here; don't move things around.
        if(envFromRank == NULL || envFromRank->IsEmpty())   
        {
            // Check for a configuration variable
            String cvFromRank = Misc::CheckConfigurationVariable(_CONF_FROM_RANK, true);
            if(!cvFromRank.IsEmpty() && cvFromRank.IsLong())
            {
                fromRank << cvFromRank;
            }
            else
            {
                fromRank << nDefaultFromRank;
            }
        }
        else
        {
            fromRank << *envFromRank;
        }

        toRank.Clean();
        // I rely on short-circuit evaluation here; don't move things around.
        String* envToRank = (String*) Env.Seek(_PARAM_NAME_TO_RANK);
        if(envToRank == NULL || envToRank->IsEmpty())
        {
            // Check for a configuration variable
            String cvToRank = Misc::CheckConfigurationVariable(_CONF_TO_RANK, true);
            if(!cvToRank.IsEmpty() && cvToRank.IsLong())
            {
                toRank << cvToRank;
            }
            else
            {
                toRank << nDefaultToRank;
            }
        }
        else
        {
            toRank << *envToRank;
        }

        debug << indent << "Got from rank [" << fromRank <<"] and to rank [" << toRank << "]\n";
        fromRank.getVal(nFromRank);
        toRank.getVal(nToRank);

        if(nFromRank < 1)
        {
            error << indent;
            error.nls(&_ERR_CMD_INVALID_PARAM, _PARAM_NAME_FROM_RANK.c_str()) << endl;
            *envResultCode = "error";
            return false;
        }
        
        if(nFromRank > nToRank)
        {
            error << indent;
            error << "GROUPLENS: 'from_rank' cannot be greater than 'to_rank'\n";
            *envResultCode = "error";
            return false;
        }


        // Get the current shopper

        String shopperRefNum;

        User* envUser = (User*) Env.Seek(NC_Environment::_VAR_Shopper);
        if (envUser == NULL)
        {
            error << indent;
            error.nls(&_ERR_CANT_LOAD_SHOPPER) << endl;
            *envResultCode = "error";
            return false;
        }
        shopperRefNum = envUser->getValue(User::_COL_REF_NUM);
		

        // Likert Dimension to be used
        String* envLikertDimensionName = (String*) Env.Seek(_PARAM_NAME_LIKERT_DIMENSION_NAME);
        if (envLikertDimensionName== NULL)
        {
            error << indent; 
            error.nls(&_API_CANT_FIND_IN_ENV, _PARAM_NAME_LIKERT_DIMENSION_NAME.c_str()) 
             << endl;
            *envResultCode = "error";
            return false;
        }
	
        // Interest Dimension to be used
        String* envInterestDimensionName = (String*) Env.Seek(_PARAM_NAME_INTEREST_DIMENSION_NAME);
        if (envInterestDimensionName== NULL)
        {
            error << indent; 
            error.nls(&_API_CANT_FIND_IN_ENV, _PARAM_NAME_INTEREST_DIMENSION_NAME.c_str()) 
             << endl;
            *envResultCode = "error";
            return false;
        }

		// Likert strategy used
        String* envLikertStrategy = (String*) Env.Seek(_PARAM_NAME_LIKERT_STRATEGY);
        if (envLikertStrategy== NULL)
        {
            error << indent; 
            error.nls(&_API_CANT_FIND_IN_ENV, _PARAM_NAME_LIKERT_STRATEGY.c_str()) 
             << endl;
            *envResultCode = "error";
            return false;
        }

		// Interest strategy used
        String* envInterestStrategy = (String*) Env.Seek(_PARAM_NAME_INTEREST_STRATEGY);
        if (envInterestStrategy== NULL)
        {
            error << indent; 
            error.nls(&_API_CANT_FIND_IN_ENV, _PARAM_NAME_INTEREST_STRATEGY.c_str()) 
             << endl;
            *envResultCode = "error";
            return false;
        }

		//==============================================================
        // Read NetPerception Configuration variables given in Net.Commerce
		// configuration files
        //==============================================================
        String npHOST = Misc::CheckConfigurationVariable(_STR_NP_HOST, true);
        String npROOT = Misc::CheckConfigurationVariable(_STR_NP_ROOT, true);
        String npServer = Misc::CheckConfigurationVariable(_STR_NP_SERVER, true);

		if (npServer.IsEmpty()) npServer = _CSTR_DEFAULT_SERVER;
		if (npROOT.IsEmpty()) npROOT = _CSTR_DEFAULT_ROOT;
		if (npHOST.IsEmpty()) npHOST = _CSTR_DEFAULT_HOST;

		debug << " NP HOST is : " << npHOST << endl;
		debug << " NP ROOT is : " << npROOT << endl;
		debug << " NP Server  is : " << npServer << endl;

        short result_code = 0;

        //==============================================================
        // Set NetPerception variables
        //==============================================================
        NetPerceptionsI::Root_var rootVar;
        NetPerceptionsI::RatingParticipantHandle subject;

 	    // update subject and object variables
	    char *tmp;
	    uword64 _key = strtoull((envUser->getRefNum()).c_str(), &tmp, 0); ;
        ull_to_LongLong(_key, subject.key);

        //==============================================================
        // NetPerceptions initialization code
        //==============================================================

		// Initialize ORB	
		int argc=0;
		char *t = new char[20];
		strcpy(t,"gl_get_rec_prod");
	    CORBA::ORB_ptr theOrbPtr = CORBA::ORB_init(argc,&t, "Orbix");

        if (CORBA::is_nil(theOrbPtr)) {
            debug << indent;
			status.nls(&_NP_ERR_NO_ORB) << endl;
	        CORBA::release(theOrbPtr);
            *envResultCode = "pers_disabled";
            return true;
        }

        theOrbPtr->setDiagnostics(orbix_diagnostic_level);
        theOrbPtr->maxConnectRetries(orbix_max_connect_retries);

		String name_server;
		name_server = npROOT << ":" << npServer;
        try {
            rootVar = NetPerceptionsI::Root::_bind(name_server.c_str(), npHOST.c_str());
        }
        catch (...) {
            debug << indent;
			status.nls(&_NP_ERR_BIND, npROOT.c_str(), name_server.c_str(), npHOST.c_str()) << endl;
	        CORBA::release(theOrbPtr);
            *envResultCode = "pers_disabled";
            return true;
        }


		// locate prediction starategies
        NetPerceptionsI::LikertPredictionStrategy_var likert_strategyVar;
		try {
            likert_strategyVar =
                rootVar->locate_likert_prediction_strategy(envLikertStrategy->c_str());
        }
        catch (...) {
            debug  <<indent;
			status.nls(&_NP_ERR_LOCATE_LIKERT_PREDICTION,envLikertStrategy->c_str()) << endl;
	        CORBA::release(theOrbPtr);
            *envResultCode = "pers_error";
            return true;
        }

		NetPerceptionsI::InterestPredictionStrategy_var interest_strategyVar;
		try {
            interest_strategyVar =
                rootVar->locate_interest_prediction_strategy(envInterestStrategy->c_str());
        }
        catch (...) {
            debug  <<indent;
			status.nls(&_NP_ERR_LOCATE_INTEREST_PREDICTION,envInterestStrategy->c_str()) << endl;
 	        CORBA::release(theOrbPtr);
            *envResultCode = "pers_error";
            return true;
        }
     

       //===============================================================
       // Net Perception transaction begins
       //===============================================================



        //===================================================
        // Set up for Net Perception call
        //===================================================

        const char *kcsMerchantRefNum = envMerchantRefNum->c_str();
        const char *kcsShopperRefNum = shopperRefNum.c_str();
        bool bGLTransactionOK = true;
     
		*envResultCode = "success";  // Assume success
		long object_count;
		toRank.getVal(object_count);

		//int object_count=10; 

        debug <<"Merchant Ref num" << kcsMerchantRefNum << ", Shopper: " << kcsShopperRefNum << endl;
         
        envRecProdList->Clean(true);
		
        // Get the prediction
        try {
			// Get the subject prediction stratergies
			// First check if likert_prediction_strategy has any predictions
			// Else check if interest prediction strategy has any

	           NetPerceptionsI::ContainerDimension_var likert_container_dimensionVar =
                likert_strategyVar->ratings_container_dimension();

			   try {
                   subject.domain = likert_container_dimensionVar->rater_domain()->the_key();
			   }
               catch (...) {
                  debug << indent;
				  status.nls(&_NP_ERR_SET_DOMAIN_KEY) << endl;
			   }

               NetPerceptionsI::RatingParticipantHandleList_var empty_list =
                 new NetPerceptionsI::RatingParticipantHandleList;

               NetPerceptionsI::PredictionResult_var resultVar =
                  likert_strategyVar->get_prediction(subject,
                                             empty_list,
                                             object_count,
                                             empty_list);
               if (CORBA::is_nil(resultVar)) {
                  debug << indent;
				  status.nls(&_NP_DBG_NO_RECOMMENDATIONS) << endl;
  		          CORBA::release(theOrbPtr);
				  *envResultCode = "pers_error";
                  return true;
			   }

               NetPerceptionsI::PredictionResult::PredictionResults_var resultsVar =
                    resultVar->the_prediction_results();
 		
               //
               // Build a list of recommendations
               //

               for (CORBA::ULong j = 0; j < resultsVar->the_predictions.length(); j++) 
			   {
				  String prod; 
			      prod << (long) LongLong_to_ull(resultsVar->the_predictions[j].object_handle.key);
                  envRecProdList->Append(new String(prod));
			   } 

   	           NetPerceptionsI::ContainerDimension_var interest_container_dimensionVar =
                interest_strategyVar->ratings_container_dimension();

			   try {
                   subject.domain = interest_container_dimensionVar->rater_domain()->the_key();
			   }
               catch (...) {
                  debug << indent;
				  status.nls(&_NP_ERR_SET_DOMAIN_KEY) << endl;
			   }

               NetPerceptionsI::PredictionResult_var resultVar2 =
                  interest_strategyVar->get_prediction(subject,
                                             empty_list,
                                             object_count,
                                             empty_list);
               if (CORBA::is_nil(resultVar2)) {
                  debug << indent;
				  status.nls(&_NP_DBG_NO_RECOMMENDATIONS) << endl;
  		          CORBA::release(theOrbPtr);
	              *envResultCode = "pers_error";
                  return true;
			   }

               NetPerceptionsI::PredictionResult::PredictionResults_var resultsVar2 =
                    resultVar2->the_prediction_results();
 		
               //
               // Build a list from the environment
               //

               for (CORBA::ULong h = 0; h < resultsVar2->the_predictions.length(); h++) 
			   {        
				   long l = (long) LongLong_to_ull(resultsVar2->the_predictions[h].object_handle.key);
				   bool donot_append=false;
				   for (CORBA::ULong k = 0; k < resultsVar->the_predictions.length(); k++) 
				   {
					   if (l == (long) LongLong_to_ull(resultsVar->the_predictions[k].object_handle.key)) {
					     donot_append=true;
					     break;
					   }
				   }
				   if (!donot_append) {
 				      String prod; 
			          prod << l ;
                      envRecProdList->Append(new String(prod));
				   }
			   } 

        }
		catch (const NetPerceptionsI::BadParameter& e) {
			*envResultCode="pers_error";
            debug << indent;
			status.nls(&_NP_ERR_PRE_BAD_PARAMS) << endl;
		}
        catch (const NetPerceptionsI::DomainMismatch& e){
			*envResultCode="pers_error";
            debug << indent;
			status.nls(&_NP_ERR_PRE_DOMAIN_MISMATCH) << endl;
		}
        catch (const NetPerceptionsI::ServerError& e){
			*envResultCode="pers_error";
            debug << indent;
			status.nls(&_NP_ERR_PRE_SERVER_ERROR) << endl;
		}
        catch (...) {
            debug << indent;
			status.nls(&_NP_ERR_PRE_UNKWN_ERROR) << endl;
			*envResultCode="pers_error";
	        CORBA::release(theOrbPtr);
            return true;
        }

        //===============================================================
        // If we reach here, then the transaction is OK
        //===============================================================
        CORBA::release(theOrbPtr);
        return bGLTransactionOK;
    }
};

const ClassName GL_GetRecProd::_STR_ThisClass("GL_GetRecProd");

static bool X1 = NC_ApiManager::GetUniqueInstance().RegisterApi( "IBM",
                                                                 "NC",
                                                                 "GL_GetRecProd",
                                                                 1.0,
                                                                 new GL_GetRecProd );

