/****************************************************************************************/
/*                                                                                      */
/* IBM Confidential                                                                     */
/*                                                                                      */
/* Net.Commerce Source Materials                                                        */
/*                                                                                      */
/* (C) Copyright IBM Corp. 1998.                                                        */
/*                                                                                      */
/* The source code for this program is not published or otherwise divested of its trade */
/* secrets, irrespective of what has been deposited with the U.S. Copyright Office.     */
/*                                                                                      */
/****************************************************************************************/

//=======================================================================================
// The order of the includes here is important! Do not move them around.
//=======================================================================================

#include "commands/np_configuration.h"
#include "messages/np_msg.pch"
#include "messages/np_msg_src.h"
#include "api/api.pch"
#include <NetPerceptionsI.h>


//=================================================================================================
#ifdef __TRACE_NCAPIS__
  typedef TraceYes Trace;
#else
  typedef TraceNo  Trace;
#endif
static Trace trace("NC_APIS ("__FILE__")");
//=================================================================================================

#ifdef WIN32
typedef __int64 word64;
typedef unsigned __int64 uword64;
#define LONG_BIT (sizeof(long) * CHAR_BIT)
#define WORD_BIT (sizeof(uword64)/2)
#define strtoull(Str, Ptr, Base) _atoi64(Str)
#endif

#ifdef SOLARIS
typedef long long word64;
typedef unsigned long long uword64;
#endif

#define ull_to_LongLong(U,K) \
    (K).hi = ((U) >> LONG_BIT); (K).low = ((U) & ULONG_MAX);

#define LongLong_to_ull(K) \
      ((((uword64) (K).hi) << LONG_BIT) | ((uword64) (K).low))

//=========================================================
// Net Perception constants
//=========================================================

// These are default values.
static const char *_CSTR_DEFAULT_HOST = "localhost";
static const char *_CSTR_DEFAULT_SERVER = "prod";
static const char *_CSTR_DEFAULT_ROOT = "prod";
static const int _INT_DEFAULT_PORT = 9000;
static unsigned int orbix_diagnostic_level = 0;
static unsigned int orbix_max_connect_retries = 1;


//=========================================================
// Configuration Variables
//=========================================================
static const ConfField _STR_NP_ROOT("NP_ROOT");
static const ConfField _STR_NP_MODE("NP_MODE");
static const ConfField _STR_NP_HOST("NP_HOST");
static const ConfField _STR_NP_SERVER("NP_SERVER");

//=========================================================
// NC Environment Parameter Names
//     must match those used by calling commands
//=========================================================
static const StringWithOwnership _PARAM_NAME_BEHAVIOR_LIST("BEHAVIOR_LIST");
static const StringWithOwnership _PARAM_NAME_PERS_RESULT_CODE("PERS_RESULT_CODE");
static const StringWithOwnership _PARAM_NAME_LIKERT_DIMENSION_NAME("LIKERT_DIMENSION_NAME");
static const StringWithOwnership _PARAM_NAME_INTEREST_DIMENSION_NAME("INTEREST_DIMENSION_NAME");
static const StringWithOwnership _PARAM_NAME_LIKERT_RATING_STRATEGY("LIKERT_RATING_STRATEGY");
static const StringWithOwnership _PARAM_NAME_INTEREST_RATING_STRATEGY("INTEREST_RATING_STRATEGY");

static String _DEFAULT_LIKERT_DIMENSION_NAME = LIKERT_DIMENSION_NAME;
static String _DEFAULT_INTEREST_DIMENSION_NAME = INTEREST_DIMENSION_NAME;
static String _DEFAULT_INTEREST_RATING_STRATEGY = INTEREST_RATING_STRATEGY;
static String _DEFAULT_LIKERT_RATING_STRATEGY = LIKERT_RATING_STRATEGY;

//=========================================================
// NC Environment Parameter Values
//=========================================================
static const StringWithOwnership _REMOVE_RATING("X_REMOVE_RATING");


class GL_ProfileUpdProd : public NC_Api
{
private:
    static ClassName _STR_ThisClass;

    bool TransactionOK;
public:
    GL_ProfileUpdProd()
    {
        Trace::Tracer T(_STR_CONSTRUCTOR, _STR_ThisClass);
    }

    virtual ~GL_ProfileUpdProd()
    {
        Trace::Tracer T(_STR_DESTRUCTOR, _STR_ThisClass);
    }

    void  operator delete( void* p ) { ::delete p; }


public:
    virtual bool Process(const HttpRequest& Req, HttpResponse& Res, NC_Environment& Env)
    {
        Trace::Tracer T(_STR_Process, _STR_ThisClass);
     


        //==========================================================
        // Get Overridable function parameters from the environment
        //==========================================================

        // Result code
        String localResultCode;

        String *envResultCode = (String *) Env.Seek(_PARAM_NAME_PERS_RESULT_CODE);
        if (envResultCode == NULL)
        {
            envResultCode = &localResultCode;
        }
        else
        {
            envResultCode->Clean();
            envResultCode->Resize(64);
        }
 

        // Product reference number list

        TemplateNC_PList<String, String>* envProductRefNumList = 
         (TemplateNC_PList<String, String>*) Env.Seek(_PARAM_NAME_PRODUCT_REF_NUM_LIST);
        if (envProductRefNumList == NULL)
        {
            error << indent; 
            error.nls(&_API_CANT_FIND_IN_ENV, _PARAM_NAME_PRODUCT_REF_NUM_LIST.c_str()) 
             << endl;
            *envResultCode = "error";
            return false;
        }

        // Merchant RefNum

        String* envMerchantRefNum = (String*) Env.Seek(_PARAM_NAME_MERCHANT_REF_NUM);
        if (envMerchantRefNum == NULL)
        {
            error << indent; 
            error.nls(&_API_CANT_FIND_IN_ENV, _PARAM_NAME_MERCHANT_REF_NUM.c_str()) << endl;
            *envResultCode = "error";
            return false;
        }

		String temp; temp.Clean();

        // Likert Dimension to be used
        String* envLikertDimensionName = (String*) Env.Seek(_PARAM_NAME_LIKERT_DIMENSION_NAME);
        if (envLikertDimensionName == NULL)
        {
			envLikertDimensionName = new String();
            temp.Clean(); temp << _DEFAULT_LIKERT_DIMENSION_NAME << envMerchantRefNum->c_str() ; 
			StringIterator i = temp.getIterator();
            envLikertDimensionName->Copy(i, temp.c_str(), temp.Len());
        }

        // Likert Rating Strategy Used 
        String* envLikertRatingStrategy = (String*) Env.Seek(_PARAM_NAME_LIKERT_RATING_STRATEGY);
        if (envLikertRatingStrategy== NULL)
        {
			envLikertRatingStrategy = new String();
            temp.Clean(); temp << _DEFAULT_LIKERT_RATING_STRATEGY << envMerchantRefNum->c_str() ; 
			StringIterator i = temp.getIterator();
            envLikertRatingStrategy->Copy(i, temp.c_str(), temp.Len());
		}

        // Interest Dimension to be used
        String* envInterestDimensionName = (String*) Env.Seek(_PARAM_NAME_INTEREST_DIMENSION_NAME);
        if (envInterestDimensionName == NULL)
        {
			envInterestDimensionName = new String();
            temp.Clean(); temp << _DEFAULT_INTEREST_DIMENSION_NAME << envMerchantRefNum->c_str() ; 
			StringIterator i = temp.getIterator();
            envInterestDimensionName->Copy(i, temp.c_str(), temp.Len());
        }

        // Likert Rating Strategy Used 
        String* envInterestRatingStrategy = (String*) Env.Seek(_PARAM_NAME_INTEREST_RATING_STRATEGY);
        if (envInterestRatingStrategy== NULL)
        {
 			envInterestRatingStrategy = new String();
            temp.Clean(); temp << _DEFAULT_INTEREST_RATING_STRATEGY << envMerchantRefNum->c_str(); 
			StringIterator i = temp.getIterator();
            envInterestRatingStrategy->Copy(i, temp.c_str(), temp.Len());
        }

        // Behavior List, or Behavior    
        String* envBehaviorName = (String*) Env.Seek(_PARAM_NAME_BEHAVIOR);
        TemplateNC_PList<String, String>* envBehaviorList = 
         (TemplateNC_PList<String, String>*) Env.Seek(_PARAM_NAME_BEHAVIOR_LIST);
        TemplateNC_PList<String, String> theBehaviorList(false);

        if (envBehaviorList == NULL && envBehaviorName == NULL)
        {
            error << indent; error.nls(&_API_CANT_FIND_IN_ENV, 
                                       _PARAM_NAME_BEHAVIOR_LIST.c_str()) << endl;
            error << indent; error.nls(&_API_CANT_FIND_IN_ENV, 
                                       _PARAM_NAME_BEHAVIOR.c_str()) << endl;
            *envResultCode = "error";
            return false;
        }
        else if(envBehaviorName != NULL)
        {
            long i = 0;
            for(i = 0; i < envProductRefNumList->Count(); i++)
            {
                theBehaviorList.Append(envBehaviorName);
            }
        }
        else if(envBehaviorList != NULL)
        {
            TemplateNC_PList<String, String>::Iterator I = envBehaviorList->getIterator();
            String* thisElement;
            for(I.Begin(); (thisElement = I.getElement()) != NULL; I.getNextElement())
            {
                theBehaviorList.Append(thisElement);
            }
        }

        // Get the current shopper 

        User* lvUser = (User*) Env.Seek(NC_Environment::_VAR_Shopper);
        if (lvUser == NULL)
        {
            error << indent; error.nls(&_ERR_CANT_LOAD_SHOPPER) << endl;
            *envResultCode = "error";
            return false;
        }
        String lvShopperRefNum = lvUser->getValue(User::_COL_REF_NUM);

        //==============================================================
        // Read NetPerception Configuration variables given in Net.Commerce
		// configuration files
        //==============================================================
        String npHOST = Misc::CheckConfigurationVariable(_STR_NP_HOST, true);
        String npROOT = Misc::CheckConfigurationVariable(_STR_NP_ROOT, true);
        String npServer = Misc::CheckConfigurationVariable(_STR_NP_SERVER, true);

		if (npServer.IsEmpty()) npServer = _CSTR_DEFAULT_SERVER;
		if (npROOT.IsEmpty()) npROOT = _CSTR_DEFAULT_ROOT;
		if (npHOST.IsEmpty()) npHOST = _CSTR_DEFAULT_HOST;

        short result_code = 0;

        //==============================================================
        // Set NetPerception variables
        //==============================================================
        NetPerceptionsI::Root_var rootVar;
		NetPerceptionsI::RatingParticipantHandle rater;
        NetPerceptionsI::RatingParticipantHandle ratee;
        NetPerceptionsI::Dimension::RatingValue rating_value;
        NetPerceptionsI::Dimension::RatingTimestamp rating_timestamp =
            (NetPerceptionsI::Dimension::RatingTimestamp) time(NULL);

		
        //==============================================================
        // NetPerceptions initialization code
        //==============================================================

		// Initialize ORB	
		int argc=0;
		char *t = new char[20];
		strcpy(t,"gl_profile_upd_prod");
		
	    CORBA::ORB_ptr theOrbPtr = CORBA::ORB_init(argc,&t, "Orbix");

        if (CORBA::is_nil(theOrbPtr)) {
            debug << indent;
			status.nls(&_NP_ERR_NO_ORB) << endl;
			CORBA::release(theOrbPtr);
            *envResultCode = "pers_disabled";
            return true;
        }

        theOrbPtr->setDiagnostics(orbix_diagnostic_level);
        theOrbPtr->maxConnectRetries(orbix_max_connect_retries);

		String name_server;
		name_server = npROOT << ":" << npServer;
        try {
            rootVar = NetPerceptionsI::Root::_bind(name_server.c_str(), npHOST.c_str());
        }
        catch (...) {
            debug << indent;
			status.nls(&_NP_ERR_BIND, npROOT.c_str(), name_server.c_str(), npHOST.c_str()) << endl;
          *envResultCode = "pers_disabled";
		  return true;
        }


		// Get the Likert RatingStrategy object
        NetPerceptionsI::RatingStrategy_var likert_rating_strategyVar;
        try {
            likert_rating_strategyVar =
                rootVar->locate_rating_strategy(envLikertRatingStrategy->c_str());
        }
        catch (...) {
            debug  <<indent;
			status.nls(&_NP_ERR_LOCATE_LIKERT_RATING,envLikertRatingStrategy->c_str()) << endl;
          *envResultCode = "pers_error";
		  return true;
        }


		// Get the Interest RatingStrategy object
        NetPerceptionsI::RatingStrategy_var interest_rating_strategyVar;
        try {
            interest_rating_strategyVar =
                rootVar->locate_rating_strategy(envInterestRatingStrategy->c_str());
        }
        catch (...) {
          debug  <<indent;
  	      status.nls(&_NP_ERR_LOCATE_INTEREST_RATING,envInterestRatingStrategy->c_str()) << endl;
          *envResultCode = "pers_error";
		  return true;
        }

		
     	// locate container dimension
        NetPerceptionsI::ContainerDimension_var likert_dimensionVar;
		try {
           likert_dimensionVar =
                  rootVar->locate_container_dimension(envLikertDimensionName->c_str());
		}
        catch (...) {
          debug  <<indent;
  	      status.nls(&_NP_ERR_LOCATE_LIKERT_CONTAINER,envLikertDimensionName->c_str()) << endl;
          *envResultCode = "pers_error";
		  return true;
		}

		// locate interest container dimension
        NetPerceptionsI::ContainerDimension_var interest_dimensionVar;
		try {
           interest_dimensionVar =
                  rootVar->locate_container_dimension(envInterestDimensionName->c_str());
		}
        catch (...) { 
          debug  <<indent;
  	      status.nls(&_NP_ERR_LOCATE_INTEREST_CONTAINER,envInterestDimensionName->c_str()) << endl;
          *envResultCode = "pers_error";
		  return true;
		}
        //==============================================================
        // Retrieve the Rating value and the product number to be rated
		// Either Addrating or Remove ratings for the given product
		// reference number.
        //==============================================================

        bool bNPTransactionOK = false;    // Assume failure for the moment
      
        const char *kcsMerchantRefNum = envMerchantRefNum->c_str();
        const char *kcsShopperRefNum = lvShopperRefNum.c_str();


        TemplateNC_PList<String, String>::Iterator lvI = envProductRefNumList->getIterator();
        TemplateNC_PList<String, String>::Iterator lvJ = theBehaviorList.getIterator();
        String* currentProductRefNum;
        String* currentBehaviorName;
        BehaviorHome lvBehavior_home (*DataBaseManager::GetCurrentDataBase());
        Behavior* lvBehavior;
        GL_Rating* lvGLRating;
        GL_RatingHome lvGLRating_home (*DataBaseManager::GetCurrentDataBase());
        NVPHash nvp_empty;
        String lvBehaviorRefNum;

		*envResultCode = "success";

        //
        // Iterate through the product reference number list
        //
        for( currentProductRefNum = lvI.getElement(), 
             currentBehaviorName = lvJ.getElement();
             
             currentProductRefNum = lvI.getElement(), 
             currentBehaviorName = lvJ.getElement(), 
             currentProductRefNum != NULL;
             
            lvI.getNextElement(), lvJ.getNextElement() )
        {
            //=====================================================
            // Get the parent refnum if any. assume two level only
            //=====================================================

            NVPHash NVP;

            String lvParentRefNum(_STR_EMPTY_);
            SKU_HardHome lvSkuHardHome(*DataBaseManager::GetCurrentDataBase());
            SKU_Hard* lvSku = lvSkuHardHome.Lookup(*currentProductRefNum, NVP);
            if (lvSku != NULL)
            {
                lvParentRefNum = lvSku->getProdRefNum();
                lvSkuHardHome.Destroy(lvSku);
            }
            if (lvParentRefNum == _STR_EMPTY_) 
            {
                lvParentRefNum = *currentProductRefNum;
            }

            const char *kcsProductRefNum = lvParentRefNum.c_str();

            //=====================================================
            // Handle the behavior
            //=====================================================

            if (currentBehaviorName == NULL)
            {
                error << indent; error.nls(&_API_PERS_ENGINE_ERROR,
                 "Could not find a behavior for at least one product") << endl;
                *envResultCode = "mismatch";
                TransactionOK = true;
				break;
            }
         
            //debug << indent << "NetPerception: Current product/behavior pair: <" 
            // << *currentProductRefNum << ", " << *currentBehaviorName << ">\n";

            // retrieve the row from db for the behavior and rating
            lvBehavior = lvBehavior_home.LookupByName(currentBehaviorName, nvp_empty);
            if (lvBehavior == NULL)
            {
                error << indent; error.nls(&_API_CANT_LOAD_BEHAVIOR, 
                                           currentBehaviorName->c_str()) << endl;
                *envResultCode = "error";
                break;
            }

            lvBehaviorRefNum = lvBehavior->getRefNum();

            lvGLRating = lvGLRating_home.LookupByRefNum(&lvBehaviorRefNum, 
                                                        envMerchantRefNum, nvp_empty);
            if (lvGLRating == NULL) 
            {
                lvGLRating = lvGLRating_home.LookupByRefNum(&lvBehaviorRefNum, 
                              SQL_Schema::_STR_NULL_, nvp_empty);
            }

            if (lvGLRating == NULL)
            {   
                error << indent; 
                error.nls(&_API_CANT_LOAD_RATING, currentBehaviorName->c_str()) << endl;
                *envResultCode = "error";
                break;
            }

            long lvRating;
            lvGLRating->getRating().getVal(lvRating);
            long lvRatingLevel;
            lvGLRating->getRatingLevel().getVal(lvRatingLevel);
            long lvGLEnable;
            lvGLRating->getEnable().getVal(lvGLEnable);
			
            //===============================================================
            // If the behavior is not enabled, then do not record the rating
            //===============================================================
            if (lvGLEnable != 1)  continue;

            //===============================================================
            // Net Perception transaction begins
            //===============================================================

			StringIterator Xplicit(currentBehaviorName); 
 	        Xplicit.Seek("X_");
			bool explicit_rating;
		    if (Xplicit.Pos() == Xplicit.Len()) explicit_rating = false;
			else explicit_rating=true;

		    // Set the rater and ratee domain's and containter dimension to use	
			NetPerceptionsI::Dimension_var the_dimension;
            NetPerceptionsI::ContainerDimension_var theDimensionVar;
	        NetPerceptionsI::RatingStrategy_var rating_strategyVar;
			String *dimension_name;
			if (explicit_rating) {
                the_dimension = likert_rating_strategyVar->the_dimension();
                theDimensionVar = likert_dimensionVar;
				rating_strategyVar = likert_rating_strategyVar;
				dimension_name = envLikertDimensionName;
			}
			else {
				the_dimension = interest_rating_strategyVar->the_dimension();
                theDimensionVar = interest_dimensionVar;
				rating_strategyVar = interest_rating_strategyVar;
				dimension_name = envInterestDimensionName;
			}

            try {
                  ratee.domain = the_dimension->ratee_domain()->the_key();
                  rater.domain = the_dimension->rater_domain()->the_key();
			}
            catch (...) {
                   debug << indent;
				   status.nls(&_NP_ERR_SET_DOMAIN_KEY) << endl;
                   *envResultCode = "pers_error";
		   		   CORBA::release(theOrbPtr);
			       return true;
			}

			// update ratee and rater variables
	 	    char *tmp;
		    uword64 _key = strtoull((lvUser->getRefNum()).c_str(), &tmp, 0); ;
            ull_to_LongLong(_key, rater.key);

            _key = strtoull(currentProductRefNum->c_str(), &tmp, 0);
            ull_to_LongLong(_key, ratee.key);


            //===============================================================
            // If the action is to remove the rating, then a different api 
            // is called.  Rating and rating level are ignored.
            //===============================================================
            if (*currentBehaviorName == _REMOVE_RATING) 
            {
           
                // Remove the rating for the item
                try {
                     likert_dimensionVar->remove_rating(rater,ratee);
				}
                catch (...) {
                   debug << indent;
				   status.nls(&_NP_ERR_REMOVE_RATINGS,currentProductRefNum->c_str()) << endl;
				   *envResultCode = "pers_error";
                     continue;
				}

                debug << indent;
				status.nls(&_NP_SUCCESS_REMOVE_RATINGS,currentProductRefNum->c_str()) << endl;
 
				*envResultCode = "remove";

            }  // if _REMOVE_RATING
            else
            {
                rating_value = lvRating;

               	// Compare new ratings with the existing ratings 
				// If the current ratings are explicit then override the existing
				// rating, else ensure that the new rating is higher than the
				// one saved in the database.

				bool update_rating = true;

                NetPerceptionsI::RatingParticipantHandleList_var rateesVar =
                     new NetPerceptionsI::RatingParticipantHandleList;
                rateesVar->length(1);
	 	        CORBA::ULong i = 0;
				ull_to_LongLong(_key,rateesVar[i].key);

				for (CORBA::ULong j = 0; j < rateesVar->length(); j++) {
                      rateesVar[j].domain = theDimensionVar->ratee_domain()->the_key();
				}
				              
				if (!explicit_rating) {
         		  try {
				   NetPerceptionsI::Dimension::RatingList_var ratingsVar = 
						 theDimensionVar->rater_ratings(rater, rateesVar);

			       for (CORBA::ULong i = 0; i < ratingsVar->length(); i++) {
                     if (ratee.key.low == (unsigned long) LongLong_to_ull(ratingsVar[i].the_ratee.key))
				        if (ratingsVar[i].the_rating < rating_value) {
						  // debug << indent << "NetPerception: Current rating value is : "<< ratingsVar[i].the_rating << endl;
						}
						else { update_rating = false; break;}
				   } 
				  }
                  catch (...) {
                         debug << indent << "NetPerceptions: Unable to retrieve current ratings" << endl;
						 *envResultCode = "pers_error";
                         continue;
				  }
				}
			
                // Add the rating
				if (update_rating) {
                     try {
                        rating_strategyVar->add_rating(rater,
                                           ratee,
                                           rating_value,
                                           rating_timestamp);
					 }
                     catch (...) {
                        debug << indent;
				        status.nls(&_NP_ERR_ADD_RATINGS,currentProductRefNum->c_str()) << endl;
						*envResultCode = "pers_error";
                        continue;
					 }
                     debug << indent;
					 String lval(lvGLRating->getRating());
				     status.nls(&_NP_SUCCESS_ADD_RATINGS,currentProductRefNum->c_str(),lval.c_str(),dimension_name->c_str()) << endl;
                }

                                                   
            } // else if not _REMOVE_RATING behavior     
            //==============================
            // End of Net Perception transaction
            //==============================

            // cleanup the row for the behavior and rating
            lvBehavior_home.Destroy(lvBehavior);
            lvGLRating_home.Destroy(lvGLRating);
        }  // for(each product in list...)


		// Cleanup
		 CORBA::release(theOrbPtr);

		         // If we reach here, then the transaction is OK.
		if ((*envResultCode == "error"))
           TransactionOK = false;
		else TransactionOK = true;
		
        return TransactionOK;
    }
};

ClassName GL_ProfileUpdProd::_STR_ThisClass("GL_ProfileUpdProd");

static bool X1 = NC_ApiManager::GetUniqueInstance().RegisterApi( "IBM",
                                                                 "NC",
                                                                 "GL_ProfileUpdProd",
                                                                 1.0,
                                                                 new GL_ProfileUpdProd );




