/****************************************************************************************/
/*                                                                                      */
/* IBM Confidential                                                                     */
/*                                                                                      */
/* Net.Commerce Source Materials                                                        */
/*                                                                                      */
/* (C) Copyright IBM Corp. 1998.                                                        */
/*                                                                                      */
/* The source code for this program is not published or otherwise divested of its trade */
/* secrets, irrespective of what has been deposited with the U.S. Copyright Office.     */
/*                                                                                      */
/****************************************************************************************/

//
// The order of the includes here is important!  Do not move them around.
//
#include "messages/np_msg.pch"
#include "messages/np_msg_src.h"
#include "api/api.pch"
#include <NetPerceptionsI.h>


//==============================================================================
//==============================================================================
#ifdef __TRACE_NCAPIS__
  typedef TraceYes Trace;
#else
  typedef TraceNo  Trace;
#endif
static Trace trace("NC_APIS ("__FILE__")");
//==============================================================================

#ifdef WIN32 // needed for ORBIX
#define USE_INIT
static int bootInit;
#endif

#ifdef WIN32
extern "C" char *optarg;
extern "C" int getopt(int argc, char *argv[], char *opstring);
typedef __int64 word64;
typedef unsigned __int64 uword64;
#define LONG_BIT (sizeof(long) * CHAR_BIT)
#define WORD_BIT (sizeof(uword64)/2)
#define strtoull(Str, Ptr, Base) _atoi64(Str)
#endif

#ifdef SOLARIS
typedef long long word64;
typedef unsigned long long uword64;
#endif

#define ull_to_LongLong(U,K) \
    (K).hi = ((U) >> LONG_BIT); (K).low = ((U) & ULONG_MAX);

#define LongLong_to_ull(K) \
      ((((uword64) (K).hi) << LONG_BIT) | ((uword64) (K).low))


///=========================================================
// Net Perception constants
//=========================================================

// These are default values.
static const char *_CSTR_DEFAULT_HOST = "localhost";
static const char *_CSTR_DEFAULT_SERVER = "prod";
static const char *_CSTR_DEFAULT_ROOT = "prod";
static const int _INT_DEFAULT_PORT = 9000;
static unsigned int orbix_diagnostic_level = 0;
static unsigned int orbix_max_connect_retries = 1;


//=========================================================
// Configuration Variables
//=========================================================
static const ConfField _STR_NP_ROOT("NP_ROOT");
static const ConfField _STR_NP_MODE("NP_MODE");
static const ConfField _STR_NP_HOST("NP_HOST");
static const ConfField _STR_NP_SERVER("NP_SERVER");

//=========================================================
// NC Environment Parameter Names
//     must match those used by calling commands
//=========================================================
static const StringWithOwnership _PARAM_NAME_RECOMMENDATION_STATUS("RECOMMENDATION_STATUS");
static const StringWithOwnership _PARAM_NAME_PERS_RESULT_CODE("PERS_RESULT_CODE");
static const StringWithOwnership _PARAM_NAME_LIKERT_DIMENSION_NAME("LIKERT_DIMENSION_NAME");
static const StringWithOwnership _PARAM_NAME_INTEREST_DIMENSION_NAME("INTEREST_DIMENSION_NAME");

//=========================================================
// Others
//=========================================================
static const StringWithOwnership _STR_YES("yes");
static const StringWithOwnership _STR_NO("no");


class GL_RemoveProdRatings : public NC_Api
{
    static const ClassName _STR_ThisClass;

public:
    GL_RemoveProdRatings()
    {
        Trace::Tracer T(_STR_CONSTRUCTOR, _STR_ThisClass);
    }

    virtual ~GL_RemoveProdRatings()
    {
        Trace::Tracer T(_STR_DESTRUCTOR, _STR_ThisClass);
    }

    void  operator delete( void* p ) { ::delete p; }

public:
   virtual bool Process(const HttpRequest& Req, HttpResponse& Res, NC_Environment& Env)
   {

      
      //==========================================================
      // Get Overridable function parameters from the environment.
      //==========================================================

        // Result code
        String localResultCode;

        String *envResultCode = (String *) Env.Seek(_PARAM_NAME_PERS_RESULT_CODE);
        if (envResultCode == NULL)
        {
            envResultCode = &localResultCode;
        }
        else
        {
            envResultCode->Clean();
            envResultCode->Resize(64);
        }
      

      // Merchant Reference Number

      String* envMerchantRefNum = (String*) Env.Seek(_PARAM_NAME_MERCHANT_REF_NUM);
      if (envMerchantRefNum == NULL)
      {
         error << indent;
         error.nls(&_API_CANT_FIND_IN_ENV, _PARAM_NAME_MERCHANT_REF_NUM.c_str()) << endl;
         *envResultCode = "error";
         return false;
      }


      // Shopper Reference Number

      String shopperRefNum;
      
      User* envUser = (User*) Env.Seek(NC_Environment::_VAR_Shopper);
      if (envUser == NULL)
      {
         error << indent;
         error.nls(&_ERR_CANT_LOAD_SHOPPER) << endl;
         *envResultCode = "error";
         return false;
      }
      shopperRefNum = envUser->getValue(User::_COL_REF_NUM);


      // Product Reference Number

      String* envProductRefNum = (String*) Env.Seek(_PARAM_NAME_PRODUCT_REF_NUM);
      if(envProductRefNum == NULL)
      {
         error << indent;
         error.nls(&_API_CANT_FIND_IN_ENV, _PARAM_NAME_PRODUCT_REF_NUM.c_str()) << endl;
         *envResultCode = "error";
         return false;
      }
      

      // Recommendation Status

      String* envRecStatus = (String*) Env.Seek(_PARAM_NAME_RECOMMENDATION_STATUS);
      if(envRecStatus == NULL)
      {
         error << indent;
         error.nls(&_API_CANT_FIND_IN_ENV, _PARAM_NAME_RECOMMENDATION_STATUS.c_str()) << endl;
         *envResultCode = "error";
         return false;
      }

      // Likert Dimension to be used
      String* envLikertDimensionName = (String*) Env.Seek(_PARAM_NAME_LIKERT_DIMENSION_NAME);
      if (envLikertDimensionName== NULL)
      {
         error << indent; 
         error.nls(&_API_CANT_FIND_IN_ENV, _PARAM_NAME_LIKERT_DIMENSION_NAME.c_str()) 
           << endl;
         *envResultCode = "error";
         return false;
      }
	
      // Interest Dimension to be used
      String* envInterestDimensionName = (String*) Env.Seek(_PARAM_NAME_INTEREST_DIMENSION_NAME);
      if (envInterestDimensionName== NULL)
      {
         error << indent; 
         error.nls(&_API_CANT_FIND_IN_ENV, _PARAM_NAME_INTEREST_DIMENSION_NAME.c_str()) 
             << endl;
         *envResultCode = "error";
         return false;
      }

	    //==============================================================
        // Set NetPerception variables
        //==============================================================
        NetPerceptionsI::Root_var rootVar;
        NetPerceptionsI::RatingParticipantHandle ratee;
       
 		//==============================================================
        // Read NetPerception Configuration variables given in Net.Commerce
		// configuration files
        //==============================================================
        String npHOST = Misc::CheckConfigurationVariable(_STR_NP_HOST, true);
        String npROOT = Misc::CheckConfigurationVariable(_STR_NP_ROOT, true);
        String npServer = Misc::CheckConfigurationVariable(_STR_NP_SERVER, true);

		if (npServer.IsEmpty()) npServer = _CSTR_DEFAULT_SERVER;
		if (npROOT.IsEmpty()) npROOT = _CSTR_DEFAULT_ROOT;
		if (npHOST.IsEmpty()) npHOST = _CSTR_DEFAULT_HOST;

		debug << " NP HOST is : " << npHOST << endl;
		debug << " NP ROOT is : " << npROOT << endl;
		debug << " NP Server  is : " << npServer << endl;

 		//==============================================================
        // NetPerceptions initialization code
        //==============================================================
        bool bGLTransactionOK = true;    // Assume failure for the moment

		// Initialize ORB	
		int argc=0;
		char *t = new char[20];
		strcpy(t,"gl_profile_upd_prod");
	    CORBA::ORB_ptr theOrbPtr = CORBA::ORB_init(argc,&t, "Orbix");

        if (CORBA::is_nil(theOrbPtr)) {
            debug << indent;
			status.nls(&_NP_ERR_NO_ORB) << endl;
	        CORBA::release(theOrbPtr);
            *envResultCode = "pers_disabled";
            return true;
        }

        theOrbPtr->setDiagnostics(orbix_diagnostic_level);
        theOrbPtr->maxConnectRetries(orbix_max_connect_retries);

		String name_server;
		name_server = npROOT << ":" << npServer;
        try {
            rootVar = NetPerceptionsI::Root::_bind(name_server.c_str(), npHOST.c_str());
        }
        catch (...) {
           debug << indent;
		   status.nls(&_NP_ERR_BIND, npROOT.c_str(), name_server.c_str(), npHOST.c_str()) << endl;
          *envResultCode = "pers_disabled";
		  return true;
        }
		     	// locate container dimension
        NetPerceptionsI::ContainerDimension_var likert_dimensionVar;
		try {
           likert_dimensionVar =
                  rootVar->locate_container_dimension(envLikertDimensionName->c_str());
		}
        catch (...) {
          debug  <<indent;
  	      status.nls(&_NP_ERR_LOCATE_LIKERT_CONTAINER,envLikertDimensionName->c_str()) << endl;
          *envResultCode = "pers_error";
		  return true;
		}

		// locate interest container dimension
        NetPerceptionsI::ContainerDimension_var interest_dimensionVar;
		try {
           interest_dimensionVar =
                  rootVar->locate_container_dimension(envInterestDimensionName->c_str());
		}
        catch (...) { 
          debug  <<indent;
  	      status.nls(&_NP_ERR_LOCATE_INTEREST_CONTAINER,envInterestDimensionName->c_str()) << endl;
          *envResultCode = "pers_error";
		  return true;
		}
      
	    // update subject and object variables
	    char *tmp;
	    uword64 _key = strtoull(envProductRefNum->c_str(), &tmp, 0); ;
        ull_to_LongLong(_key, ratee.key);

        debug  <<indent;
  	    status.nls(&_NP_DBG_REMOVE_RATINGS,envProductRefNum->c_str(),envMerchantRefNum->c_str()) << endl;

        // Can now assume that *envRecStatus is YES or NO.
        if(*envRecStatus == _STR_YES)
		{
		  try {
             ratee.domain = likert_dimensionVar->ratee_domain()->the_key();
		  }
          catch (...) {
             debug << indent;
		     status.nls(&_NP_ERR_SET_DOMAIN_KEY) << endl;
             *envResultCode = "pers_error";
		     CORBA::release(theOrbPtr);
		     return true;
		  }
         
          // Remove all ratings for the given product
          try {
                likert_dimensionVar->remove_ratees_ratings(ratee);
		  }
		  catch (const NetPerceptionsI::BadParameter& e) {
			*envResultCode="pers_error";
            debug << indent;
			status.nls(&_NP_ERR_REMOVE_BAD_PARAMS,envLikertDimensionName) << endl;
		  }
          catch (const NetPerceptionsI::DomainMismatch& e){
			*envResultCode="pers_error";
             debug << indent;
			status.nls(&_NP_ERR_REMOVE_DOMAIN_MISMATCH,envLikertDimensionName) << endl;
		  }
          catch (const NetPerceptionsI::ServerError& e){
			*envResultCode="pers_error";
            debug << indent;
			status.nls(&_NP_ERR_REMOVE_SERVER_ERROR,envLikertDimensionName) << endl;
		  }
          catch (...) {   
            debug << indent;
			status.nls(&_NP_ERR_REMOVE_UNKWN_ERROR,envLikertDimensionName) << endl;
				 *envResultCode = "pers_error";
      	  }

          try {
             ratee.domain = interest_dimensionVar->ratee_domain()->the_key();
		  }
          catch (...) {
             debug << indent <<  "NetPerceptions: Unable to set ratee or rater domain keys" << endl;
             *envResultCode = "pers_error";
		     CORBA::release(theOrbPtr);
		     return true;
		  }

          try {
                interest_dimensionVar->remove_ratees_ratings(ratee);
		  }
		  catch (const NetPerceptionsI::BadParameter& e) {
			*envResultCode="pers_error";
            debug << indent;
			status.nls(&_NP_ERR_REMOVE_BAD_PARAMS,envInterestDimensionName) << endl;
		  }
          catch (const NetPerceptionsI::DomainMismatch& e){
			*envResultCode="pers_error";
             debug << indent;
			status.nls(&_NP_ERR_REMOVE_DOMAIN_MISMATCH,envInterestDimensionName) << endl;
		  }
          catch (const NetPerceptionsI::ServerError& e){
			*envResultCode="pers_error";
            debug << indent;
			status.nls(&_NP_ERR_REMOVE_SERVER_ERROR,envInterestDimensionName) << endl;
		  }
          catch (...) {   
            debug << indent;
			status.nls(&_NP_ERR_REMOVE_UNKWN_ERROR,envInterestDimensionName) << endl;
				 *envResultCode = "pers_error";
      	  }

		  if (*envResultCode != "pers_error") {
                debug << indent;
				status.nls(&_NP_SUCCESS_REMOVE_RATINGS,envProductRefNum->c_str()) << endl;
 
		     *envResultCode = "remove";
		  }
      }

		// Cleanup
		 CORBA::release(theOrbPtr);

        // If we reach here, then the transaction is OK.

      return bGLTransactionOK;
   }
};

const ClassName GL_RemoveProdRatings::_STR_ThisClass("GL_SRemoveProdRatings");

static bool X1 = NC_ApiManager::GetUniqueInstance().RegisterApi( "IBM",
                                                                 "NC",
                                                                 "GL_RemoveProdRatings",
                                                                 1.0,
                                                                 new GL_RemoveProdRatings);

