/****************************************************************************************/
/*                                                                                      */
/* IBM Confidential                                                                     */
/*                                                                                      */
/* Net.Commerce Source Materials                                                        */
/*                                                                                      */
/* (C) Copyright IBM Corp. 1998.                                                        */
/*                                                                                      */
/* The source code for this program is not published or otherwise divested of its trade */
/* secrets, irrespective of what has been deposited with the U.S. Copyright Office.     */
/*                                                                                      */
/****************************************************************************************/
//////////////////////////////////////////////////////////////////////////////////////////
// Change History
//////////////////////////////////////////////////////////////////////////////////////////
// YYMMDD  F/D#   WHO    Description
// ---------------------------------------------------------------------------------------
// 981006         jbrains Initial version
// 981020         holung  Removing unrated products
//////////////////////////////////////////////////////////////////////////////////////////

#include "nc_core.pch"
#include "api/api.pch"
#include <containers/ldh_list.h>
#include "commands/np_configuration.h"
#include "messages/np_msg.pch"
#include "messages/np_msg_src.h"

/****************************************************************************************/
#ifdef __TRACE_COMMANDS__
  typedef TraceYes Trace;
#else
  typedef TraceNo  Trace;
#endif
static Trace trace("NC_COMMANDS ("__FILE__")");
/****************************************************************************************/


//////////////////////////////////////////////////////////////////////////////////////////
//
// Internal constants
//

//==============================================================
// External Parameters -- interface with incoming URL
//==============================================================

// None!

//==============================================================
// Internal Parameters -- interface with NCEnvironment
//==============================================================
static const StringWithOwnership paramNameMerchantRefNum("merchant_rn");
static const StringWithOwnership _PARAM_NAME_FROM_RANK("FROM_RANK");
static const StringWithOwnership _PARAM_NAME_TO_RANK("TO_RANK");
static const StringWithOwnership _PARAM_NAME_PERS_RESULT_CODE("PERS_RESULT_CODE");

static const StringWithOwnership _TASK_GL_GET_REC_PROD("GL_GET_REC_PROD");

//==============================================================
// Return Parameters -- interface with outgoing URL
//==============================================================

static const StringWithOwnership paramNameURL("url");
static const StringWithOwnership paramNameRecommendedProduct("recommended_product");
static const StringWithOwnership paramNameResultCode("result_code");
static const StringWithOwnership _PARAM_NAME_LIKERT_DIMENSION_NAME("LIKERT_DIMENSION_NAME");
static const StringWithOwnership _PARAM_NAME_INTEREST_DIMENSION_NAME("INTEREST_DIMENSION_NAME");
static const StringWithOwnership _PARAM_NAME_LIKERT_PREDICTION_STRATEGY("LIKERT_PREDICTION_STRATEGY");
static const StringWithOwnership _PARAM_NAME_INTEREST_PREDICTION_STRATEGY("INTEREST_PREDICTION_STRATEGY");

//==============================================================
// Others
//==============================================================

static const FuncName _STR_Constructor("constructor");
static const char *msgPersonalizationDisabled = "Personalization not enabled";


//////////////////////////////////////////////////////////////////////////////////////////
//
//  Command EnterMerchant
//

class EnterMerchant : public NC_Command
{
private:
    static ClassName _STR_ThisClass;
    static const String m_fromRank;
    static const String m_toRank;

    String m_merchant_rn;
    String m_result_code;
	
    TemplateNC_PList<String, String> m_product_refnum_list;
    String m_recommended_product;
    
public:
    EnterMerchant() : m_product_refnum_list(true), m_merchant_rn(), m_result_code(),
                         m_recommended_product()
    {
        Trace::Tracer T(_STR_Constructor, _STR_ThisClass);
        // Do nothing!
    }

    ~EnterMerchant()
    {
        // Do nothing!
    }
    
    void operator delete( void* p )
    {
        ::delete p;
    }

public:
    virtual bool CheckParameters(const HttpRequest& Req, 
                                 HttpResponse& Res,
                                 NC_Environment& Env, 
                                 NC_Environment& Resources)
    {
        Trace::Tracer T(_STR_CheckParameters, _STR_ThisClass);
		
		String *envMerchantRefNum;
		Misc::CheckFieldExistenceLong(Req, paramNameMerchantRefNum, m_merchant_rn, true);
        if(m_merchant_rn.IsEmpty())
        {
            MerchantHome theMerchantHome(*DataBaseManager::GetCurrentDataBase());
            MerchantHome::SchemaList* theMerchantList;
            String whereClause;
            whereClause.Resize(STRLEN_1K);
            whereClause << Merchant::_COL_STORE_NAME << "='6ixth Avenue'";
            theMerchantList = theMerchantHome.Query(whereClause);

            if(theMerchantList == NULL)
            {
                error << indent;
                error.nls(&_API_CANT_FIND_IN_ENV, _PARAM_NAME_MERCHANT_REF_NUM.c_str()) << endl;
                m_result_code = "error";
                return false;
            }
			m_merchant_rn = theMerchantList->getHead()->getRefNum();
        }

        String tempURL;
        if(Misc::CheckFieldExistence(Req, paramNameURL, tempURL, false) == false)  return false;

        return true;
    }
        
                                 
    virtual bool Process(const HttpRequest& Req,
                         HttpResponse& Res, 
                         NC_Environment& Env)
    {
        Trace::Tracer T(_STR_Process, _STR_ThisClass);

        m_result_code = "success";
        NVPHash redirectNVP;

        if (Misc::CheckConfigurationVariable(ConfField::_CONF_PERS_ENABLED, true) == "YES")
        {
            const ErrorMsg_Cmd* Err;

            //
            // Get the Merchant Reference Number for 6ixth Avenue
            //
        
            // First, try the environment

            //String *envMerchantRefNum = (String*) Env.Seek(_PARAM_NAME_MERCHANT_REF_NUM);
            //if(envMerchantRefNum == NULL)
            //{
                // Go to the database, then.
            //   MerchantHome theMerchantHome(*DataBaseManager::GetCurrentDataBase());
            //   MerchantHome::SchemaList* theMerchantList;
            //  String whereClause;
            //    whereClause.Resize(STRLEN_1K);
            //    whereClause << Merchant::_COL_STORE_NAME << "='6ixth Avenue'";
            //    theMerchantList = theMerchantHome.Query(whereClause);

            //    if(theMerchantList == NULL)
            //    {
            //        error << indent;
            //        error.nls(&_API_CANT_FIND_IN_ENV, _PARAM_NAME_MERCHANT_REF_NUM.c_str()) << endl;
            //        m_result_code = "error";
            //        return false;
            //    }
    		//	m_merchant_rn = theMerchantList->getHead()->getRefNum();
            //}
            //else {
            //    m_merchant_rn = *envMerchantRefNum;
            //}

            //
            // Get Top 1
            //
			// Likert Dimension to be used
			String likert_dimension;
			likert_dimension.Clean();
			likert_dimension << LIKERT_DIMENSION_NAME << m_merchant_rn;

			// Interest Dimension to be used
			String interest_dimension;
			interest_dimension.Clean();
			interest_dimension << INTEREST_DIMENSION_NAME << m_merchant_rn;		

			String likert_prediction_strategy;
			likert_prediction_strategy.Clean();
			likert_prediction_strategy << LIKERT_PREDICTION_STRATEGY << m_merchant_rn;
 
			String interest_prediction_strategy;
			interest_prediction_strategy.Clean();
			interest_prediction_strategy << INTEREST_PREDICTION_STRATEGY << m_merchant_rn;

            Env.AddRef(_PARAM_NAME_PERS_RESULT_CODE, &m_result_code);
            Env.AddRef(_PARAM_NAME_MERCHANT_REF_NUM, &m_merchant_rn);
            Env.AddRef(_PARAM_NAME_PRODUCT_REF_NUM_LIST, &m_product_refnum_list);
            Env.AddRef(_PARAM_NAME_FROM_RANK, &m_fromRank);
            Env.AddRef(_PARAM_NAME_TO_RANK, &m_toRank);
			Env.AddRef(_PARAM_NAME_LIKERT_DIMENSION_NAME, &likert_dimension);
			Env.AddRef(_PARAM_NAME_INTEREST_DIMENSION_NAME, &interest_dimension);
			Env.AddRef(_PARAM_NAME_LIKERT_PREDICTION_STRATEGY, &likert_prediction_strategy);
			Env.AddRef(_PARAM_NAME_INTEREST_PREDICTION_STRATEGY, &interest_prediction_strategy);			

                   
            Err = NC_ApiManager::GetUniqueInstance().ProcessApi(Req, Res, Env,
                                                                _TASK_GL_GET_REC_PROD,
                                                                m_merchant_rn );

            Env.Remove(_PARAM_NAME_PERS_RESULT_CODE);
            Env.Remove(_PARAM_NAME_MERCHANT_REF_NUM);
            Env.Remove(_PARAM_NAME_PRODUCT_REF_NUM_LIST);
            Env.Remove(_PARAM_NAME_FROM_RANK);
            Env.Remove(_PARAM_NAME_TO_RANK);
            Env.Remove(_PARAM_NAME_LIKERT_DIMENSION_NAME);
            Env.Remove(_PARAM_NAME_INTEREST_DIMENSION_NAME);
            Env.Remove(_PARAM_NAME_LIKERT_PREDICTION_STRATEGY);
            Env.Remove(_PARAM_NAME_INTEREST_PREDICTION_STRATEGY);                   

            if (Err == &_ERR_CMD_ERR_HANDLED)  // API already handled the error!
            {
                throw Err;
            }

            if (Err != NULL) // Unhandled error
            {
                error << indent;
                error.nls(&_ERR_UNHANDLED_IN_API,__FILE__,__LINE__) << endl;
                return false;
            } 

            if(!m_product_refnum_list.Empty())
            {
                String* recommendedProductRefNum = m_product_refnum_list.getHead();
                if(recommendedProductRefNum != NULL)
                {
                    m_recommended_product = *recommendedProductRefNum;
                    redirectNVP.Add(paramNameRecommendedProduct, m_recommended_product);
                }
            }
        }
        else
        {
            error << indent;
            error.nls(&_API_PERS_ENGINE_ERROR, msgPersonalizationDisabled) << endl;
            m_result_code = "disabled";
            // Personalization not enabled
        }

        m_product_refnum_list.Clean(true);
        redirectNVP.Add(paramNameResultCode, m_result_code);
        redirectNVP.Add(paramNameMerchantRefNum,m_merchant_rn);
        Res.Redirect(Req, paramNameURL, redirectNVP);

        return true;
    }
};

ClassName EnterMerchant::_STR_ThisClass("EnterMerchant");

const String EnterMerchant::m_fromRank("1");
const String EnterMerchant::m_toRank("1");

static bool Z = NC_CommandManager::GetUniqueInstance().RegisterCommand("IBM",
                                                                       "NC",
                                                                       "EnterMerchant",
                                                                       1.0,
                                                                       new EnterMerchant);



