/****************************************************************************************/
/*                                                                                      */
/* IBM Confidential                                                                     */
/*                                                                                      */
/* Net.Commerce Source Materials                                                        */
/*                                                                                      */
/* (C) Copyright IBM Corp. 1998.                                                        */
/*                                                                                      */
/* The source code for this program is not published or otherwise divested of its trade */
/* secrets, irrespective of what has been deposited with the U.S. Copyright Office.     */
/*                                                                                      */
/****************************************************************************************/
//////////////////////////////////////////////////////////////////////////////////////////
// Change History
//////////////////////////////////////////////////////////////////////////////////////////
// YYMMDD  F/D#   WHO    Description
// ---------------------------------------------------------------------------------------
// 
//////////////////////////////////////////////////////////////////////////////////////////

#include "nc_core.pch"
#include "api/api.pch"
#include <containers/ldh_list.h>
#include "commands/np_configuration.h"
#include "messages/np_msg.pch"
#include "messages/np_msg_src.h"


/****************************************************************************************/
#ifdef __TRACE_COMMANDS__
  typedef TraceYes Trace;
#else
  typedef TraceNo  Trace;
#endif
static Trace trace("NC_COMMANDS ("__FILE__")");
/****************************************************************************************/


//=========================================================
// Internal constants
//=========================================================

//=========================================================
// External Parameters -- interface with URL
//=========================================================

static const StringWithOwnership paramNameMerchantRefNum("merchant_rn");
static const StringWithOwnership paramNameFromRank  ("from_rank");
static const StringWithOwnership paramNameToRank    ("to_rank");
static const StringWithOwnership paramNameResultCode("history_result");
static const StringWithOwnership paramNameURL("url");




//=========================================================
// Internal Parameters -- interface with NCEnvironment
//=========================================================
static const StringWithOwnership _PARAM_NAME_HISTORY_PROD_LIST("RATING_HISTORY_PRODUCT_LIST");
static const StringWithOwnership _PARAM_NAME_HISTORY_RATING_LIST("RATING_HISTORY_RATING_LIST");
static const StringWithOwnership _PARAM_NAME_PERS_RESULT_CODE("PERS_RESULT_CODE");
static const StringWithOwnership _PARAM_NAME_FROM_RANK("FROM_RANK");
static const StringWithOwnership _PARAM_NAME_TO_RANK("TO_RANK");
static const StringWithOwnership _PARAM_NAME_LIKERT_DIMENSION_NAME("LIKERT_DIMENSION_NAME");

//=========================================================
// Others
//=========================================================

static const FuncName _STR_Constructor("constructor");
static const String strEmptyMerchantRefNum("EMPTY");

static const char *msgPersonalizationDisabled = "Personalization not enabled";

static const StringWithOwnership _TASK_GET_RATING_HISTORY("GET_RATING_HISTORY");
//static const StringWithOwnership _STR_RATE_HISTORY_MACRO_NAME("/demomall/ratinghistory.d2w");

// HTML page to display if personalization not enabled
static const StringWithOwnership naURL("/demomall/pers_na.htm");

// HTML page to display if personalization error occurs
static const StringWithOwnership errorURL("/demomall/pers_error.htm");

static const long _default_from_rank = 1;
static const long _default_to_rank = 25;



//////////////////////////////////////////////////////////////////////////////////////////
//
//  Command RatingHistory
//


class RatingHistory : public NC_Command
{
private:
    static ClassName _STR_ThisClass;

    String m_from_rank;
    String m_to_rank;

    String m_merchant_rn;
    String m_shopper_rn;
    String m_result_code;
	String url;
    TemplateNC_PList<String, String> m_history_product_list;
    TemplateNC_PList<String, String> m_history_rating_list;
    
public:
    RatingHistory() : m_history_product_list(true), m_history_rating_list(true),
                       m_from_rank(), m_to_rank(), m_merchant_rn(), m_shopper_rn(),
                       m_result_code()
    {
        Trace::Tracer T(_STR_Constructor, _STR_ThisClass);
        // Do nothing!
    }

    ~RatingHistory()
    {
        // Do nothing!
    }
    


    bool RatingHistory::CheckParameters(const HttpRequest& Req,
                                               HttpResponse& Res,
                                               NC_Environment& Env,
                                               NC_Environment& Resources )
    {
        Misc::CheckFieldExistenceLong(Req, paramNameMerchantRefNum, m_merchant_rn, true);
        if(m_merchant_rn.IsEmpty())
        {
            MerchantHome theMerchantHome(*DataBaseManager::GetCurrentDataBase());
            MerchantHome::SchemaList* theMerchantList;
            String whereClause;
            whereClause.Resize(STRLEN_1K);
            whereClause << Merchant::_COL_STORE_NAME << "='6ixth Avenue'";
            theMerchantList = theMerchantHome.Query(whereClause);

            if(theMerchantList == NULL)
            {
                error << indent;
                error.nls(&_API_CANT_FIND_IN_ENV, _PARAM_NAME_MERCHANT_REF_NUM.c_str()) << endl;
                m_result_code = "error";
                return false;
            }
			m_merchant_rn = theMerchantList->getHead()->getRefNum();
        }

        long theMerchantRefNum;
        m_merchant_rn.getVal(theMerchantRefNum);
        if(theMerchantRefNum < 0)
        {
            error << indent;
            error.nls(&_ERR_CMD_INVALID_PARAM, paramNameMerchantRefNum.c_str()) << endl;
            return false;
        }

		if(Misc::CheckFieldExistence(Req, paramNameURL, url, false) == false)  return false;

        long theFromRank, theToRank;
        
        Misc::CheckFieldExistenceLong(Req, paramNameFromRank, m_from_rank, true);

        if(m_from_rank.IsEmpty())
        {
            m_from_rank.Clean();
            m_from_rank << _default_from_rank;
            theFromRank = _default_from_rank;
        }
        else
        {
            m_from_rank.getVal(theFromRank);
            if(theFromRank < 1)
            {
                error << indent;
                error.nls(&_ERR_CMD_INVALID_PARAM, paramNameFromRank.c_str()) << endl;
                return false;
            }
        }

        Misc::CheckFieldExistenceLong(Req, paramNameToRank, m_to_rank, true);

        if(m_to_rank.IsEmpty())
        {
            m_to_rank.Clean();
            m_to_rank << _default_to_rank;
            theToRank = _default_to_rank;
        }
        else
        {
            m_to_rank.getVal(theToRank);
            if(theToRank < 1)
            {
                error << indent;
                error.nls(&_ERR_CMD_INVALID_PARAM, paramNameToRank.c_str()) << endl;
                return false;
            }
        }

        // Place this check here in case someone accidentally makes the default
        // 'from rank' larger than the default 'to rank'.
        if(theFromRank > theToRank)
        {
            error << indent;
            error.nls(&_ERR_CMD_INVALID_PARAM, paramNameFromRank.c_str()) << endl;
            error << indent;
            error.nls(&_ERR_CMD_INVALID_PARAM, paramNameToRank.c_str()) << endl;
            error << indent << "'From rank' cannot be greater than 'to rank'.\n";
            return false;             
        }

        return true;
    }  // CheckParameters()


    bool RatingHistory::Process( const HttpRequest& Req,
                                        HttpResponse& Res,
                                        NC_Environment& Env )
    {
		NVPHash redirectNVP;

        if (Misc::CheckConfigurationVariable(ConfField::_CONF_PERS_ENABLED, true) == "YES")
        {
            const ErrorMsg_Cmd* Err;

            m_history_product_list.Clean(true);
            m_history_rating_list.Clean(true);

			// Likert Dimension to be used
			String likert_dimension;
			likert_dimension.Clean();
			likert_dimension << LIKERT_DIMENSION_NAME << m_merchant_rn;

            Env.AddRef(_PARAM_NAME_MERCHANT_REF_NUM, &m_merchant_rn);
            Env.AddRef(_PARAM_NAME_HISTORY_PROD_LIST, &m_history_product_list);
            Env.AddRef(_PARAM_NAME_HISTORY_RATING_LIST, &m_history_rating_list);
            Env.AddRef(_PARAM_NAME_PERS_RESULT_CODE, &m_result_code);
            Env.AddRef(_PARAM_NAME_FROM_RANK, &m_from_rank);
            Env.AddRef(_PARAM_NAME_TO_RANK, &m_to_rank);
			Env.AddRef(_PARAM_NAME_LIKERT_DIMENSION_NAME, &likert_dimension);

            Err = NC_ApiManager::GetUniqueInstance().ProcessApi( Req, 
                                                                Res, 
                                                                Env, 
                                                                _TASK_GET_RATING_HISTORY,
                                                                m_merchant_rn );

            Env.Remove(_PARAM_NAME_MERCHANT_REF_NUM);
            Env.Remove(_PARAM_NAME_HISTORY_PROD_LIST);
            Env.Remove(_PARAM_NAME_HISTORY_RATING_LIST);
            Env.Remove(_PARAM_NAME_PERS_RESULT_CODE);
            Env.Remove(_PARAM_NAME_FROM_RANK);
            Env.Remove(_PARAM_NAME_TO_RANK);
            Env.Remove(_PARAM_NAME_LIKERT_DIMENSION_NAME);

            if (Err == &_ERR_CMD_ERR_HANDLED)  // API already handled the error!
            {
              throw Err;
            }

            if (Err != NULL) // Unhandled error
            {
                error << indent;
                error.nls(&_ERR_UNHANDLED_IN_API,__FILE__,__LINE__) << endl;
                return false;
            } 


            //           
            // If personalization error occurs, then the result code will have "pers_error".  Exit and
            // display the personalization error page.
            //
            if (m_result_code == "pers_error")
            {
               debug << indent; 
               status.nls(&_NP_ERR_PERSONALIZATION_ENGINE) << endl;
               status << indent << "Redirect to [" << errorURL << "]\n";
               Res.setLocation(errorURL, true);
               return true;
            }
     
 

            //
            // Build the parameter list
            //
            //String url("/cgi-bin/ncommerce3/ExecMacro");
            //url << _STR_RATE_HISTORY_MACRO_NAME << "/report";

            String parameters("?");
                
            long startIndex, stopIndex; 
            m_from_rank.getVal(startIndex);
            m_to_rank.getVal(stopIndex);
            if (startIndex > stopIndex)
            {
                error << indent;
				error << "From_rank cannot be greater than to_rank." << endl;
                return false;
            }

            if(m_history_product_list.Count() != 0) 
            {
                TemplateNC_PList<String, String>::Iterator iProd(&m_history_product_list);
                TemplateNC_PList<String, String>::Iterator iRating(&m_history_rating_list);

                int pnum=0, pindx;
                int pcount;
                for(iProd.Begin(), iRating.Begin(), pindx = 1;
                    ((*iProd != NULL) && (*iRating != NULL) && (pindx <= stopIndex));
                    ++iProd, ++iRating, ++pindx)
                {
                    if ((pindx >= startIndex) && (pindx <= stopIndex)) 
                    { 
                        pnum++;

                        parameters << "HistProdRN" << pnum << "=" << *(iProd.getElement()) << "&";
                        parameters << "HistRating" << pnum << "=" << *(iRating.getElement()) << "&";
                        debug << indent << "Retrieved product " << *(iProd.getElement()) << " with rating " << *(iRating.getElement()) << endl;

                    }  // if pindx
                }  // for iProd
            }  // if m_history_product_list.Count

            parameters << paramNameResultCode << "=" << m_result_code;
			parameters << "&" << paramNameMerchantRefNum << "=" << m_merchant_rn;
            // lets see if this clears up the vector delete memory problem.
            m_history_product_list.Clean(false);
            m_history_rating_list.Clean(false);

            url << parameters;

            debug << indent << "Redirect to [" << url << "]\n";

 			// Set return code
            Res.setLocation(url, true);     // Load page in SSL mode.
            // Res.setLocation(url, true);     // Load page in SSL mode.

            return true;
        }  // PERS_ENABLED
        else {
            error << indent; 
            error.nls(&_API_PERS_ENGINE_ERROR, msgPersonalizationDisabled) << endl;
            m_result_code = "disabled";
            debug << indent << "Redirect to [" << naURL << "]\n";
            Res.setLocation(naURL, true);
            return true;
        }
    }  // Process()
};

ClassName RatingHistory::_STR_ThisClass("RatingHistory");

static bool Z = 
   NC_CommandManager::GetUniqueInstance().RegisterCommand( "IBM",
                                                           "NC",
                                                           "RatingHistory",
                                                           1.0,
                                                           new RatingHistory );



