#!/bin/ksh
#
# IBM
#
# Net.Commerce
#
# (C) Copyright IBM Corp. 1997, 1998, 1999.
#
# Net.Commerce Version 3.1.2 Database Creation Utility
#
#  Dependencies
#   This utility should be running from the command line
#

if [ -z "${NCPATH}" ]; then
  export NCPATH="/opt/IBMnetc/NetCommerce3"
fi

export dbname="$1"
export logfile="persdemo_migrate.log"

if [ $# -lt 2 ]; then
echo " "
echo "Migrate a database to enable personalization. "
echo
echo "Usage: "
echo " "
echo "pers_migrate merchant_num dbname dbuser dbpass [logfile] "
echo " "
echo "    dbname = Name of the database to migrate "
echo "    merchant_num = merchant reference numb "
echo "    dbuser/dbpass = Login and password for the "
echo "                    specified database "
echo "    logfile = Migration log file. OPTIONAL. "
echo "              DEFAULT is pers_migrate.log "
echo ". "
exit 2
fi


echo "Migrating database $1 to enable personalization "
echo 
echo "If you do not see the message Migration complete"
echo "then please check the logfile $logfile for error "
echo "messages. "
echo ". "

db2 "connect to $dbname" >> $logfile

echo " Adding shoppers..."
db2 -tsvf demomall/persdemo_shoppers.db2.sql >> $logfile
echo " Registering sample commands, tasks and overridable functions... "

echo;
echo Adding mappings between explicit profiling behaviours and GroupLens ratings;
echo;

db2 "delete from task_mer_of where task_rn = (select tkrfnbr from tasks where tkname = 'PROFILE_UPD_PROD' and merchant_rn = $2)" 

db2 "delete from task_mer_of where task_rn = (select tkrfnbr from tasks where tkname = 'PROFILE_UPD_PROD')"



db2 "insert into gl_behrate (beh_rn, mer_rn, rating, r_level, enable) values ((select refnum from behavior where name='X_REMOVE_RATING'), $2, 1, 0, 1)"

db2 "insert into gl_behrate (beh_rn, mer_rn, rating, r_level, enable) values ((select refnum from behavior where name='X_VERY_PLEASED'),$2, 5, 22, 1)"

db2 "insert into gl_behrate (beh_rn, mer_rn, rating, r_level, enable) values ((select refnum from behavior where name='X_PLEASED'), $2,4, 22, 1)"

db2 "insert into gl_behrate (beh_rn, mer_rn, rating, r_level, enable) values ((select refnum from behavior where name='X_SATISFIED'),$2, 3, 22, 1)"

db2 "insert into gl_behrate (beh_rn, mer_rn, rating, r_level, enable) values ((select refnum from behavior where name='X_NEUTRAL'),$2, 2, 22, 1)"

db2 "insert into gl_behrate (beh_rn, mer_rn, rating, r_level, enable) values ((select refnum from behavior where name='X_DISAPPOINTED'), $2,1, 22, 1)"

echo;
echo Adding mappings between explicit profiling behaviours and GroupLens ratings;
echo;

db2 "insert into gl_behrate (beh_rn, mer_rn, rating, r_level, enable) values ((select refnum from behavior where name='ClickOnProduct'), $2, 2, 16, 1)"

db2 "insert into gl_behrate (beh_rn, mer_rn, rating, r_level, enable) values ((select refnum from behavior where name='AddInterestProduct'), $2, 3, 18, 1)"

db2 "insert into gl_behrate (beh_rn, mer_rn, rating, r_level, enable) values ((select refnum from behavior where name='RemoveInterestProduct'), $2 , 3, 18, 1)"

db2 "insert into gl_behrate (beh_rn, mer_rn, rating, r_level, enable) values ((select refnum from behavior where name='OrderProduct'),  $2, 4, 20, 1)"



db2 "insert into task_mer_of (TASK_RN, MERCHANT_RN, OF_RN) values ((select tkrfnbr from tasks where tkname='SELECT_UNRATED_PRODUCTS'), $2,(select refnum from ofs where name='GL_ProfileSelectUnratedProd'))"

db2 "insert into task_mer_of (TASK_RN, MERCHANT_RN, OF_RN) values ((select tkrfnbr from tasks where tkname='GET_RATING_HISTORY'),$2, (select refnum from ofs where name='GL_GetRatingHistory' and  version=1.0 and vendor='IBM' and product='NC'))"


db2 "insert into task_mer_of (TASK_RN, MERCHANT_RN, OF_RN) values ((select tkrfnbr from tasks where tkname='GL_GET_REC_PROD'), $2, (select refnum from ofs where name='GL_GetRecProd'))"

db2 "insert into task_mer_of (TASK_RN, MERCHANT_RN, OF_RN) values ((select tkrfnbr from tasks where tkname='PROFILE_UPD_ATTR'),$2 , (select refnum from ofs where name='GL_ProfileUpdAttr' ))"

db2 "insert into task_mer_of (TASK_RN, MERCHANT_RN, OF_RN) values ((select tkrfnbr from tasks where tkname='GL_GET_REC_PROD_FR_LIST'), $2, (select refnum from ofs where   name='GL_GetRecProdFrList' ))"

db2 "insert into task_mer_of (TASK_RN, MERCHANT_RN, OF_RN) values ((select tkrfnbr from tasks where tkname='REC_PROD_DSP'), $2, (select refnum from ofs where name='TaskDisplay' ))"

db2 "insert into macros (MARFNBR, MAMERNBR, MAFILENAME) values ((select tkrfnbr from tasks where tkname='REC_PROD_DSP'), $2, '/demomall/rcmnd1.d2w')"

db2 "insert into task_mer_of (TASK_RN, MERCHANT_RN, OF_RN) values ((select tkrfnbr from tasks where tkname='GL_REMOVE_PROD_RATINGS'), $2, (select refnum from ofs where name='GL_RemoveProdRatings'))"

db2 "insert into task_mer_of (TASK_RN, MERCHANT_RN, OF_RN) values ((select tkrfnbr from tasks where tkname='PROFILE_UPD_PROD'), $2, (select refnum from ofs where name='GL_ProfileUpdProd'))"


db2 "update merchant set metbase = '/cgi-bin/ncommerce3/EnterMerchant?url=/cgi-bin/ncommerce3/ExecMacro/demomall/6ixth_storefront.d2w/report' where merfnbr = $2"

db2 commit


db2 connect reset >> $logfile


echo "Migration complete."  >> $logfile 
echo   >> $logfile 
echo " Migration complete. "

