#!/bin/ksh
#
# IBM
#
# Net.Commerce
#
# (C) Copyright IBM Corp. 1997, 1998.
#
# Net.Commerce Version 3.1.2 Database Creation Utility
#
#  Dependencies
#  This utility should be running from the command line
#

if [ -z "${NCPATH}" ]; then
  export NCPATH="/opt/IBMnetc/NetCommerce3"
fi

if [ $# -lt 3 ]; then
echo " "
echo "Migrate a database to enable personalization. "
echo
echo "Usage: "
echo " "
echo "pers_migrate dbname dbuser dbpass merchant_num [logfile] "
echo " "
echo "    dbname = Name of the database to migrate "
echo "    dbuser/dbpass = Login and password for the "
echo "                    specified database "
echo "    merchant_num = merchant reference number"
echo "    logfile = Migration log file. OPTIONAL. "
echo "              DEFAULT is pers_migrate.log "
echo ". "
exit 2
fi


if [ "$5" == "" ]; then 
  export logfile="pers_migrate.log"
  rm pers_migrate.log
fi

echo "Migrating database $1 to enable personalization "
echo 
echo "If you do not see the message Migration complete"
echo "then please check the logfile $logfile for error "
echo "messages. "
echo ". "

echo "Adding customer profiling information... "
sqlplus $2/$3 @pers_create.ora.sql $logfile
if [ $? -ne 0 ]; then
  echo "Error running pers_create.ora.sql"
  exit 6
fi
sqlplus $2/$3 @sun/upd_sol_cmdnames.ora.sql $logfile
if [ $? -ne 0 ]; then
  echo "Error running upd_sol_cmdnames.ora.sql"
  exit 6
fi


echo "Adding personalization demo commands "
if [ "$4" != "" ]; then 
sqlplus $2/$3 @demomall/persdemo_shoppers.ora.sql $4 
sqlplus $2/$3 @demomall/persdemo_migrate_6ixth_avenue.ora.sql $4 
sqlplus $2/$3 @demomall/persdemo_register_merchant_tasks.ora.sql $4
fi

if [ $? -ne 0 ]; then
  echo "Error running persdemo_create.ora.sql"
  exit 6
fi


echo "Migration complete."  >> $logfile 
echo   >> $logfile 
echo " Migration complete. "
echo " END ----- Check the log files --------------- "

