/****************************************************************************************/
/*                                                                                      */
/* IBM Confidential                                                                     */
/*                                                                                      */
/* Net.Commerce Source Materials                                                        */
/*                                                                                      */
/* (C) Copyright IBM Corp. 1996, 1997.                                                  */
/*                                                                                      */
/* The source code for this program is not published or otherwise divested of its trade */
/* secrets, irrespective of what has been deposited with the U.S. Copyright Office.     */
/*                                                                                      */
/****************************************************************************************/

#include "commands/commands.pch"
#ifndef _ORDER_DISPLAY_H_
#define _ORDER_DISPLAY_H_


//////////////////////////////////////////////////////////////////////////////////////////
//
// AutoPointers
//
class OrderAutoPointer
{
public:
   OrderAutoPointer(OrderHome& order_home, Order* order) :
      _order_home(order_home), _order(order) { }
   ~OrderAutoPointer() { _order_home.Destroy(_order); }

private:
   OrderHome& _order_home;
   Order*     _order;
};

//////////////////////////////////////////////////////////////////////////////////////////
//
// Utility Class for use by other commands as well: PendingOrderDisplayProcessingUtility
//
//////////////////////////////////////////////////////////////////////////////////////////
class PendingOrderDisplayProcessingUtility : public NC_Void
{
 public:
  PendingOrderDisplayProcessingUtility();
  ~PendingOrderDisplayProcessingUtility();
  void reSet();

  bool Initialize( const HttpRequest& Req, HttpResponse& Res, NC_Environment& Env, 
                   Order* order, const String& shopper_rn );
  bool CheckOrderInventory     (const HttpRequest& Req, HttpResponse& Res, NC_Environment& Env);
  bool UpdateOrderItemPrices   (const HttpRequest& Req, HttpResponse& Res, NC_Environment& Env);
  bool UpdateOrderItemAddresses(const HttpRequest& Req, HttpResponse& Res, NC_Environment& Env);
  bool SaveOrderItems          (const HttpRequest& Req, HttpResponse& Res, NC_Environment& Env);
  bool CreateSubOrders         (const HttpRequest& Req, HttpResponse& Res, NC_Environment& Env);
  bool ComputeOrderTotals      (const HttpRequest& Req, HttpResponse& Res, NC_Environment& Env);
  bool SaveOrder               (const String& lockStatus);

 private:
  DataBase* _db;  // This must be first.

  // Homes
  OrderItemHome   _orderitem_home;
  DestinationHome _destination_home;
  AddressHome     _address_home;

  // The shopper reference number
  String _shopper_rn;

  // The order
  Order* _order;

  // The OrderItems for Order
  OrderItemList* _orderitem_list;
};

//////////////////////////////////////////////////////////////////////////////////////////
//
// User Command : CommandOrderDisplay.
//
//////////////////////////////////////////////////////////////////////////////////////////

class __DLL_NCS_CMD__ CommandOrderDisplay : public NC_Command
{
public:
   CommandOrderDisplay() : _order_status(String("")), _merchant_rn(String("")),
      _order_rn(String("")),
      _order_home(NULL),
      _order(NULL),
      _processing_utility(NULL)
      { }

   ~CommandOrderDisplay() {  }

   void  operator delete( void* p ) { ::delete p; }

public:
   virtual bool CheckParameters( const HttpRequest& Req, 
                                 HttpResponse& Res,
                                 NC_Environment& Env, 
                                 NC_Environment& Resources );
   virtual bool Process(const HttpRequest& Req, HttpResponse& Res, NC_Environment& Env);

private:
   bool FindOrderEntry( const String& shopper_rn, 
                        const String& order_status, 
                        const String& merchant_rn, 
                        const String& order_rn );

protected:
   bool CheckOrderInventory     (const HttpRequest& Req, HttpResponse& Res, NC_Environment& Env);
   bool UpdateOrderItemPrices   (const HttpRequest& Req, HttpResponse& Res, NC_Environment& Env);
   bool UpdateOrderItemAddresses(const HttpRequest& Req, HttpResponse& Res, NC_Environment& Env);
   bool SaveOrderItems          (const HttpRequest& Req, HttpResponse& Res, NC_Environment& Env);
   bool CreateSubOrders         (const HttpRequest& Req, HttpResponse& Res, NC_Environment& Env);
   bool ComputeOrderTotals      (const HttpRequest& Req, HttpResponse& Res, NC_Environment& Env);
   bool SaveOrder               ();
   
   virtual bool DoProcess(const HttpRequest& Req, HttpResponse& Res, NC_Environment& Env);

private:
   // Name-value pair values
   String _order_status;
   String _merchant_rn;
   String _order_rn;

   // Homes
   OrderHome*       _order_home;

protected:
   // The order
   Order* _order;

private:
   PendingOrderDisplayProcessingUtility* _processing_utility;
};


#endif


