/****************************************************************************************/
/*                                                                                      */
/* Licensed Materials - Property of IBM                              			    */
/*                                                                   			    */
/* 5697-D24                                                           			    */
/*                                                                  			    */
/* (c)  Copyright  IBM Corp.  1998, 1999.      All Rights Reserved   			    */
/*                                                                   			    */
/* US Government Users Restricted Rights - Use, duplication or       			    */
/* disclosure restricted by GSA ADP Schedule Contract with IBM Corp. 			    */
/*                                                                                      */
/****************************************************************************************/
//////////////////////////////////////////////////////////////////////////////////////////
// YYMMDD  F/D#   WHO    Description
// ---------------------------------------------------------------------------------------
// 980504  33789  RML
//////////////////////////////////////////////////////////////////////////////////////////
#ifndef NCLogonOptions_h
#define NCLogonOptions_h

// look for StringList typedef -- revisit
typedef TemplateNC_PArray<String, String> StringArray;

class NCLogonOptions {

private:

	static const ConfField	AuthenticationModeKey; 
	static const ConfField	AllowNCAdminKey; 
	static const ConfField	USENCDirectoryKey;
	static const ConfField	LDAPHostNameKey;
	static const ConfField	LDAPPortKey;
	static const ConfField	LDAPAuthenticationMethodKey; 
	static const ConfField	NCShopperAttribsKey; 
	static const ConfField	LDAPAttribsKey; 
	static const ConfField	LDAPSearchNameKey;
	static const int		DefaultLDAPPort;

	StringArray fNC_ShopperAttribs;
	StringArray fLDAP_SchemaAttribs;

	void LoadAttribs();

public:

	enum LDAPAuthenticationMethod 
	{
		NC_LDAP_NONE  = 0,
		NC_LDAP_BASIC = 1,
		NC_LDAP_X509  = 2
	};

	enum AuthenticationMode 
	{
		NC_STANDARD = 1,
		NC_BASIC	= 2,
		NC_X509	= 4
	};
	
	NCLogonOptions();	
	~NCLogonOptions();
	
	inline AuthenticationMode GetAuthenticationMode() const
	{
		const String &str =ConfFile::GetConfValue(AuthenticationModeKey);
		return (AuthenticationMode) atoi(str.c_str());
	}

	inline bool AllowX509AuthenticationMode() const 
	{
		return GetAuthenticationMode() & NCLogonOptions::NC_X509;
	}

	inline bool AllowBasicAuthenticationMode() const 
	{
		return GetAuthenticationMode() & NCLogonOptions::NC_BASIC;
	}

	inline bool AllowStandardAuthenticationMode() const 
	{
		return GetAuthenticationMode() & NCLogonOptions::NC_STANDARD;
	}

	inline bool AllowNCAdmin() const
	{
		const String &str =ConfFile::GetConfValue(AllowNCAdminKey);
		return str == "1";
	}

	inline bool UseNCDirectory() const
	{
		const String &str =ConfFile::GetConfValue(USENCDirectoryKey);
		return str == "1";
	}

	//  ConFile returns String not String&. Bad!!!!! - revist
	inline const String GetLDAPHostName() const
	{
		return ConfFile::GetConfValue(LDAPHostNameKey);
	}

	inline int GetLDAPPort() const
	{
		const String &port =ConfFile::GetConfValue(LDAPPortKey);
		int portNum = atoi(port.c_str());
		if(portNum == 0)
			portNum=DefaultLDAPPort;
		return portNum;
	}

	inline LDAPAuthenticationMethod GetAuthenticationMethod() const
	{
		const String &str =ConfFile::GetConfValue(LDAPAuthenticationMethodKey);
		return (LDAPAuthenticationMethod) atoi(str.c_str());
	}

	inline const StringArray& GetNCShopperAttribs() const
	{
		return fNC_ShopperAttribs;
	}

	inline const StringArray& GetLDAPSchemaAttribs() const
	{
		return fLDAP_SchemaAttribs;
	}

};
#endif

