
/*********************************************************************/
/*                                                                   */
/* Licensed Materials - Property of IBM                              */
/*                                                                   */
/* 5697-D24                                                          */
/*                                                                   */
/* (C) Copyright IBM Corp. 1996, 1998. All Rights Reserved           */
/*                                                                   */
/* US Government Users Restricted Rights - Use, duplication or       */
/* disclosure restricted by GSA, ADP Schedule Contract with IBM Corp.*/
/*                                                                   */
/*********************************************************************/

//////////////////////////////////////////////////////////////////////////////////////////
// Filename: access.h
//
//

#ifndef ACCESS_H
#define ACCESS_H

typedef TemplateNC_PList<String, String> StringList;


/////////////////////////////////////////////////////////////////////////////////////////
//
//  class AccessMode
//
//

class __DLL_NCS_OBJ__ AccessMode : public SQL_Schema
{
public:
   AccessMode(DataBase& db);

public:
   static const StringWithOwnership _STR_T_NAME;
   static const StringWithOwnership _COL_REF_NUM;
   static const StringWithOwnership _COL_MER_REF_NUM;
   static const StringWithOwnership _COL_CMD_REF_NUM;
   static const StringWithOwnership _COL_SSL;
   static const StringWithOwnership _COL_PROTECT;

   static const StringWithOwnership _STR_MERCHANT;
   static const StringWithOwnership _STR_ENABLED;
   static const StringWithOwnership _STR_DISABLED;

public:
   const String& getMerchant(){ return getValue(_COL_MER_REF_NUM); }
   const String& getCommand() { return getValue(_COL_CMD_REF_NUM); }
   bool          getSSL()     { return (getValue(_COL_SSL) == "1" ? true : false); }
   bool          getProtect() { return (getValue(_COL_PROTECT) == "1" ? true : false); }

   void setMerchant(const String& s){ setValue(_COL_MER_REF_NUM, s); }
   void setCommand (const String& s){ setValue(_COL_CMD_REF_NUM, s); }
   void setSSL     (bool b){ setValue(_COL_SSL    , (b == true ? _STR_ENABLED : _STR_DISABLED)); }
   void setProtect (bool b){ setValue(_COL_PROTECT, (b == true ? _STR_ENABLED : _STR_DISABLED)); }

   void CheckMode( const String& command_refnum,
                   StringList& merchants,
                   bool& ssl,
                   bool& protect );
};


/////////////////////////////////////////////////////////////////////////////////////////
//
//  class AccessModeHome
//
//

typedef TemplateNC_PList<AccessMode, String> AccessModeList;

class __DLL_NCS_OBJ__ AccessModeHome : public SQL_SchemaMap<AccessMode>
{
   typedef SQL_SchemaMap<AccessMode> _parent;

public:
   AccessModeHome(DataBase& db) : _parent(db) { }

public:
   AccessMode* Create( const String& command_rn,
                       const String& ssl,
                       const String& protect,
                       const NVPHash& NameValuePairs );
   AccessMode* Lookup(const String& RefNum, const NVPHash& NameValuePairs);
};


/////////////////////////////////////////////////////////////////////////////////////////
//
//  class AccessGroup
//
//

class __DLL_NCS_OBJ__ AccessGroup : public SQL_Schema
{
public:
   AccessGroup(DataBase& db);

public:
   static const StringWithOwnership _STR_T_NAME;
   static const StringWithOwnership _COL_REF_NUM;
   static const StringWithOwnership _COL_MER_REF_NUM;
   static const StringWithOwnership _COL_NAME;
   static const StringWithOwnership _COL_DESC;

   static const StringWithOwnership _STR_USRGRP_T_NAME;
   static const StringWithOwnership _COL_USRGRP_USR_REF_NUM;
   static const StringWithOwnership _COL_USRGRP_GRPU_REF_NUM;
   static const StringWithOwnership _COL_USRGRP_MER_REF_NUM;

   static const StringWithOwnership _STR_CMDGRP_T_NAME;
   static const StringWithOwnership _COL_CMDGRP_GRPC_REF_NUM;
   static const StringWithOwnership _COL_CMDGRP_CMD_REF_NUM;

   static const StringWithOwnership _STR_MERCHANT;

public:
   const String& getRefnum()     { return getValue(_COL_REF_NUM); }
   const String& getMerchant()   { return getValue(_COL_MER_REF_NUM); }
   const String& getName()       { return getValue(_COL_NAME); }
   const String& getDescription(){ return getValue(_COL_DESC); }
   void          setRefnum     (const String& s){ setValue(_COL_REF_NUM     ,s); }
   void          setMerchant   (const String& s){ setValue(_COL_MER_REF_NUM ,s); }
   void          setName       (const String& s){ setValue(_COL_NAME        ,s); }
   void          setDescription(const String& s){ setValue(_COL_DESC        ,s); }

   void CheckAccess( const String& command_refnum,
                     const String& shopper_refnum,
                     StringList& resources,
                     bool& access );
};


/////////////////////////////////////////////////////////////////////////////////////////
//
//  class AccessGroupHome
//
//

typedef TemplateNC_PList<AccessGroup, String> AccessGroupList;

class __DLL_NCS_OBJ__ AccessGroupHome : public SQL_SchemaMap<AccessGroup>
{
   typedef SQL_SchemaMap<AccessGroup> _parent;

public:
   AccessGroupHome(DataBase& db) : _parent(db) { }

public:
   AccessGroup* Create(const String& Name, const NVPHash& NameValuePairs);
   AccessGroup* Lookup(const String& RefNum, const NVPHash& NameValuePairs);
};

#endif

