//<PRE>
#ifndef _addr_book_h_
#define _addr_book_h_


/*********************************************************************/
/*                                                                   */
/* Licensed Materials - Property of IBM                              */
/*                                                                   */
/* 5697-D24                                                          */
/*                                                                   */
/* (C) Copyright IBM Corp. 1996, 1999. All Rights Reserved           */
/*                                                                   */
/* US Government Users Restricted Rights - Use, duplication or       */
/* disclosure restricted by GSA, ADP Schedule Contract with IBM Corp.*/
/*                                                                   */
/*********************************************************************/

///////////////////////////////////////////////////////////////////////////////////////////////////
// Schema for Address Book
///////////////////////////////////////////////////////////////////////////////////////////////////
class StaticSQL;

class __DLL_NCS_OBJ__ Address : public SQL_Schema
 {
   // These two lines are for the static SQL implementation.  They must be put in
   // all files that use this.
   friend class StaticSQL;
   friend class AddressHome;

   static const ClassName _STR_ThisClass        ;  // Strings used for tracing and debugging
   static const FuncName  _STR_Init             ;

   public:
    Address(DataBase& DB);

   public: // Schema column names
    static const StringWithOwnership _COL_TNAME                ;
    static const StringWithOwnership _COL_REF_NUM              ;
    static const StringWithOwnership _COL_SHOPPER_REF_NUM      ;
    static const StringWithOwnership _COL_NICKNAME             ;
    static const StringWithOwnership _COL_TITLE                ;
       static const StringWithOwnership _VAL_TITLE_DR          ;
       static const StringWithOwnership _VAL_TITLE_MR          ;
       static const StringWithOwnership _VAL_TITLE_MRS         ;
       static const StringWithOwnership _VAL_TITLE_MS          ;
       static const StringWithOwnership _VAL_TITLE_N           ;
    static const StringWithOwnership _COL_FLAG                 ;
       static const StringWithOwnership _VAL_FLAG_OLD          ;
       static const StringWithOwnership _VAL_FLAG_CURRENT      ;
    static const StringWithOwnership _COL_LAST_NAME            ;
    static const StringWithOwnership _COL_FIRST_NAME           ;
    static const StringWithOwnership _COL_MIDDLE_NAME          ;
    static const StringWithOwnership _COL_COMP                 ;
    static const StringWithOwnership _COL_PHONE1               ;
    static const StringWithOwnership _COL_PHONE2               ;
    static const StringWithOwnership _COL_FAX                  ;
    static const StringWithOwnership _COL_ADDR1                ;
    static const StringWithOwnership _COL_ADDR2                ;
    static const StringWithOwnership _COL_ADDR3                ;
    static const StringWithOwnership _COL_CITY                 ;
    static const StringWithOwnership _COL_STATE                ;
    static const StringWithOwnership _COL_COUNTRY              ;
    static const StringWithOwnership _COL_ZIP_CODE             ;
    static const StringWithOwnership _COL_EMAIL1               ;
    static const StringWithOwnership _COL_EMAIL2               ;
    static const StringWithOwnership _COL_TIME_CREATED         ;
    static const StringWithOwnership _COL_DAY_PHONE_TYPE       ;
    static const StringWithOwnership _COL_DAY_PHONE_LIST       ;
       static const StringWithOwnership _VAL_DAY_PHONE_LIST_YES;
       static const StringWithOwnership _VAL_DAY_PHONE_LIST_NO ;
    static const StringWithOwnership _COL_EVE_PHONE_TYPE       ;
    static const StringWithOwnership _COL_EVE_PHONE_LIST       ;
       static const StringWithOwnership _VAL_EVE_PHONE_LIST_YES;
       static const StringWithOwnership _VAL_EVE_PHONE_LIST_NO ;
    static const StringWithOwnership _COL_BEST_TIME_PHONE      ;
       static const StringWithOwnership _VAL_BEST_TIME_PHONE_DAY;
       static const StringWithOwnership _VAL_BEST_TIME_PHONE_EVE;
    static const StringWithOwnership _COL_PACKAGE_INSERTS      ;
       static const StringWithOwnership _VAL_PACKAGE_INSERTS_YES;
       static const StringWithOwnership _VAL_PACKAGE_INSERTS_NO;
    static const StringWithOwnership _COL_FIELD1               ;
    static const StringWithOwnership _COL_FIELD2               ;

   public: // Get functions
    const String& getRefNum               (bool Real=true) { return SQL_Schema::getValue(_COL_REF_NUM              , Real); }
    const String& getShopperRefNum        (bool Real=true) { return SQL_Schema::getValue(_COL_SHOPPER_REF_NUM      , Real); }
    const String& getNickname             (bool Real=true) { return SQL_Schema::getValue(_COL_NICKNAME             , Real); }
    const String& getTitle                (bool Real=true) { return SQL_Schema::getValue(_COL_TITLE                , Real); }
             bool isDr                    (bool Real=true) { return SQL_Schema::getValue(_COL_TITLE, Real) == _VAL_TITLE_DR    ; }
             bool isMr                    (bool Real=true) { return SQL_Schema::getValue(_COL_TITLE, Real) == _VAL_TITLE_MR    ; }
             bool isMrs                   (bool Real=true) { return SQL_Schema::getValue(_COL_TITLE, Real) == _VAL_TITLE_MRS   ; }
             bool isMs                    (bool Real=true) { return SQL_Schema::getValue(_COL_TITLE, Real) == _VAL_TITLE_MS    ; }
             bool isN                     (bool Real=true) { return SQL_Schema::getValue(_COL_TITLE, Real) == _VAL_TITLE_N     ; }
    const String& getFlag                 (bool Real=true) { return SQL_Schema::getValue(_COL_FLAG                 , Real); }
             bool isOld                   (bool Real=true) { return SQL_Schema::getValue(_COL_FLAG, Real) == _VAL_FLAG_OLD     ; }
             bool isCurrent               (bool Real=true) { return SQL_Schema::getValue(_COL_FLAG, Real) == _VAL_FLAG_CURRENT ; }
    const String& getLastName             (bool Real=true) { return SQL_Schema::getValue(_COL_LAST_NAME            , Real); }
    const String& getFirstName            (bool Real=true) { return SQL_Schema::getValue(_COL_FIRST_NAME           , Real); }
    const String& getMiddleName           (bool Real=true) { return SQL_Schema::getValue(_COL_MIDDLE_NAME          , Real); }
    const String& getCompany              (bool Real=true) { return SQL_Schema::getValue(_COL_COMP                 , Real); }
    const String& getPhone1               (bool Real=true) { return SQL_Schema::getValue(_COL_PHONE1               , Real); }
    const String& getPhone2               (bool Real=true) { return SQL_Schema::getValue(_COL_PHONE2               , Real); }
    const String& getFax                  (bool Real=true) { return SQL_Schema::getValue(_COL_FAX                  , Real); }
    const String& getAddress1             (bool Real=true) { return SQL_Schema::getValue(_COL_ADDR1                , Real); }
    const String& getAddress2             (bool Real=true) { return SQL_Schema::getValue(_COL_ADDR2                , Real); }
    const String& getAddress3             (bool Real=true) { return SQL_Schema::getValue(_COL_ADDR3                , Real); }
    const String& getCity                 (bool Real=true) { return SQL_Schema::getValue(_COL_CITY                 , Real); }
    const String& getState                (bool Real=true) { return SQL_Schema::getValue(_COL_STATE                , Real); }
    const String& getCountry              (bool Real=true) { return SQL_Schema::getValue(_COL_COUNTRY              , Real); }
    const String& getZip                  (bool Real=true) { return SQL_Schema::getValue(_COL_ZIP_CODE             , Real); }
    const String& getEmail1               (bool Real=true) { return SQL_Schema::getValue(_COL_EMAIL1               , Real); }
    const String& getEmail2               (bool Real=true) { return SQL_Schema::getValue(_COL_EMAIL2               , Real); }
    const String& getTimeCreated          (bool Real=true) { return SQL_Schema::getValue(_COL_TIME_CREATED         , Real); }
    const String& getDayPhoneType         (bool Real=true) { return SQL_Schema::getValue(_COL_DAY_PHONE_TYPE       , Real); }
    const String& getDayPhoneListing      (bool Real=true) { return SQL_Schema::getValue(_COL_DAY_PHONE_LIST       , Real); }
             bool isDayPhoneListed        (bool Real=true) { return SQL_Schema::getValue(_COL_DAY_PHONE_LIST, Real) == _VAL_DAY_PHONE_LIST_YES   ; }
             bool isDayPhoneNotListed     (bool Real=true) { return SQL_Schema::getValue(_COL_DAY_PHONE_LIST, Real) == _VAL_DAY_PHONE_LIST_NO    ; }
    const String& getEveningPhoneType     (bool Real=true) { return SQL_Schema::getValue(_COL_EVE_PHONE_TYPE       , Real); }
    const String& getEveningPhoneListing  (bool Real=true) { return SQL_Schema::getValue(_COL_EVE_PHONE_LIST       , Real); }
             bool isEveningPhoneListed    (bool Real=true) { return SQL_Schema::getValue(_COL_EVE_PHONE_LIST, Real) == _VAL_EVE_PHONE_LIST_YES   ; }
             bool isEveningPhoneNotListed (bool Real=true) { return SQL_Schema::getValue(_COL_EVE_PHONE_LIST, Real) == _VAL_EVE_PHONE_LIST_NO    ; }
    const String& getBestPhoneTime        (bool Real=true) { return SQL_Schema::getValue(_COL_BEST_TIME_PHONE      , Real); }
             bool isBestPhoneTimeDay      (bool Real=true) { return SQL_Schema::getValue(_COL_BEST_TIME_PHONE, Real) == _VAL_BEST_TIME_PHONE_DAY  ; }
             bool isBestPhoneTimeEvening  (bool Real=true) { return SQL_Schema::getValue(_COL_BEST_TIME_PHONE, Real) == _VAL_BEST_TIME_PHONE_EVE  ; }
    const String& getPackageInsertion     (bool Real=true) { return SQL_Schema::getValue(_COL_PACKAGE_INSERTS      , Real); }
             bool isPackageInsertionYes   (bool Real=true) { return SQL_Schema::getValue(_COL_PACKAGE_INSERTS, Real) == _VAL_PACKAGE_INSERTS_YES  ; }
             bool isPackageInsertionNo    (bool Real=true) { return SQL_Schema::getValue(_COL_PACKAGE_INSERTS, Real) == _VAL_PACKAGE_INSERTS_NO   ; }
    const String& getField1               (bool Real=true) { return SQL_Schema::getValue(_COL_FIELD1               , Real); }
    const String& getField2               (bool Real=true) { return SQL_Schema::getValue(_COL_FIELD2               , Real); }

   public: // Set functions
    void setRefNum               (const String& RefNum               ) { SQL_Schema::setValue(_COL_REF_NUM              ,RefNum               ); }
    void setShopperRefNum        (const String& ShopperRefNum        ) { SQL_Schema::setValue(_COL_SHOPPER_REF_NUM      ,ShopperRefNum        ); }
    void setNickname             (const String& Nickname             ) { SQL_Schema::setValue(_COL_NICKNAME             ,Nickname             ); }
    void setTitle                (const String& Title                ) { SQL_Schema::setValue(_COL_TITLE                ,Title                ); }
    void setFlag                 (const String& Flag                 ) { SQL_Schema::setValue(_COL_FLAG                 ,Flag                 ); }
    void setLastName             (const String& LastName             ) { SQL_Schema::setValue(_COL_LAST_NAME            ,LastName             ); }
    void setFirstName            (const String& FirstName            ) { SQL_Schema::setValue(_COL_FIRST_NAME           ,FirstName            ); }
    void setMiddleName           (const String& MiddleName           ) { SQL_Schema::setValue(_COL_MIDDLE_NAME          ,MiddleName           ); }
    void setCompany              (const String& Company              ) { SQL_Schema::setValue(_COL_COMP                 ,Company              ); }
    void setPhone1               (const String& Phone1               ) { SQL_Schema::setValue(_COL_PHONE1               ,Phone1               ); }
    void setPhone2               (const String& Phone2               ) { SQL_Schema::setValue(_COL_PHONE2               ,Phone2               ); }
    void setFax                  (const String& Fax                  ) { SQL_Schema::setValue(_COL_FAX                  ,Fax                  ); }
    void setAddress1             (const String& Address1             ) { SQL_Schema::setValue(_COL_ADDR1                ,Address1             ); }
    void setAddress2             (const String& Address2             ) { SQL_Schema::setValue(_COL_ADDR2                ,Address2             ); }
    void setAddress3             (const String& Address3             ) { SQL_Schema::setValue(_COL_ADDR3                ,Address3             ); }
    void setCity                 (const String& City                 ) { SQL_Schema::setValue(_COL_CITY                 ,City                 ); }
    void setState                (const String& State                ) { SQL_Schema::setValue(_COL_STATE                ,State                ); }
    void setCountry              (const String& Country              ) { SQL_Schema::setValue(_COL_COUNTRY              ,Country              ); }
    void setZip                  (const String& Zip                  ) { SQL_Schema::setValue(_COL_ZIP_CODE             ,Zip                  ); }
    void setEmail1               (const String& Email1               ) { SQL_Schema::setValue(_COL_EMAIL1               ,Email1               ); }
    void setEmail2               (const String& Email2               ) { SQL_Schema::setValue(_COL_EMAIL2               ,Email2               ); }
    void setTimeCreated          (const String& TimeCreated          ) { SQL_Schema::setValue(_COL_TIME_CREATED         ,TimeCreated          ); }
    void setDayPhoneType         (const String& DayPhoneType         ) { SQL_Schema::setValue(_COL_DAY_PHONE_TYPE       ,DayPhoneType         ); }
    void setDayPhoneListing      (const String& DayPhoneListing      ) { SQL_Schema::setValue(_COL_DAY_PHONE_LIST       ,DayPhoneListing      ); }
    void setEveningPhoneType     (const String& EveningPhoneType     ) { SQL_Schema::setValue(_COL_EVE_PHONE_TYPE       ,EveningPhoneType     ); }
    void setEveningPhoneListing  (const String& EveningPhoneListing  ) { SQL_Schema::setValue(_COL_EVE_PHONE_LIST       ,EveningPhoneListing  ); }
    void setBestPhoneTime        (const String& BestPhoneTime        ) { SQL_Schema::setValue(_COL_BEST_TIME_PHONE      ,BestPhoneTime        ); }
    void setPackageInsertion     (const String& PackageInsertion     ) { SQL_Schema::setValue(_COL_PACKAGE_INSERTS      ,PackageInsertion     ); }
    void setField1               (const String& Field1               ) { SQL_Schema::setValue(_COL_FIELD1               ,Field1               ); }
    void setField2               (const String& Field2               ) { SQL_Schema::setValue(_COL_FIELD2               ,Field2               ); }

   public:
    static int CheckAddressRefNum(DataBase& DB, String& AddrRefNum);
    static int Migrate               (DataBase& DB, long OwnerRefNum, long UnregisteredUserRefNum);
 };



class __DLL_NCS_OBJ__ AddressHome : public SQL_SchemaMap<Address>
 {
   #if !defined(AS400)
   static const ClassName _STR_ThisClass;  // Strings used for tracing and debugging
   #endif

   public:
    AddressHome(DataBase& DB) : SQL_SchemaMap<Address>(DB) { }


   public:
    // This method explicitely creates the object in the database on the spot.
    Address* Create(const String& ShopperRefNum, const String& Nickname,
                    const NVPHash& NameValuePairs);
    // This method does not create the object in the database. Combine with Write for
    //same result or delay for better performance.
    Address* Create(const String& ShopperRefNum, const String& Nickname);

    // This method explicitely selects the object in the database on the spot.
    Address* Lookup(const String& RefNum, const NVPHash& NameValuePairs);
    // This method does not explicitely select the object in the database. Combine with Read
    //for same results
    Address* Lookup(const String& RefNum);

    // Given an address ID, returns the most up to date address with the same nickname as the one
    // for the address given. This should be used each time some external process sends in an ID.
    // There is always the chance that between the time that ID was generated, and the time it was
    // received, the address it names was rendered obsolete. This will make sure that you'll have
    // the most up to date address.
    Address* LookupCurrentFromRefNum(const String& ShopperRefNum, const String& RefNum);

    // Retreives the current address for that shopper and nickname. This assumes that
    // there is only one current address. If there are more, a random record is returned
    Address* LookupCurrentFromNickname(const String& ShopperRefNum, const String& NickName);

    // Creates a new address, with the given nickname, for the given shopper.
    // If an address already exists with that nickname, and it is Current, marks it
    // as Old, and create a new object as Current.
    // Assumes that there is only one record that is current. If there are more, only marks
    // as old a random record.
    Address* BackupAndCreateCurrent(const String& ShopperRefNum, const String& Nickname,
                                    const NVPHash& NVP
                                   );
 };




class __DLL_NCS_OBJ__ AddressNVP : public NC_Void
 {
   public:
    //  Name Value Pairs
    static const StringWithOwnership NVP_addr_rn       ;
    static const StringWithOwnership NVP_nickname      ;
    static const StringWithOwnership NVP_title         ;
    static const StringWithOwnership NVP_lname         ;
    static const StringWithOwnership NVP_fname         ;
    static const StringWithOwnership NVP_mname         ;
    static const StringWithOwnership NVP_company       ;
    static const StringWithOwnership NVP_phone1        ;
    static const StringWithOwnership NVP_phone2        ;
    static const StringWithOwnership NVP_fax           ;
    static const StringWithOwnership NVP_addr1         ;
    static const StringWithOwnership NVP_addr2         ;
    static const StringWithOwnership NVP_addr3         ;
    static const StringWithOwnership NVP_city          ;
    static const StringWithOwnership NVP_state         ;
    static const StringWithOwnership NVP_country       ;
    static const StringWithOwnership NVP_zip           ;
    static const StringWithOwnership NVP_email1        ;
    static const StringWithOwnership NVP_email2        ;
    static const StringWithOwnership NVP_dayphonetype  ;
    static const StringWithOwnership NVP_dayphonelisted;
    static const StringWithOwnership NVP_evephonetype  ;
    static const StringWithOwnership NVP_evephonelisted;
    static const StringWithOwnership NVP_besttime      ;
    static const StringWithOwnership NVP_package       ;
    static const StringWithOwnership NVP_field1        ;
    static const StringWithOwnership NVP_field2        ;

   public:
    static bool CreateSchemaNVP(const HttpRequest& Req, NC_Environment& Env,
                                const String& ErrorTask, const String& MerchantRefNum,
                                NVPHash& NameValuePairs
                               );
    static void SetThroughNVP  (const HttpRequest& Req, Address* A             );
 };

#endif
