
/*********************************************************************/
/*                                                                   */
/* Licensed Materials - Property of IBM                              */
/*                                                                   */
/* 5697-D24                                                          */
/*                                                                   */
/* (C) Copyright IBM Corp. 1996, 1999. All Rights Reserved           */
/*                                                                   */
/* US Government Users Restricted Rights - Use, duplication or       */
/* disclosure restricted by GSA, ADP Schedule Contract with IBM Corp.*/
/*                                                                   */
/*********************************************************************/

#ifndef _CATEGORY_SCHEMA_H_
#define _CATEGORY_SCHEMA_H_


/////////////////////////////////////////////////////////////////////////////////////////
//
//  class Category
//

class StaticSQL;

class __DLL_NCS_OBJ__ Category : public SQL_Schema
{
   // These two lines are for the static SQL implementation.  They must be put in
   // all files that use this.
   friend class StaticSQL;
   friend class CategoryHome;

   #if !defined(AS400)
   static const ClassName _STR_ThisClass;  // Strings used for tracing and debugging
   #endif

public:
   Category(DataBase& DB);

public: // Schema column names
   static const StringWithOwnership _COL_TNAME            ;
   static const StringWithOwnership _COL_REF_NUM          ;
   static const StringWithOwnership _COL_MERCHANT_REF_NUM ;
   static const StringWithOwnership _COL_NAME             ;
   static const StringWithOwnership _COL_FIELD1           ;
   static const StringWithOwnership _COL_FIELD2           ;
   static const StringWithOwnership _COL_PUBLISH          ;
      static const StringWithOwnership _VAL_PUBLISH_NOT   ;
      static const StringWithOwnership _VAL_PUBLISH_YES   ;
      static const StringWithOwnership _VAL_PUBLISH_DELETE;
   static const StringWithOwnership _COL_TIME_LAST_UPDATED;
   static const StringWithOwnership _COL_OBJECT_ID        ;
   static const StringWithOwnership _COL_CAT_NUMBER       ;

public: // Get functions
   const String& getRefNum          (bool Real=true) { return SQL_Schema::getValue(_COL_REF_NUM         , Real); }
   const String& getMerchantRefNum  (bool Real=true) { return SQL_Schema::getValue(_COL_MERCHANT_REF_NUM, Real); }
   const String& getName            (bool Real=true) { return SQL_Schema::getValue(_COL_NAME            , Real); }
   const String& getField1          (bool Real=true) { return SQL_Schema::getValue(_COL_FIELD1          , Real); }
   const String& getField2          (bool Real=true) { return SQL_Schema::getValue(_COL_FIELD2          , Real); }
   const String& getPublish         (bool Real=true) { return SQL_Schema::getValue(_COL_PUBLISH         , Real); }
            bool isNotPublished     (bool Real=true) { return SQL_Schema::getValue(_COL_PUBLISH, Real) == _VAL_PUBLISH_NOT   ; }
            bool isPublished        (bool Real=true) { return SQL_Schema::getValue(_COL_PUBLISH, Real) == _VAL_PUBLISH_YES   ; }
            bool isMarkedForDelete  (bool Real=true) { return SQL_Schema::getValue(_COL_PUBLISH, Real) == _VAL_PUBLISH_DELETE; }
   const String& getLastUpdate      (bool Real=true) { return SQL_Schema::getValue(_COL_TIME_LAST_UPDATED, Real); }
   const String& getObjectid        (bool Real=true) { return SQL_Schema::getValue(_COL_OBJECT_ID       , Real); }

public: // Set functions
   void setRefNum          (const String& RefNum          ) { SQL_Schema::setValue(_COL_REF_NUM            ,RefNum          ); }
   void setMerchantRefNum  (const String& MerchantRefNum  ) { SQL_Schema::setValue(_COL_MERCHANT_REF_NUM   ,MerchantRefNum  ); }
   void setName            (const String& Name            ) { SQL_Schema::setValue(_COL_NAME               ,Name            ); }
   void setField1          (const String& Field1          ) { SQL_Schema::setValue(_COL_FIELD1             ,Field1          ); }
   void setField2          (const String& Field2          ) { SQL_Schema::setValue(_COL_FIELD2             ,Field2          ); }
   void setPublish         (const String& Publish         ) { SQL_Schema::setValue(_COL_PUBLISH            ,Publish         ); }
   void setLastUpdate     (const String& LastUpdate       ) { SQL_Schema::setValue(_COL_TIME_LAST_UPDATED  ,LastUpdate      ); }
   void setObjectid       (const String& Objectid         ) { SQL_Schema::setValue(_COL_OBJECT_ID          ,Objectid        ); }
};


class __DLL_NCS_OBJ__ CategoryHome : public SQL_SchemaMap<Category>
 {
   #if !defined(AS400)
   static const ClassName _STR_ThisClass;  // Strings used for tracing and debugging
   #endif

   public:
    CategoryHome(DataBase& DB) : SQL_SchemaMap<Category>(DB) { }


   public:
    Category* Create(const String& MerchantRefNum, const String& Name, const NVPHash& NameValuePairs);
    Category* Create(const String& MerchantRefNum, const String& Name);

    Category* Lookup(const String& RefNum, const NVPHash& NameValuePairs);
    Category* Lookup(const String& RefNum);

    Category* LookupByMerchantAndName(const String& MerchantRefNum, const String& Name,
                                      const NVPHash& NameValuePairs);
    Category* LookupByMerchantAndName(const String& MerchantRefNum, const String& Name);

    Category* LookupByName(const String& CategoryName, const NVPHash& NameValuePairs);
    Category* LookupByNameAndMerchant(const String& CategoryName, const String& Merchant, const NVPHash& NameValuePairs);
 };


/////////////////////////////////////////////////////////////////////////////////////////
//
//  class CategoryDescription
//

class __DLL_NCS_OBJ__ CategoryDescription : public SQL_Schema
 {
   #if !defined(AS400)
   static const ClassName _STR_ThisClass;  // Strings used for tracing and debugging
   #endif
   friend class CategoryDescriptionHome;

   public:
    CategoryDescription(DataBase& DB);

   public: // Schema column names
    static const StringWithOwnership _COL_TNAME              ;
    static const StringWithOwnership _COL_CATEGORY_REF_NUM   ;
    static const StringWithOwnership _COL_SHORT_DESC         ;
    static const StringWithOwnership _COL_LONG_DESC          ;
    static const StringWithOwnership _COL_DISPLAY            ;
    static const StringWithOwnership _COL_SMALL_IMAGE        ;
    static const StringWithOwnership _COL_LARGE_IMAGE        ;
    static const StringWithOwnership _COL_PUBLISH            ;
       static const StringWithOwnership _VAL_PUBLISH_NOT     ;
       static const StringWithOwnership _VAL_PUBLISH_YES     ;
       static const StringWithOwnership _VAL_PUBLISH_DELETE  ;

   public: // Get functions
    const String& getCategoryRefNum  (bool Real=true) { return SQL_Schema::getValue(_COL_CATEGORY_REF_NUM, Real); }
    const String& getShortDescription(bool Real=true) { return SQL_Schema::getValue(_COL_SHORT_DESC      , Real); }
    const String& getLongDescription (bool Real=true) { return SQL_Schema::getValue(_COL_LONG_DESC       , Real); }
    const String& getDisplay         (bool Real=true) { return SQL_Schema::getValue(_COL_DISPLAY         , Real); }
    const String& getSmallImage      (bool Real=true) { return SQL_Schema::getValue(_COL_SMALL_IMAGE     , Real); }
    const String& getLargeImage      (bool Real=true) { return SQL_Schema::getValue(_COL_LARGE_IMAGE     , Real); }
    const String& getPublish         (bool Real=true) { return SQL_Schema::getValue(_COL_PUBLISH         , Real); }
             bool isNotPublished     (bool Real=true) { return SQL_Schema::getValue(_COL_PUBLISH, Real) == _VAL_PUBLISH_NOT   ; }
             bool isPublished        (bool Real=true) { return SQL_Schema::getValue(_COL_PUBLISH, Real) == _VAL_PUBLISH_YES   ; }
             bool isMarkedForDelete  (bool Real=true) { return SQL_Schema::getValue(_COL_PUBLISH, Real) == _VAL_PUBLISH_DELETE; }

   public: // Set functions
    void setCategoryRefNum  (const String& RefNum          ) { SQL_Schema::setValue(_COL_CATEGORY_REF_NUM,RefNum          ); }
    void setShortDescription(const String& ShortDescription) { SQL_Schema::setValue(_COL_SHORT_DESC      ,ShortDescription); }
    void setLongDescription (const String& LongDescription ) { SQL_Schema::setValue(_COL_LONG_DESC       ,LongDescription ); }
    void setDisplay         (const String& Display         ) { SQL_Schema::setValue(_COL_DISPLAY         ,Display         ); }
    void setSmallImage      (const String& SmallImage      ) { SQL_Schema::setValue(_COL_SMALL_IMAGE     ,SmallImage      ); }
    void setLargeImage      (const String& LargeImage      ) { SQL_Schema::setValue(_COL_LARGE_IMAGE     ,LargeImage      ); }
    void setPublish         (const String& Publish         ) { SQL_Schema::setValue(_COL_PUBLISH         ,Publish         ); }
 };


class __DLL_NCS_OBJ__ CategoryDescriptionHome : public SQL_SchemaMap<CategoryDescription>
 {
   #if !defined(AS400)
   static const ClassName _STR_ThisClass;  // Strings used for tracing and debugging
   #endif

   public:
    CategoryDescriptionHome(DataBase& DB) : SQL_SchemaMap<CategoryDescription>(DB) { }

   public:
    CategoryDescription* Create(const String& CategoryRefNum, const NVPHash& NameValuePairs);
    CategoryDescription* Create(const String& CategoryRefNum);

    CategoryDescription* Lookup(const String& RefNum, const NVPHash& NameValuePairs);
    CategoryDescription* Lookup(const String& RefNum);
 };


#endif

