#ifndef _DESTINATION_H_
#define _DESTINATION_H_


/*********************************************************************/
/*                                                                   */
/* Licensed Materials - Property of IBM                              */
/*                                                                   */
/* 5697-D24                                                          */
/*                                                                   */
/* (C) Copyright IBM Corp. 1996, 1999. All Rights Reserved           */
/*                                                                   */
/* US Government Users Restricted Rights - Use, duplication or       */
/* disclosure restricted by GSA, ADP Schedule Contract with IBM Corp.*/
/*                                                                   */
/*********************************************************************/
class StaticSQL;

class __DLL_NCS_OBJ__ Destination : public SQL_Schema
{
   // These two lines are for the static SQL implementation.  They must be put in
   // all files that use this.
   friend class StaticSQL;
   friend class DestinationHome;

public:
  Destination(DataBase& DB);

  static const StringWithOwnership _COL_TNAME;        // value MUST be lower case!
  static const StringWithOwnership _COL_ORDER_REF_NUM;
  static const StringWithOwnership _COL_ADDRESS_REF_NUM;
  static const StringWithOwnership _COL_TOTAL_PROD_PRICE;
  static const StringWithOwnership _COL_TOTAL_PROD_TAX;
  static const StringWithOwnership _COL_TOTAL_SHIPPING_PRICE;
  static const StringWithOwnership _COL_TOTAL_SHIPPING_PRICE_TAX;
  static const StringWithOwnership _COL_CURRENCY;
  static const StringWithOwnership _COL_TAX1;
  static const StringWithOwnership _COL_TAX2;
  static const StringWithOwnership _COL_TAX3;
  static const StringWithOwnership _COL_TAX4;
  static const StringWithOwnership _COL_TAX5;
  static const StringWithOwnership _COL_TAX6;


  const String& getOrderRefNum(void)      { return SQL_Schema::getValue(_COL_ORDER_REF_NUM);}
  const String& getAddressRefNum(void)    { return SQL_Schema::getValue(_COL_ADDRESS_REF_NUM);}
  const String& getTotalPrdPrice(void)    { return SQL_Schema::getValue(_COL_TOTAL_PROD_PRICE);}
  const String& getTotalProdTax(void)     { return SQL_Schema::getValue(_COL_TOTAL_PROD_TAX);}
  const String& getShippingPrice(void)    { return SQL_Schema::getValue(_COL_TOTAL_SHIPPING_PRICE);}
  const String& getShippingPriceTax(void) { return SQL_Schema::getValue(_COL_TOTAL_SHIPPING_PRICE_TAX);}
  const String& getCurrency        (void) { return SQL_Schema::getValue(_COL_CURRENCY                );}
  const String& getTax1(void)             { return SQL_Schema::getValue(_COL_TAX1);}
  const String& getTax2(void)             { return SQL_Schema::getValue(_COL_TAX2);}
  const String& getTax3(void)             { return SQL_Schema::getValue(_COL_TAX3);}
  const String& getTax4(void)             { return SQL_Schema::getValue(_COL_TAX4);}
  const String& getTax5(void)             { return SQL_Schema::getValue(_COL_TAX5);}
  const String& getTax6(void)             { return SQL_Schema::getValue(_COL_TAX6);}

  void setOrderRefNum(const String& val)       { SQL_Schema::setValue(_COL_ORDER_REF_NUM, val);}
  void setAddressRefNum(const String& val)     { SQL_Schema::setValue(_COL_ADDRESS_REF_NUM, val);}
  void setTotalProdPrice(const String& val)    { SQL_Schema::setValue(_COL_TOTAL_PROD_PRICE, val);}
  void setTotalProdTax(const String& val)      { SQL_Schema::setValue(_COL_TOTAL_PROD_TAX, val);}
  void setShippingPrice(const String& val)     { SQL_Schema::setValue(_COL_TOTAL_SHIPPING_PRICE, val);}
  void setShippingPricetTax(const String& val) { SQL_Schema::setValue(_COL_TOTAL_SHIPPING_PRICE_TAX, val);}
  void setCurrency         (const String& val) { SQL_Schema::setValue(_COL_CURRENCY                , val);}
  void setTax1(const String& val)              { SQL_Schema::setValue(_COL_TAX1, val);}
  void setTax2(const String& val)              { SQL_Schema::setValue(_COL_TAX2, val);}
  void setTax3(const String& val)              { SQL_Schema::setValue(_COL_TAX3, val);}
  void setTax4(const String& val)              { SQL_Schema::setValue(_COL_TAX4, val);}
  void setTax5(const String& val)              { SQL_Schema::setValue(_COL_TAX5, val);}
  void setTax6(const String& val)              { SQL_Schema::setValue(_COL_TAX6, val);}

};

typedef TemplateNC_PList<Destination, String> DestinationList;

class __DLL_NCS_OBJ__ DestinationHome : public SQL_SchemaMap<Destination>
 {
   #if !defined(AS400)
    static const ClassName _COL_ThisClass;  // Strings used for tracing and debugging
   #endif

   public:
    DestinationHome(DataBase& DB) : SQL_SchemaMap<Destination>(DB) { }


   public:
    // This method explicitely creates the object in the database on the spot.
    ///////////////////////////////////////////////////////////////////////
    // NOTE: ProductTotal and DiscountTotal are discarded !!!!
    ///////////////////////////////////////////////////////////////////////
    Destination* Create(float ProductTotal, float DiscountTotal,
                        const String& AddressRefNum, const String& OrderRefNum,
                        const NVPHash& NameValuePairs);
    // This method does not create the object in the database. Combine with Write for
    //same result or delay for better performance.
    ///////////////////////////////////////////////////////////////////////
    // NOTE: ProductTotal and DiscountTotal are discarded !!!!
    ///////////////////////////////////////////////////////////////////////
    Destination* Create(float ProductTotal, float DiscountTotal,
                        const String& AddressRefNum, const String& OrderRefNum);

    // This method explicitely selects the object in the database on the spot.
    Destination* Lookup(const String& OrderRefNum, const String& AddresRefNum,
                        const NVPHash& NameValuePairs);
    // This method does not explicitely select the object in the database. Combine with Read
    //for same results
    Destination* Lookup(const String& OrderRefNum, const String& AddresRefNum);

  static int Migrate(Address* address_book, String NewAddressRefNum);
};

#endif
