

/*********************************************************************/
/*                                                                   */
/* Licensed Materials - Property of IBM                              */
/*                                                                   */
/* 5697-D24                                                          */
/*                                                                   */
/* (C) Copyright IBM Corp. 1996, 1999. All Rights Reserved           */
/*                                                                   */
/* US Government Users Restricted Rights - Use, duplication or       */
/* disclosure restricted by GSA, ADP Schedule Contract with IBM Corp.*/
/*                                                                   */
/*********************************************************************/
#ifndef _INTERESTITEM_SCHEMA_H_
#define _INTERESTITEM_SCHEMA_H_


/////////////////////////////////////////////////////////////////////////////////////////
//
//  InterestItem
//
//

class StaticSQL;

class __DLL_NCS_OBJ__ InterestItem : public SQL_Schema
{
   // These two lines are for the static SQL implementation.  They must be put in
   // all files that use this.
   friend class StaticSQL;
   friend class InterestItemHome;

public:
   InterestItem(DataBase& DB);

public:
   // TABLE DEFINIFTION
   static const StringWithOwnership _COL_TNAME;
   static const StringWithOwnership _STR_T_NAME;

   // NOT NULL Fields
   static const StringWithOwnership _COL_SHOPPER_REF_NUM;
   static const StringWithOwnership _COL_PRODUCT_REF_NUM;
   static const StringWithOwnership _COL_MERCHANT_REF_NUM;

   // NULLable fields
   static const StringWithOwnership _COL_PRODUCT_PRICE;
   static const StringWithOwnership _COL_PRICE_CURRENCY;
   static const StringWithOwnership _COL_LAST_UPDATE;
   static const StringWithOwnership _COL_FIELD1_INT;
   static const StringWithOwnership _COL_FIELD2_FL;
   static const StringWithOwnership _COL_FIELD3_STR;

// Gets and Sets
public:
   void setProductRefNum (const String& s){ SQL_Schema::setValue(_COL_PRODUCT_REF_NUM , s); }
   void setShopperRefNum (const String& s){ SQL_Schema::setValue(_COL_SHOPPER_REF_NUM , s); }
   void setMerchantRefNum(const String& s){ SQL_Schema::setValue(_COL_MERCHANT_REF_NUM, s); }
   void setPrice         (const String& s){ SQL_Schema::setValue(_COL_PRODUCT_PRICE   , s); }
   void setCurrency      (const String& s){ SQL_Schema::setValue(_COL_PRICE_CURRENCY  , s); }
   void setLastUpdateTime(const String& s){ SQL_Schema::setValue(_COL_LAST_UPDATE     , s); }
   void setField1        (const String& s){ SQL_Schema::setValue(_COL_FIELD1_INT      , s); }
   void setField2        (const String& s){ SQL_Schema::setValue(_COL_FIELD2_FL       , s); }
   void setField3        (const String& s){ SQL_Schema::setValue(_COL_FIELD3_STR      , s); }

   const String& getProductRefNum (void){ return SQL_Schema::getValue(_COL_PRODUCT_REF_NUM  ); }
   const String& getShopperRefNum (void){ return SQL_Schema::getValue(_COL_SHOPPER_REF_NUM  ); }
   const String& getMerchantRefNum(void){ return SQL_Schema::getValue(_COL_MERCHANT_REF_NUM ); }
   const String& getPrice         (void){ return SQL_Schema::getValue(_COL_PRODUCT_PRICE    ); }
   const String& getCurrency      (void){ return SQL_Schema::getValue(_COL_PRICE_CURRENCY   ); }
   const String& getLastUpdateTime(void){ return SQL_Schema::getValue(_COL_LAST_UPDATE      ); }
   const String& getField1        (void){ return SQL_Schema::getValue(_COL_FIELD1_INT       ); }
   const String& getField2        (void){ return SQL_Schema::getValue(_COL_FIELD2_FL        ); }
   const String& getField3        (void){ return SQL_Schema::getValue(_COL_FIELD3_STR       ); }
};


/////////////////////////////////////////////////////////////////////////////////////////
//
//  InterestItemHome
//
//

typedef TemplateNC_PList<InterestItem, String> InterestItemList;

class __DLL_NCS_OBJ__ InterestItemHome : public SQL_SchemaMap<InterestItem>
{
   typedef SQL_SchemaMap<InterestItem> _parent;

public:
   InterestItemHome(DataBase& db) : _parent(db) { }

public:
    // This method explicitely creates the object in the database on the spot.
   InterestItem* Create( const String& ShopperRefNum,
                         const String& ProductRefNum,
                         const String& MerchantRefNum,
                         const NVPHash& NameValuePairs );
    // This method does not create the object in the database. Combine with Write for
    //same result or delay for better performance.
   InterestItem* Create( const String& ShopperRefNum,
                         const String& ProductRefNum,
                         const String& MerchantRefNum);

    // This method explicitely selects the object in the database on the spot.
   InterestItem* Lookup( const String& ShopperRefNum,
                         const String& ProductRefNum,
                         const NVPHash& NameValuePairs );
    // This method does not explicitely select the object in the database. Combine with Read
    //for same results
   InterestItem* Lookup( const String& ShopperRefNum,
                         const String& ProductRefNum);
};

#endif

