#ifndef _misc_objs_h_
#define _misc_objs_h_


/*********************************************************************/
/*                                                                   */
/* Licensed Materials - Property of IBM                              */
/*                                                                   */
/* 5697-D24                                                          */
/*                                                                   */
/* (C) Copyright IBM Corp. 1996, 1999. All Rights Reserved           */
/*                                                                   */
/* US Government Users Restricted Rights - Use, duplication or       */
/* disclosure restricted by GSA, ADP Schedule Contract with IBM Corp.*/
/*                                                                   */
/*********************************************************************/



class __DLL_NCS_OBJ__ Misc : public NC_Void
 {
   public:
    // If the field named is found in the NVP in Req, sets Value to its value and returns true.
    // An error occurs if CanBeEmpty is false and the parameter is not present or its value is
    //empty. In this case, false is returned. If CanBeEmpty is true, a missing parameter or an
    //empty value is permited.
    static bool CheckFieldExistence              (const HttpRequest& Req, const String& Name,
                                                  String& Value, bool CanBeEmpty);

    // Same as above, but sets an error handler as specified in case of an error.
    static bool CheckFieldExistence              (const HttpRequest& Req, NC_Environment& Env,
                                                  const String& TaskName,
                                                  const String& MerchantRefNum,
                                                  const String& ErrorCode,
                                                  const String& Name,
                                                  String& Value,
                                                  bool CanBeEmpty);

    // Same, but with type checking;
    static bool CheckFieldExistenceLong  (const HttpRequest& Req, const String& Name,
                                          String& Value, bool CanBeEmpty);

    // Same, but with type checking;
    static bool CheckFieldExistenceDouble(const HttpRequest& Req, const String& Name,
                                          String& Value, bool CanBeEmpty);

    // Same, but with type checking;
    static bool CheckFieldExistenceChar  (const HttpRequest& Req, const String& Name,
                                          String& Value, bool CanBeEmpty);

    // Same, but with type checking;
    static bool CheckFieldExistenceLong  (const HttpRequest& Req, NC_Environment& Env,
                                          const String& TaskName,
                                          const String& MerchantRefNum,
                                          const String& ErrorCode,
                                          const String& Name,
                                          String& Value,
                                          bool CanBeEmpty);

    // Same, but with type checking;
    static bool CheckFieldExistenceDouble(const HttpRequest& Req, NC_Environment& Env,
                                          const String& TaskName,
                                          const String& MerchantRefNum,
                                          const String& ErrorCode,
                                          const String& Name,
                                          String& Value,
                                          bool CanBeEmpty);

    // Same, but with type checking;
    static bool CheckFieldExistenceChar  (const HttpRequest& Req, NC_Environment& Env,
                                          const String& TaskName,
                                          const String& MerchantRefNum,
                                          const String& ErrorCode,
                                          const String& Name,
                                          String& Value,
                                          bool CanBeEmpty);

    // Checks that there is no double quotes in the value given. If one is found, sets the error
    //handler.
    static bool CheckFieldForCommandLineInclusion(NC_Environment& Env,
                                                  const String& TaskName,
                                                  const String& MerchantRefNum,
                                                  const String& ErrorCode,
                                                  const String& Name,
                                                  const String& Value);

    // Checks whether the field is only made of alpha numerics or '@', '.', '/', ' '
    static bool CheckFieldIsAlphaNum(NC_Environment& Env,
                                     const String& TaskName,
                                     const String& MerchantRefNum,
                                     const String& ErrorCode,
                                     const String& Name,
                                     String& Value);

    static bool SetErrorHandler                   (NC_Environment& Env,
                                                   const String& TaskName,
                                                   const String& MerchantRefNum,
                                                   const String& ErrorCode,
                                                   const String& ParamName=_STR_EMPTY_);

    static void ClearErrorHandler                 (NC_Environment& Env);

    static bool SetView                           (NC_Environment& Env,
                                                   const String& TaskName,
                                                   const String& MerchantRefNum,
                                                   const String& HandlerName=_STR_EMPTY_);

    // Checks for the given variable in the Environment supplied. If the var is not found,
    // &_ERR_CMD_ERR_BAD_SYSTEM is thrown. If it is not caught, the system will terminate.
    static const NC_Void* CheckEnvironmentVariable(const NC_Environment& Env, const String& Name);

    // Checks for the given variable in the configuration file. If the var is not found,
    // &_ERR_CMD_ERR_BAD_SYSTEM is thrown. If it is not caught, the system will terminate.
    // if CanBeEmpty is set to true, then not finding the var will not result in an error.
    static String CheckConfigurationVariable(const ConfField& Name, bool CanBeEmpty=false);

    // Returns the MacroNVPHash object from the environment. If the object does not already exist,
    // creates a new one and adds it to the environment.
    static NVPHash& GetMacroNVPHash(NC_Environment& Env);

    //determines the merchant reference number in the db from the specified field, sets resources
    static bool GetMerchantRefNumFromProductRefNum      (NC_Environment& Env,
                                                         NC_Environment& Resources,
                                                         const String& ProductRefNum);
    static bool GetMerchantRefNumFromCategoryRefNum     (NC_Environment& Env,
                                                         NC_Environment& Resources,
                                                         const String& CategoryRefNum);
    static bool GetMerchantRefNumFromOrderItemRefNum    (NC_Environment& Env,
                                                         NC_Environment& Resources,
                                                         const String& OrderItemRefNum);
    static bool GetMerchantRefNumFromOrderRefNum        (NC_Environment& Env,
                                                         NC_Environment& Resources,
                                                         const String& OrderRefNum);
    static bool GetMerchantRefNumFromOrderItemAddrRefNum(NC_Environment& Env,
                                                         NC_Environment& Resources,
                                                         String& addr_rn);
    static bool GetMerchantRefNumFromFirstOrder         (NC_Environment& Env,
                                                         NC_Environment& Resources,
                                                         const String& status);
    static bool GetMerchantRefNumFromOrderStatus        (NC_Environment& Env,
                                                         NC_Environment& Resources,
                                                         const String& status);

    static bool GetMerchantRefNumFromProductRefNum  (NC_Environment& Env, NC_Environment& Resources,
                                                     const StringList& SL);
    static bool GetMerchantRefNumFromCategoryRefNum (NC_Environment& Env, NC_Environment& Resources,
                                                     const StringList& SL);
    static bool GetMerchantRefNumFromOrderItemRefNum(NC_Environment& Env, NC_Environment& Resources,
                                                     const StringList& SL);
    static bool GetMerchantRefNumFromOrderRefNum    (NC_Environment& Env, NC_Environment& Resources,
                                                     const StringList& SL);
    static bool GetMerchantRefNumFromShoppingCart   (NC_Environment& Env, NC_Environment& Resources);
    static bool GetMerchantRefNumFromProductSku     (NC_Environment& Env, NC_Environment& Resources,
                                                      const String& sku);
    static bool GetMerchantRefNumFromCategoryName   (NC_Environment& Env, NC_Environment& Resources,
                                                      const String& CategoryName);
    
    // resolves template file name used to send a notification messsage
    // template file names are stored in the same table as d2w macros
    static String ResolveNotifTemplateFileName(const HttpRequest& Req, NC_Environment& Env, const String & TaskName, const String & MerchantRefNum);
    // sends notification message using message profile for the given merchant
    static bool Misc::SendNotificationMessage(int MerchantRefNum, int MessageType, const String & Subject, const String & Contents, int Priority);

    // d34608 start
    static String Misc::GetSiteAdminLogonId(NC_Environment& Env);

public:
    static StringWithOwnership SITE_ADMIN_GROUP_REFNUM;
    // d34608 end
 };


// LDH-NOTE: I am working on a way to wrap calls to tasks. This code is the begining of this effort
//          and remains compiled out until more is done, and proper unit testing is performed.

//#define __PROCESS_TASK_CALLER__

#if defined (__PROCESS_TASK_CALLER__)
class __DLL_NCS_OBJ__ Product;
class __DLL_NCS_OBJ__ Merchant;
class __DLL_NCS_OBJ__ ProcessTask : public NC_Void
 {
   public:
    static const ErrorMsg_Cmd* GET_BASE_UNIT_PRC(const HttpRequest& Req, HttpResponse& Res,
                                                 NC_Environment& Env,
                                                 const Merchant* M,
                                                 const Product*  P,
                                                 String& Price
                                                );

    static const ErrorMsg_Cmd* RESOLVE_SKU(const HttpRequest& Req, HttpResponse& Res, NC_Environment& Env,
                                                 const Merchant* M,
                                           const Product*  P,
                                           String& SkuRefNum
                                          );

    static const ErrorMsg_Cmd* CHK_INV(const HttpRequest& Req, HttpResponse& Res, NC_Environment& Env,
                                                 const Merchant* M,
                                       const Product*  P,
                                       const String& Quantity
                                      );
 };
#endif


#endif

