#ifndef _mshipmod_schema_h_
#define _mshipmod_schema_h_

/*********************************************************************/
/*                                                                   */
/* Licensed Materials - Property of IBM                              */
/*                                                                   */
/* 5697-D24                                                          */
/*                                                                   */
/* (c)  Copyright  IBM Corp.  1998, 1999.      All Rights Reserved   */
/*                                                                   */
/* US Government Users Restricted Rights - Use, duplication or       */
/* disclosure restricted by GSA ADP Schedule Contract with IBM Corp. */
/*********************************************************************/

///////////////////////////////////////////////////////////////////////
// This file is part of Net.Commerce                                 //
// Header file for MerchantShipmode.                                 //
///////////////////////////////////////////////////////////////////////




class StaticSQL;

class __DLL_NCS_OBJ__ MerchantShipmode : public SQL_Schema
 { 
   // These two lines are for the static SQL implementation.  They must be put in
   // all files that use this.
   friend class StaticSQL; 
   friend class MerchantShipmodeHome;

   #if !defined(AS400)
   static const ClassName _STR_ThisClass;  // Strings used for tracing and debugging
   #endif 

   public: 
     // Database against which the object is used. If LoadAll is true, the object loads 
     //all fields at once. Otherwise, loads the minimum set, and will load the others 
     //on demand
    MerchantShipmode(DataBase& DB, bool LoadAll=true);

   public: // Schema column names
    static const StringWithOwnership _COL_TNAME           ;
    static const StringWithOwnership _COL_REF_NUM         ;
    static const StringWithOwnership _COL_SHIPMODE_REF_NUM;
    static const StringWithOwnership _COL_MER_REF_NUM     ;
    static const StringWithOwnership _COL_DATE_AVAILABLE  ;
    static const StringWithOwnership _COL_DATE_UNAVAILABLE;
    static const StringWithOwnership _COL_CUSTOM1         ;
    static const StringWithOwnership _COL_CUSTOM2         ;
	//start d26246
	static const StringWithOwnership _COL_CARRY_SP_REF_NUM;
	//end d26246

   public: // Get functions
    const String& getRefNum         (bool Real=true);
    const String& getShipRefNum     (bool Real=true);
    const String& getMerRefNum      (bool Real=true);
    const String& getDateAvailable  (bool Real=true);
    const String& getDateUnavailable(bool Real=true);
    const String& getCustom1        (bool Real=true);
    const String& getCustom2        (bool Real=true);
	//start d26246
	const String& getCarrySpRefNum  (bool Real=true);
	//end d26246

   public: // Set functions
    void setRefNum         (const String& RefNum         ) { SQL_Schema::setValue(_COL_REF_NUM         ,RefNum         ); }
    void setShipRefNum     (const String& ShipRefNum     ) { SQL_Schema::setValue(_COL_SHIPMODE_REF_NUM,ShipRefNum     ); }
    void setMerRefNum      (const String& MerRefNum      ) { SQL_Schema::setValue(_COL_MER_REF_NUM     ,MerRefNum      ); }
    void setDateAvailable  (const String& DateAvailable  ) { SQL_Schema::setValue(_COL_DATE_AVAILABLE  ,DateAvailable  ); }
    void setDateUnavailable(const String& DateUnavailable) { SQL_Schema::setValue(_COL_DATE_UNAVAILABLE,DateUnavailable); }
    void setCustom1        (const String& Custom1        ) { SQL_Schema::setValue(_COL_CUSTOM1         ,Custom1        ); }
    void setCustom2        (const String& Custom2        ) { SQL_Schema::setValue(_COL_CUSTOM2         ,Custom2        ); }
	//start d26246
	void setCarrySpRefNum  (const String& CarrySpRefNum  ) { SQL_Schema::setValue(_COL_CARRY_SP_REF_NUM,CarrySpRefNum  ); } 
	//end d26246
};



class __DLL_NCS_OBJ__ MerchantShipmodeHome : public SQL_SchemaMap<MerchantShipmode>
 { 
   static const ClassName _STR_ThisClass;  // Strings used for tracing and debugging 
   static const FuncName  _STR_Create; 
   static const FuncName  _STR_Lookup; 

   public: 
    MerchantShipmodeHome(DataBase& DB)  : SQL_SchemaMap<MerchantShipmode>(DB) { }


   public: 
    MerchantShipmode* Create(const NVPHash& NameValuePairs);
    MerchantShipmode* Lookup(const String& RefNum, const NVPHash& NameValuePairs);
 };



class __DLL_NCS_OBJ__ MerchantShipmodeNVP : public NC_Void
 { 
   #if !defined(AS400)
   static const ClassName _STR_ThisClass;  // Strings used for tracing and debugging
   #endif 

   public: 
       static const StringWithOwnership _NVP_REF_NUM      ;
       static const StringWithOwnership _NVP_SHIPMODE_REF_NUM;
       static const StringWithOwnership _NVP_MER_REF_NUM  ;

   public: 
    static bool CreateSchemaNVP(const HttpRequest& Req, NC_Environment& Env,
                                const String& ErrorTask, const String& MerchantRefNum,
                                NVPHash& NameValuePairs
                               );
    static void SetThroughNVP  (const HttpRequest& Req, MerchantShipmode* R);

 };



#endif

