/*********************************************************************/
/* Licensed Materials - Property of IBM                              */
/*                                                                   */
/* 5697-D24                                                          */
/*                                                                   */
/* (c)  Copyright  IBM Corp.  1998, 1999.      All Rights Reserved   */
/*                                                                   */
/* US Government Users Restricted Rights - Use, duplication or       */
/* disclosure restricted by GSA ADP Schedule Contract with IBM Corp. */
/*********************************************************************/
#ifndef _ORDER_H_
#define _ORDER_H_


class StaticSQL;

class __DLL_NCS_OBJ__ Order : public SQL_Schema
{
   // These two lines are for the static SQL implementation.  They must be put in
   // all files that use this.
   friend class StaticSQL;
   friend class OrderHome;

public:
  Order(DataBase& DB);

  static const StringWithOwnership _COL_TNAME;        // value MUST be lower case!
  static const StringWithOwnership _COL_REF_NUM;
  static const StringWithOwnership _COL_SHOPPER_REF_NUM;
  static const StringWithOwnership _COL_MERCHANT_REF_NUM;
  static const StringWithOwnership _COL_MER_ORDER_REF_NUM;
  static const StringWithOwnership _COL_BILL_TO_REF_NUM;
  static const StringWithOwnership _COL_PRODUCT_TOTAL;
  static const StringWithOwnership _COL_PRODUCT_TAX;
  static const StringWithOwnership _COL_SHIPPING_TOTAL;
  static const StringWithOwnership _COL_SHIPPING_TAX;
  static const StringWithOwnership _COL_CURRENCY;
  static const StringWithOwnership _COL_STATUS;
  static const StringWithOwnership _COL_LOCK;
  static const StringWithOwnership _COL_LAST_UPDATE;
  static const StringWithOwnership _COL_PLACED_TIME;
  static const StringWithOwnership _COL_FIELD1;
  static const StringWithOwnership _COL_FIELD2;
  static const StringWithOwnership _COL_FIELD3;

  static const StringWithOwnership _COL_DBV_STATUS_PENDING;
  static const StringWithOwnership _COL_DBV_STATUS_CANCELLED;
  static const StringWithOwnership _COL_DBV_STATUS_COMPLETE;
  static const StringWithOwnership _COL_DBV_LOCKED;    
  static const StringWithOwnership _COL_DBV_UNLOCKED;
  static const StringWithOwnership _COL_DBV_STATUS_NEW;

  

  const String& getRefNum(void) const         { return SQL_Schema::getValue(_COL_REF_NUM              );}
  const String& getShopperRefNum(void) const  { return SQL_Schema::getValue(_COL_SHOPPER_REF_NUM);}
  const String& getMerchantRefNum(void) const { return SQL_Schema::getValue(_COL_MERCHANT_REF_NUM);}
  const String& getMerOrderRefNum(void) const { return SQL_Schema::getValue(_COL_MER_ORDER_REF_NUM);}
  const String& getBillToRefNum(void) const   { return SQL_Schema::getValue(_COL_BILL_TO_REF_NUM);}
  const String& getStatus(void) const         { return SQL_Schema::getValue(_COL_STATUS);}
  const String& getLock(void) const           { return SQL_Schema::getValue(_COL_LOCK);}
  const String& getLastUpdate(void) const     { return SQL_Schema::getValue(_COL_LAST_UPDATE);}
  const String& getPlacedTime(void) const     { return SQL_Schema::getValue(_COL_PLACED_TIME);}
  const String& getProductTotal(void) const   { return SQL_Schema::getValue(_COL_PRODUCT_TOTAL);}
  const String& getProductTax(void) const     { return SQL_Schema::getValue(_COL_PRODUCT_TAX);}
  const String& getShippingTotal(void) const  { return SQL_Schema::getValue(_COL_SHIPPING_TOTAL);}
  const String& getShippingTax(void) const    { return SQL_Schema::getValue(_COL_SHIPPING_TAX);}
  const String& getCurrency(void) const       { return SQL_Schema::getValue(_COL_CURRENCY);}
  const String& getField1(void) const         { return SQL_Schema::getValue(_COL_FIELD1);}
  const String& getField2(void) const         { return SQL_Schema::getValue(_COL_FIELD2);}
  const String& getField3(void) const         { return SQL_Schema::getValue(_COL_FIELD3);}

  void setRefNum(const String& RefNum)                 { SQL_Schema::setValue(_COL_REF_NUM, RefNum); }
  void setShopperRefNum(const String& ShopperRefNum)   { SQL_Schema::setValue(_COL_SHOPPER_REF_NUM, ShopperRefNum);}
  void setStatus(const String& Status)                 { SQL_Schema::setValue(_COL_STATUS, Status);}
  void setMerchantRefNum(const String& MerchantRefNum) { SQL_Schema::setValue(_COL_MERCHANT_REF_NUM , MerchantRefNum);}
  void setMerOrderRefNum(const String& MerOrderRefNum) { SQL_Schema::setValue(_COL_MER_ORDER_REF_NUM, MerOrderRefNum);}
  void setBillToRefNum(const String& BillToRefNum)     { SQL_Schema::setValue(_COL_BILL_TO_REF_NUM, BillToRefNum);}
  void setLock(const String& Lock)                     { SQL_Schema::setValue(_COL_LOCK, Lock);}
  void setLastUpdate(const String& LastUpdate)         { SQL_Schema::setValue(_COL_LAST_UPDATE, LastUpdate);}
  void setPlacedTime(const String& PlacedTime)         { SQL_Schema::setValue(_COL_PLACED_TIME, PlacedTime);}
  void setProductTotal(const String& ProductTotal)     { SQL_Schema::setValue(_COL_PRODUCT_TOTAL, ProductTotal);}
  void setProductTax(const String& ProductTax)         { SQL_Schema::setValue(_COL_PRODUCT_TAX, ProductTax);}
  void setShippingTotal(const String& ShippingTotal)   { SQL_Schema::setValue(_COL_SHIPPING_TOTAL, ShippingTotal);}
  void setShippingTax(const String& ShippingTax)   { SQL_Schema::setValue(_COL_SHIPPING_TAX, ShippingTax);}
  void setCurrency(const String& curr)                 { SQL_Schema::setValue(_COL_CURRENCY, curr);}
  void setField1(const String& Field1)                 { SQL_Schema::setValue(_COL_FIELD1, Field1);}
  void setField2(const String& Field2)                 { SQL_Schema::setValue(_COL_FIELD2, Field2);}
  void setField3(const String& Field3)                 { SQL_Schema::setValue(_COL_FIELD3, Field3);}

  double GetOrderTotal(void) const;
};

typedef TemplateNC_PList<Order, String> OrderList;

class __DLL_NCS_OBJ__ OrderHome : public SQL_SchemaMap<Order>
{ 
  #if !defined(AS400)
   static const ClassName _STR_ThisClass;  // Strings used for tracing and debugging
   #endif 

private:
  OrderItemHome _OrderItemHome;

public: 
  OrderHome(DataBase& DB) : SQL_SchemaMap<Order>(DB), _OrderItemHome(DB) { }

public: 
    // This method explicitely creates the object in the database on the spot.
  Order* Create(const String& ShopperRefNum, const String& MerchantRefNum, const NVPHash& NameValuePairs);
    // This method does not create the object in the database. Combine with Write for
    //same result or delay for better performance.
  Order* Create(const String& ShopperRefNum, const String& MerchantRefNum);

    // This method explicitely selects the object in the database on the spot.
  Order* Lookup(const String& RefNum, const NVPHash& NameValuePairs);
    // This method does not explicitely select the object in the database. Combine with Read
    //for same results
  Order* Lookup(const String& RefNum);

  bool UpdateOrderList(String ShopperRefNum);
};

#endif                                                            
