/*********************************************************************/
/*                                                                   */
/* Licensed Materials - Property of IBM                              */
/*                                                                   */
/* 5697-D24                                                          */
/*                                                                   */
/* (C) Copyright IBM Corp. 1996, 1999. All Rights Reserved           */
/*                                                                   */
/* US Government Users Restricted Rights - Use, duplication or       */
/* disclosure restricted by GSA, ADP Schedule Contract with IBM Corp.*/
/*                                                                   */
/*********************************************************************/

#ifndef _ORDERITEM_SCHEMA_H_
#define _ORDERITEM_SCHEMA_H_


/////////////////////////////////////////////////////////////////////////////////////////
//
//  OrderItem
//
//
class StaticSQL;

class __DLL_NCS_OBJ__ OrderItem : public SQL_Schema
{
   // These two lines are for the static SQL implementation.  They must be put in
   // all files that use this.
   friend class StaticSQL;
   friend class OrderItemHome;

public:
   OrderItem(DataBase& DB);

public:
   // TABLE DEFINIFTION
   static const StringWithOwnership _COL_TNAME;
   static const StringWithOwnership _STR_T_NAME;

   // NOT NULL Fields
   static const StringWithOwnership _COL_REF_NUM;
   static const StringWithOwnership _COL_ADDR_REF_NUM;
   static const StringWithOwnership _COL_SHOPPER_REF_NUM;
   static const StringWithOwnership _COL_MERCHANT_REF_NUM;
   static const StringWithOwnership _COL_PRODUCT_REF_NUM;
   static const StringWithOwnership _COL_QUANTITY;
   static const StringWithOwnership _COL_STATUS;

   // NULLable fields
   static const StringWithOwnership _COL_ORDER_REF_NUM;
   static const StringWithOwnership _COL_PRODUCT_PRICE;
   static const StringWithOwnership _COL_PRICE_CURRENCY;
   static const StringWithOwnership _COL_PRODUCT_CODE;
   static const StringWithOwnership _COL_COMMENT;
   static const StringWithOwnership _COL_CREATION_TIME;
   static const StringWithOwnership _COL_LAST_UPDATE;
   static const StringWithOwnership _COL_SHIP_MODE_REF_NUM;
   static const StringWithOwnership _COL_FIELD1_INT;
   static const StringWithOwnership _COL_FIELD2_STR;
   static const StringWithOwnership _COL_BASE_PRODUCT_PRICE;
   static const StringWithOwnership _COL_BASE_PRICE_CURRENCY;

// Gets and Sets
public:
   void setAddressRefNum (const String& s){ SQL_Schema::setValue(_COL_ADDR_REF_NUM     , s); }
   void setComment       (const String& s){ SQL_Schema::setValue(_COL_COMMENT          , s); }
   void setField1        (const String& s){ SQL_Schema::setValue(_COL_FIELD1_INT       , s); }
   void setField2        (const String& s){ SQL_Schema::setValue(_COL_FIELD2_STR       , s); }
   void setLastUpdateTime(const String& s){ SQL_Schema::setValue(_COL_LAST_UPDATE      , s); }
   void setMerchantRefNum(const String& s){ SQL_Schema::setValue(_COL_MERCHANT_REF_NUM , s); }
   void setOrderRefNum   (const String& s){ SQL_Schema::setValue(_COL_ORDER_REF_NUM    , s); }
   void setCurrency      (const String& s){ SQL_Schema::setValue(_COL_PRICE_CURRENCY   , s); }
   void setTaxCode       (const String& s){ SQL_Schema::setValue(_COL_PRODUCT_CODE     , s); }
   void setPrice         (const String& s){ SQL_Schema::setValue(_COL_PRODUCT_PRICE    , s); }
   void setProductRefNum (const String& s){ SQL_Schema::setValue(_COL_PRODUCT_REF_NUM  , s); }
   void setQuantity      (const String& s){ SQL_Schema::setValue(_COL_QUANTITY         , s); }
   void setShipModeRefNum(const String& s){ SQL_Schema::setValue(_COL_SHIP_MODE_REF_NUM, s); }
   void setShopperRefNum (const String& s){ SQL_Schema::setValue(_COL_SHOPPER_REF_NUM  , s); }
   void setStatus        (const String& s){ SQL_Schema::setValue(_COL_STATUS           , s); }
   void setBasePrice     (const String& s){ SQL_Schema::setValue(_COL_BASE_PRODUCT_PRICE, s); }
   void setBaseCurrency  (const String& s){ SQL_Schema::setValue(_COL_BASE_PRICE_CURRENCY, s); }

   const String& getRefNum        (void){ return SQL_Schema::getValue(_COL_REF_NUM          ); }
   const String& getAddressRefNum (void){ return SQL_Schema::getValue(_COL_ADDR_REF_NUM     ); }
   const String& getComment       (void){ return SQL_Schema::getValue(_COL_COMMENT          ); }
   const String& getCreationTime  (void){ return SQL_Schema::getValue(_COL_CREATION_TIME    ); }
   const String& getField1        (void){ return SQL_Schema::getValue(_COL_FIELD1_INT       ); }
   const String& getField2        (void){ return SQL_Schema::getValue(_COL_FIELD2_STR       ); }
   const String& getLastUpdateTime(void){ return SQL_Schema::getValue(_COL_LAST_UPDATE      ); }
   const String& getMerchantRefNum(void){ return SQL_Schema::getValue(_COL_MERCHANT_REF_NUM ); }
   const String& getOrderRefNum   (void){ return SQL_Schema::getValue(_COL_ORDER_REF_NUM    ); }
   const String& getTaxCode       (void){ return SQL_Schema::getValue(_COL_PRODUCT_CODE     ); }
   const String& getCurrency      (void){ return SQL_Schema::getValue(_COL_PRICE_CURRENCY   ); }
   const String& getPrice         (void){ return SQL_Schema::getValue(_COL_PRODUCT_PRICE    ); }
   const String& getProductRefNum (void){ return SQL_Schema::getValue(_COL_PRODUCT_REF_NUM  ); }
   const String& getQuantitiy     (void){ return SQL_Schema::getValue(_COL_QUANTITY         ); }
   const String& getShipModeRefNum(void){ return SQL_Schema::getValue(_COL_SHIP_MODE_REF_NUM); }
   const String& getShopperRefNum (void){ return SQL_Schema::getValue(_COL_SHOPPER_REF_NUM  ); }
   const String& getStatus        (void){ return SQL_Schema::getValue(_COL_STATUS           ); }
   const String& getBaseCurrency  (void){ return SQL_Schema::getValue(_COL_BASE_PRICE_CURRENCY); }
   const String& getBasePrice     (void){ return SQL_Schema::getValue(_COL_BASE_PRODUCT_PRICE ); }
};


/////////////////////////////////////////////////////////////////////////////////////////
//
//  OrderItemHome
//
//

typedef TemplateNC_PList<OrderItem, String> OrderItemList;

class __DLL_NCS_OBJ__ OrderItemHome : public SQL_SchemaMap<OrderItem>
{
   typedef SQL_SchemaMap<OrderItem> _parent;

public:
   OrderItemHome(DataBase& db) : _parent(db) { }

public:
    // This method explicitely creates the object in the database on the spot.
   OrderItem* Create( const String& AddrRefNum,
                      const String& ShopperRefNum,
                      const String& MerchantRefNum,
                      const String& ProductRefNum,
                      const String& Quantity,
                      const String& Status,
                      const NVPHash& NameValuePairs );
    // This method does not create the object in the database. Combine with Write for
    //same result or delay for better performance.
   OrderItem* Create( const String& AddrRefNum,
                      const String& ShopperRefNum,
                      const String& MerchantRefNum,
                      const String& ProductRefNum,
                      const String& Quantity,
                      const String& Status);
    // This method explicitely selects the object in the database on the spot.
   OrderItem* Lookup(const String& RefNum, const NVPHash& NameValuePairs);
    // This method does not explicitely select the object in the database. Combine with Read
    //for same results
   OrderItem* Lookup(const String& RefNum);

   bool UpdateAddresses(OrderItemList* list, bool write = true);
};

#endif

