#ifndef _ordpaymthd_schema_h_
#define _ordpaymthd_schema_h_
/*********************************************************************/
/* Licensed Materials - Property of IBM                              */
/*                                                                   */
/* 5697-D24                                                          */
/*                                                                   */
/* (c)  Copyright  IBM Corp.  1998, 1999.      All Rights Reserved   */
/*                                                                   */
/* US Government Users Restricted Rights - Use, duplication or       */
/* disclosure restricted by GSA ADP Schedule Contract with IBM Corp. */
/*********************************************************************/
///////////////////////////////////////////////////////////////////////
// This file is part of Net.Commerce                                 //
// Header file for OrdPayMthd.                                               //
///////////////////////////////////////////////////////////////////////
// Change History
// d35082 15/07/1999 SB    Add some error checking



class StaticSQL;

class __DLL_NCS_OBJ__ OrdPayMthd : public SQL_Schema
 { 
   // These two lines are for the static SQL implementation.  They must be put in
   // all files that use this.
   friend class StaticSQL; 
   friend class OrdPayMthdHome;

   #if !defined(AS400)
   static const ClassName _STR_ThisClass;  // Strings used for tracing and debugging
   #endif 

   public: 
     // Database against which the object is used. If LoadAll is true, the object loads 
     //all fields at once. Otherwise, loads the minimum set, and will load the others 
     //on demand
    OrdPayMthd(DataBase& DB, bool LoadAll=true);

   public: // Schema column names
    static const StringWithOwnership _COL_TNAME                  ;
    // static const StringWithOwnership _COL_REF_NUM                ;
    static const StringWithOwnership _COL_ORDER_RN               ;
    static const StringWithOwnership _COL_PAY_MTHD               ;
    static const StringWithOwnership _COL_PAY_ID                 ;
    static const StringWithOwnership _COL_EXP_DATE               ;
    static const StringWithOwnership _COL_ISSUE_DATE             ;
    static const StringWithOwnership _COL_MAX_AMOUNT             ;
    // static const StringWithOwnership _COL_PAY_ID_FORMAT          ;
    // static const StringWithOwnership _VAL_PAY_ID_FORMAT_ENCRYPTED;
    // static const StringWithOwnership _VAL_PAY_ID_FORMAT_PLAIN;

   public: // Get functions
    // const String& getRefNum     (bool Real=true);
    const String& getOrderRefNum(bool Real=true);
    const String& getPayMthd    (bool Real=true);
          String  getPayId      (bool Real=true);
    const String& getExpDate    (bool Real=true);
    const String& getIssueDate  (bool Real=true);
    const String& getMaxAmount  (bool Real=true);
    // const String& getPayIdFormat(bool Real=true);
    // bool          isPayIdFormatEncrypted   (bool Real=true) { return getPayIdFormat(Real) == _VAL_PAY_ID_FORMAT_ENCRYPTED; }

   public: // Set functions
    // void setRefNum     (const String& RefNum                           );
    void setOrderRefNum(const String& OrderRefNum                      );
    void setPayMthd    (const String& PayMthd                          );    
    // d35082 start
    bool setPayId      (const String& PayId      , bool Encrypt = false);
    // d35082 end
    void setExpDate    (const String& ExpDate                          );
    void setIssueDate  (const String& IssueDate                        );
    void setMaxAmount  (const String& MaxAmount                        );
    // void setPayIdFormat(const String& PayIdFormat                      );
 };


/////////////////////////////////////////////////////////////////////////////////////////
//
//  OrdPayMthdHome
//
//

typedef TemplateNC_PList<OrdPayMthd, String> OrdPayMthdList;

class __DLL_NCS_OBJ__ OrdPayMthdHome : public SQL_SchemaMap<OrdPayMthd>
 { 
   static const ClassName _STR_ThisClass;  // Strings used for tracing and debugging 
   static const FuncName  _STR_Create; 
   static const FuncName  _STR_Lookup; 

   public: 
    OrdPayMthdHome(DataBase& DB)  : SQL_SchemaMap<OrdPayMthd>(DB) { }


   public: 
    OrdPayMthd* Create                (const String& OrderRefNum, const String& PayMthd, const String& PayId, const NVPHash& NameValuePairs, bool Encrypt = false /*encrypt PayId*/);
    // OrdPayMthd* Lookup                (const String& RefNum, const NVPHash& NameValuePairs);
    OrdPayMthd* LookupByOrderAndMethod(const String& OrderRefNum, const String& PayMthd, const String& PayId, const NVPHash& NameValuePairs);
 };



class __DLL_NCS_OBJ__ OrdPayMthdNVP : public NC_Void
 { 
   #if !defined(AS400)
   static const ClassName _STR_ThisClass;  // Strings used for tracing and debugging
   #endif 

   public: 
       static const StringWithOwnership _NVP_PAY_MTHD            ;
       static const StringWithOwnership _NVP_PAY_ID              ;
       static const StringWithOwnership _NVP_EXP_MONTH           ;
       static const StringWithOwnership _NVP_EXP_YEAR            ;

   public: 
    static bool CreateSchemaNVP(const HttpRequest& Req, NC_Environment& Env,
                                const String& ErrorTask, const String& MerchantRefNum,
                                NVPHash& NameValuePairs
                               );
    static void SetThroughNVP  (const HttpRequest& Req, OrdPayMthd* R);

 };



#endif

