#ifndef _prod_price_schema_h_
#define _prod_price_schema_h_


/*********************************************************************/
/*                                                                   */
/* Licensed Materials - Property of IBM                              */
/*                                                                   */
/* 5697-D24                                                          */
/*                                                                   */
/* (C) Copyright IBM Corp. 1996, 1999. All Rights Reserved           */
/*                                                                   */
/* US Government Users Restricted Rights - Use, duplication or       */
/* disclosure restricted by GSA, ADP Schedule Contract with IBM Corp.*/
/*                                                                   */
/*********************************************************************/
//////////////////////////////////////////////////////////////////////////////////////////
// Change History
//////////////////////////////////////////////////////////////////////////////////////////
// YYMMDD  F/D#   WHO    Description
// ---------------------------------------------------------------------------------------
// 980727  d26082 lam    Catalog Architect.
//
//////////////////////////////////////////////////////////////////////////////////////////

class StaticSQL;

class __DLL_NCS_OBJ__ ProductPrice : public SQL_Schema
 {
   // These two lines are for the static SQL implementation.  They must be put in
   // all files that use this.
   friend class StaticSQL;
   friend class ProductPriceHome;

   #if !defined(AS400)
   static const ClassName _STR_ThisClass;  // Strings used for tracing and debugging
   #endif

   public:
    ProductPrice(DataBase& DB);

   public: // Schema column names
    static const StringWithOwnership _COL_TNAME                   ;
    static const StringWithOwnership _COL_REF_NUM                 ;
    static const StringWithOwnership _COL_MERCHANT_REF_NUM        ;
    static const StringWithOwnership _COL_PRODUCT_REF_NUM         ;
    static const StringWithOwnership _COL_SHOPPER_GROUP_REF_NUM   ;
    static const StringWithOwnership _COL_PRICE                   ;
    static const StringWithOwnership _COL_CURRENCY                ;
    static const StringWithOwnership _COL_PRECEDENCE              ;
    static const StringWithOwnership _COL_TIME_BEGIN              ;
    static const StringWithOwnership _COL_TIME_END                ;
    static const StringWithOwnership _COL_FIELD1                  ;
    static const StringWithOwnership _COL_FIELD2                  ;
// d26082 start
    static const StringWithOwnership _COL_OBJECT_ID               ;
// d26082 end


   public: // Get functions
    const String& getRefNum            (bool Real=true) { return SQL_Schema::getValue(_COL_REF_NUM                 , Real); }
    const String& getMerchantRefNum    (bool Real=true) { return SQL_Schema::getValue(_COL_MERCHANT_REF_NUM        , Real); }
    const String& getProductRefNum     (bool Real=true) { return SQL_Schema::getValue(_COL_PRODUCT_REF_NUM         , Real); }
    const String& getShopperGroupRefNum(bool Real=true) { return SQL_Schema::getValue(_COL_SHOPPER_GROUP_REF_NUM   , Real); }
    const String& getPrice             (bool Real=true) { return SQL_Schema::getValue(_COL_PRICE                   , Real); }
    const String& getCurrency          (bool Real=true) { return SQL_Schema::getValue(_COL_CURRENCY                , Real); }
    const String& getPrecedence        (bool Real=true) { return SQL_Schema::getValue(_COL_PRECEDENCE              , Real); }
    const String& getTimeBegin         (bool Real=true) { return SQL_Schema::getValue(_COL_TIME_BEGIN              , Real); }
    const String& getTimeEnd           (bool Real=true) { return SQL_Schema::getValue(_COL_TIME_END                , Real); }
    const String& getField1            (bool Real=true) { return SQL_Schema::getValue(_COL_FIELD1                  , Real); }
    const String& getField2            (bool Real=true) { return SQL_Schema::getValue(_COL_FIELD2                  , Real); }
// d26082 start
    const String& getObjectid          (bool Real=true) { return SQL_Schema::getValue(_COL_OBJECT_ID       	   , Real); }
// d26082 end

   public: // Set functions
    void setRefNum            (const String& RefNum            ) { SQL_Schema::setValue(_COL_REF_NUM                 ,RefNum            ); }
    void setMerchantRefNum    (const String& MerchantRefNum    ) { SQL_Schema::setValue(_COL_MERCHANT_REF_NUM        ,MerchantRefNum    ); }
    void setProductRefNum     (const String& ProductRefNum     ) { SQL_Schema::setValue(_COL_PRODUCT_REF_NUM         ,ProductRefNum     ); }
    void setShopperGroupRefNum(const String& ShopperGroupRefNum) { SQL_Schema::setValue(_COL_SHOPPER_GROUP_REF_NUM   ,ShopperGroupRefNum); }
    void setPrice             (const String& Price             ) { SQL_Schema::setValue(_COL_PRICE                   ,Price             ); }
    void setCurrency          (const String& Currency          ) { SQL_Schema::setValue(_COL_CURRENCY                ,Currency          ); }
    void setPrecedence        (const String& Precedence        ) { SQL_Schema::setValue(_COL_PRECEDENCE              ,Precedence        ); }
    void setTimeBegin         (const String& TimeBegin         ) { SQL_Schema::setValue(_COL_TIME_BEGIN              ,TimeBegin         ); }
    void setTimeEnd           (const String& TimeEnd           ) { SQL_Schema::setValue(_COL_TIME_END                ,TimeEnd           ); }
    void setField1            (const String& Field1            ) { SQL_Schema::setValue(_COL_FIELD1                  ,Field1            ); }
    void setField2            (const String& Field2            ) { SQL_Schema::setValue(_COL_FIELD2                  ,Field2            ); }
// d26082 start
    void setObjectid          (const String& Objectid          ) { SQL_Schema::setValue(_COL_OBJECT_ID               ,Objectid          ); }
// d26082 end
 };



class __DLL_NCS_OBJ__ ProductPriceHome : public SQL_SchemaMap<ProductPrice>
 {
   #if !defined(AS400)
   static const ClassName _STR_ThisClass;  // Strings used for tracing and debugging
   #endif

   public:
    ProductPriceHome(DataBase& DB)  : SQL_SchemaMap<ProductPrice>(DB) { }


   public:
    ProductPrice* Create(const String& MerchantRefNum, const String& ShopperGroupRefNum,
                         const String& ProductRefNum, const String& Price, const String& Currency,
                         const NVPHash& NameValuePairs);
    ProductPrice* Create(const String& MerchantRefNum, const String& ShopperGroupRefNum,
                         const String& ProductRefNum, const String& Price, const String& Currency);

    ProductPrice* Lookup(const String& RefNum, const NVPHash& NameValuePairs);
    ProductPrice* Lookup(const String& RefNum);
 };



#endif

