#ifndef _schstatus_schema_h_
#define _schstatus_schema_h_
/*********************************************************************/
/* Licensed Materials - Property of IBM                              */
/*                                                                   */
/* 5697-D24                                                          */
/*                                                                   */
/* (c)  Copyright  IBM Corp.  1998, 1999.      All Rights Reserved   */
/*                                                                   */
/* US Government Users Restricted Rights - Use, duplication or       */
/* disclosure restricted by GSA ADP Schedule Contract with IBM Corp. */
/*********************************************************************/
///////////////////////////////////////////////////////////////////////
// This file is part of Net.Commerce                                 //
// Header file for SchStatus.                                               //
///////////////////////////////////////////////////////////////////////




class StaticSQL;

class __DLL_NCS_OBJ__ SchStatus : public SQL_Schema
 { 
   // These two lines are for the static SQL implementation.  They must be put in
   // all files that use this.
   friend class StaticSQL; 
   friend class SchStatusHome;

   #if !defined(AS400)
   static const ClassName _STR_ThisClass;  // Strings used for tracing and debugging
   #endif 

   public: 
     // Database against which the object is used. If LoadAll is true, the object loads 
     //all fields at once. Otherwise, loads the minimum set, and will load the others 
     //on demand
    SchStatus(DataBase& DB, bool LoadAll=true);

   public: // Schema column names
    static const StringWithOwnership _COL_TNAME         ;
    static const StringWithOwnership _COL_REF_NUM       ;
    static const StringWithOwnership _COL_JOB_NBR       ;
    static const StringWithOwnership _COL_STATE         ;
    static const StringWithOwnership _VAL_STATE_COMPLETE;
    static const StringWithOwnership _VAL_STATE_IDLE    ;
    static const StringWithOwnership _VAL_STATE_RUNNING ;
    static const StringWithOwnership _VAL_STATE_COMPLETE_FAILED ;
   	static const StringWithOwnership _VAL_STATE_IDLE_FAILED		;
    static const StringWithOwnership _VAL_STATE_RUNNING_FAILED  ;
    
	static const StringWithOwnership _COL_PREF_START    ;
    static const StringWithOwnership _COL_ACTUAL_START  ;
    static const StringWithOwnership _COL_RESULT        ;
    static const StringWithOwnership _VAL_RESULT_SUCCESS;
    static const StringWithOwnership _VAL_FAILED_FAILED;
    static const StringWithOwnership _COL_QUEUE         ;
    static const StringWithOwnership _COL_END           ;
    static const StringWithOwnership _COL_ATT_LEFT      ;
    static const StringWithOwnership _COL_SEQUENCE      ;
	static const StringWithOwnership _COL_ID_REC		;


   public: // Get functions
    const String& getRefNum  (bool Real=true);
    const String& getJobNum  (bool Real=true);
    const String& getState   (bool Real=true);
	bool isStateComplete (bool Real=true) { return getState(Real) == _VAL_STATE_COMPLETE; }
	bool isStateIdle     (bool Real=true) { return getState(Real) == _VAL_STATE_IDLE    ; }
	bool isStateRunning  (bool Real=true) { return getState(Real) == _VAL_STATE_RUNNING ; }

	bool isStateCompleteFailed (bool Real=true) { return getState(Real) == _VAL_STATE_COMPLETE_FAILED; }
	bool isStateIdleFailed     (bool Real=true) { return getState(Real) == _VAL_STATE_IDLE_FAILED    ; }
	bool isStateRunningFailed  (bool Real=true) { return getState(Real) == _VAL_STATE_RUNNING_FAILED ; }

	const String& getPrefStart    (bool Real=true);
    const String& getActualStart  (bool Real=true);
    const String& getResult       (bool Real=true);
             bool isResultSuccess  (bool Real=true) { return getResult(Real) == _VAL_RESULT_SUCCESS; }
             bool isResultfailed   (bool Real=true) { return getResult(Real) == _VAL_FAILED_FAILED; }
    const String& getQueue   (bool Real=true);
    const String& getEnd     (bool Real=true);
    const String& getAttLeft (bool Real=true);
    const String& getSequence(bool Real=true);
	const String& getIdRecov (bool Real=true);

	 
   public: // Set functions
    void setRefNum      (const String& RefNum  );
    void setJobNum      (const String& JobNum  );
    void setState       (const String& State   );
    void setPrefStart   (const String& Start   );
    void setActualStart (const String& Start   );
    void setResult      (const String& Result  );
    void setQueue       (const String& Queue   );
    void setEnd         (const String& End     );
    void setAttLeft     (const String& AttLeft );
    void setSequence    (const String& Sequence);
	void setIdRecov     (const String& IdRecov) ;
};



typedef TemplateNC_PList<SchStatus, String> SchStatusList;

class __DLL_NCS_OBJ__ SchStatusHome : public SQL_SchemaMap<SchStatus>
 { 
   static const ClassName _STR_ThisClass;  // Strings used for tracing and debugging 
   static const FuncName  _STR_Create; 
   static const FuncName  _STR_Lookup; 

   public: 
    SchStatusHome(DataBase& DB)  : SQL_SchemaMap<SchStatus>(DB) { }


   public: 
    SchStatus* Create               (const String& JobNum, const String&  State, const String& Start, const String& Sequence,const String& AttLeft,const String& JobIdRec, const NVPHash& NameValuePairs);
    SchStatus* Lookup               (const String& RefNum, const NVPHash& NameValuePairs);
    SchStatus* LookupByQueueAndState(const String& Queue,  const String&  State, const NVPHash& NameValuePairs);
 };






#endif

