#ifndef _shipmode_schema_h_
#define _shipmode_schema_h_

/*********************************************************************/
/*                                                                   */
/* Licensed Materials - Property of IBM                              */
/*                                                                   */
/* 5697-D24                                                          */
/*                                                                   */
/* (c)  Copyright  IBM Corp.  1998, 1999.      All Rights Reserved   */
/*                                                                   */
/* US Government Users Restricted Rights - Use, duplication or       */
/* disclosure restricted by GSA ADP Schedule Contract with IBM Corp. */
/*********************************************************************/

///////////////////////////////////////////////////////////////////////
// This file is part of Net.Commerce                                 //
// Header file for Shipmode.                                         //
///////////////////////////////////////////////////////////////////////




class StaticSQL;

class __DLL_NCS_OBJ__ Shipmode : public SQL_Schema
 { 
   // These two lines are for the static SQL implementation.  They must be put in
   // all files that use this.
   friend class StaticSQL; 
   friend class ShipmodeHome;

   #if !defined(AS400)
   static const ClassName _STR_ThisClass;  // Strings used for tracing and debugging
   #endif 

   public: 
     // Database against which the object is used. If LoadAll is true, the object loads 
     //all fields at once. Otherwise, loads the minimum set, and will load the others 
     //on demand
    Shipmode(DataBase& DB, bool LoadAll=true);

   public: // Schema column names
    static const StringWithOwnership _COL_TNAME           ;
    static const StringWithOwnership _COL_REF_NUM         ;
    static const StringWithOwnership _COL_CARRIER_ID      ;
    static const StringWithOwnership _COL_SHIPPING_MODE   ;
    static const StringWithOwnership _COL_MODE_DESCRIPTION;
    static const StringWithOwnership _COL_CUSTOM1         ;
    static const StringWithOwnership _COL_CUSTOM2         ;
	//start d26246
	static const StringWithOwnership _COL_TRACK_NAME;
	static const StringWithOwnership _COL_TRACK_URL;
	static const StringWithOwnership _COL_SOCK_HOST;
	static const StringWithOwnership _COL_SOCK_PORT;
	static const StringWithOwnership _COL_TRACK_ICON;
	static const StringWithOwnership _COL_INQ_TYPE;
	//end d26246

   public: // Get functions
    const String& getRefNum         (bool Real=true);
    const String& getCarrierID      (bool Real=true);
    const String& getShippingMode   (bool Real=true);
    const String& getModeDescription(bool Real=true);
    const String& getCustom1        (bool Real=true);
    const String& getCustom2        (bool Real=true);
	//start d26246
	const String& getTrackName      (bool Real=true);
	const String& getTrackUrl       (bool Real=true);
	const String& getSockHost       (bool Real=true);
	const String& getSockPort       (bool Real=true);
	const String& getTrackIcon      (bool Real=true);
	const String& getInqType        (bool Real=true);
	//end d26246

   public: // Set functions
    void setRefNum         (const String& RefNum         ) { SQL_Schema::setValue(_COL_REF_NUM         ,RefNum         ); }
    void setCarrierID      (const String& CarrierID      ) { SQL_Schema::setValue(_COL_CARRIER_ID      ,CarrierID      ); }
    void setShippingMode   (const String& ShippingMode   ) { SQL_Schema::setValue(_COL_SHIPPING_MODE   ,ShippingMode   ); }
    void setModeDescription(const String& ModeDescription) { SQL_Schema::setValue(_COL_MODE_DESCRIPTION,ModeDescription); }
    void setCustom1        (const String& Custom1        ) { SQL_Schema::setValue(_COL_CUSTOM1         ,Custom1        ); }
    void setCustom2        (const String& Custom2        ) { SQL_Schema::setValue(_COL_CUSTOM2         ,Custom2        ); }
	//start d26246
	void setTrackName      (const String& TrackName      ) { SQL_Schema::setValue(_COL_TRACK_NAME      ,TrackName      ); }
	void setTrackUrl       (const String& TrackUrl       ) { SQL_Schema::setValue(_COL_TRACK_URL       ,TrackUrl       ); }
	void setSockHost       (const String& SockHost       ) { SQL_Schema::setValue(_COL_SOCK_HOST       ,SockHost       ); }
	void setSockPort       (const String& SockPort       ) { SQL_Schema::setValue(_COL_SOCK_PORT       ,SockPort       ); }
	void setTrackIcon      (const String& TrackIcon      ) { SQL_Schema::setValue(_COL_TRACK_ICON      ,TrackIcon      ); }
	void setInqType        (const String& InqType        ) { SQL_Schema::setValue(_COL_INQ_TYPE        ,InqType        ); }
	//end d26246
 };



class __DLL_NCS_OBJ__ ShipmodeHome : public SQL_SchemaMap<Shipmode>
 { 
   static const ClassName _STR_ThisClass;  // Strings used for tracing and debugging 
   static const FuncName  _STR_Create; 
   static const FuncName  _STR_Lookup; 

   public: 
    ShipmodeHome(DataBase& DB)  : SQL_SchemaMap<Shipmode>(DB) { }


   public: 
    Shipmode* Create(const NVPHash& NameValuePairs);
    Shipmode* Lookup(const String& RefNum, const NVPHash& NameValuePairs);
 };



class __DLL_NCS_OBJ__ ShipmodeNVP : public NC_Void
 { 
   #if !defined(AS400)
   static const ClassName _STR_ThisClass;  // Strings used for tracing and debugging
   #endif

   public: 
       static const StringWithOwnership _NVP_REF_NUM      ;

   public: 
    static bool CreateSchemaNVP(const HttpRequest& Req, NC_Environment& Env,
                                const String& ErrorTask, const String& MerchantRefNum,
                                NVPHash& NameValuePairs
                               );
    static void SetThroughNVP  (const HttpRequest& Req, Shipmode* R);

 };



#endif

