//<PRE>
#ifndef _USER_H_
#define _USER_H_


/*********************************************************************/
/*                                                                   */
/* Licensed Materials - Property of IBM                              */
/*                                                                   */
/* 5697-D24                                                          */
/*                                                                   */
/* (C) Copyright IBM Corp. 1996, 1999. All Rights Reserved           */
/*                                                                   */
/* US Government Users Restricted Rights - Use, duplication or       */
/* disclosure restricted by GSA, ADP Schedule Contract with IBM Corp.*/
/*                                                                   */
/*********************************************************************/
// This was mover out of the class definition because of a bug in VC++ 5.0
enum UserRegistrationStatus { E_USER_REGISTERED, E_USER_UNREGISTERED };


////////////////////////////////////////////////////////////////////////////////////////////////////
// Schema for the SHOPPER table
////////////////////////////////////////////////////////////////////////////////////////////////////
class StaticSQL;

class __DLL_NCS_OBJ__ User: public SQL_Schema
 {
   // These two lines are for the static SQL implementation.  They must be put in
   // all files that use this.
   friend class StaticSQL;
   friend class UserHome;

   static const ClassName _STR_ThisClass        ;  // Strings used for tracing and debugging
   static const FuncName  _STR_Init             ;
   static const FuncName  _STR_CreateNewUser    ;
   static const FuncName  _STR_Register         ;

   public:
    static const StringWithOwnership _STR_SESSION;

   public:
    User(DataBase& DB);

   public: // Schema column names
    static const StringWithOwnership _COL_TNAME                ;
    static const StringWithOwnership _COL_REF_NUM              ;
    static const StringWithOwnership _COL_ID                   ;
    static const StringWithOwnership _COL_PASSWORD             ;
    static const StringWithOwnership _COL_TYPE                 ;
       static const StringWithOwnership _VAL_TYPE_GUEST        ;
       static const StringWithOwnership _VAL_TYPE_REGISTERED   ;
       static const StringWithOwnership _VAL_TYPE_ADMIN        ;
    static const StringWithOwnership _COL_COMM                 ;
    static const StringWithOwnership _COL_PHLIST               ;
    static const StringWithOwnership _COL_TIME_LAST_VISIT      ;
    static const StringWithOwnership _COL_TIME_LAST_ORDER      ;
    static const StringWithOwnership _COL_TIME_REGISTERED      ;
    static const StringWithOwnership _COL_TIME_REG_CANCELED    ;
    static const StringWithOwnership _COL_TIME_REG_CHANGE      ;
    static const StringWithOwnership _COL_CNTCT                ;
    static const StringWithOwnership _COL_CHALLENGE_QUESTION   ;
    static const StringWithOwnership _COL_CHALLENGE_ANSWER     ;
    static const StringWithOwnership _COL_FIELD1               ;
    static const StringWithOwnership _COL_FIELD2               ;
    static const StringWithOwnership _COL_PREFERRED_CURRENCY   ;

   public: // Get functions
    const String& getRefNum           (bool Real=true) { return SQL_Schema::getValue(_COL_REF_NUM           , Real); }
    const String& getName             (bool Real=true) { return SQL_Schema::getValue(_COL_ID                , Real); }
    const String& getPassword         (bool Real=true) { return SQL_Schema::getValue(_COL_PASSWORD          , Real); }
    const String& getType             (bool Real=true) { return SQL_Schema::getValue(_COL_TYPE              , Real); }
             bool isGuest             (bool Real=true) { return SQL_Schema::getValue(_COL_TYPE, Real) == _VAL_TYPE_GUEST     ; }
             bool isRegistered        (bool Real=true) { return SQL_Schema::getValue(_COL_TYPE, Real) == _VAL_TYPE_REGISTERED; }
             bool isAdmin             (bool Real=true) { return SQL_Schema::getValue(_COL_TYPE, Real) == _VAL_TYPE_ADMIN     ; }
    const String& getComm             (bool Real=true) { return SQL_Schema::getValue(_COL_COMM              , Real); }
    const String& getPhList           (bool Real=true) { return SQL_Schema::getValue(_COL_PHLIST            , Real); }
    const String& getLastVisit        (bool Real=true) { return SQL_Schema::getValue(_COL_TIME_LAST_VISIT   , Real); }
    const String& getLastOrder        (bool Real=true) { return SQL_Schema::getValue(_COL_TIME_LAST_ORDER   , Real); }
    const String& getTimeRegistered   (bool Real=true) { return SQL_Schema::getValue(_COL_TIME_REGISTERED   , Real); }
    const String& getTimeCanceled     (bool Real=true) { return SQL_Schema::getValue(_COL_TIME_REG_CANCELED , Real); }
    const String& getLastChanged      (bool Real=true) { return SQL_Schema::getValue(_COL_TIME_REG_CHANGE   , Real); }
    const String& getIBM_Contact      (bool Real=true) { return SQL_Schema::getValue(_COL_CNTCT             , Real); }
    const String& getChallengeQuestion(bool Real=true) { return SQL_Schema::getValue(_COL_CHALLENGE_QUESTION, Real); }
    const String& getChallengeAnswer  (bool Real=true) { return SQL_Schema::getValue(_COL_CHALLENGE_ANSWER  , Real); }
    const String& getField1           (bool Real=true) { return SQL_Schema::getValue(_COL_FIELD1            , Real); }
    const String& getField2           (bool Real=true) { return SQL_Schema::getValue(_COL_FIELD2            , Real); }
    const String& getPreferredCurrency(bool Real=true) { return SQL_Schema::getValue(_COL_PREFERRED_CURRENCY, Real); }

   public: // Set functions
    void setRefNum           (const String& RefNum           ) { SQL_Schema::setValue(_COL_REF_NUM              ,RefNum           ); }
    void setName             (const String& Name             ) { SQL_Schema::setValue(_COL_ID                   ,Name             ); }
    void setPassword         (const String& Password, const String& MerchantKey);
    void setType             (const String& Type             ) { SQL_Schema::setValue(_COL_TYPE                 ,Type             ); }
    void setComm             (const String& Comm             ) { SQL_Schema::setValue(_COL_COMM                 ,Comm             ); }
    void setPhList           (const String& PhList           ) { SQL_Schema::setValue(_COL_PHLIST               ,PhList           ); }
    void setLastVisit        (const String& LastVisit        ) { SQL_Schema::setValue(_COL_TIME_LAST_VISIT      ,LastVisit        ); }
    void setLastOrder        (const String& LastOrder        ) { SQL_Schema::setValue(_COL_TIME_LAST_ORDER      ,LastOrder        ); }
    void setTimeRegistered   (const String& TimeRegistered   ) { SQL_Schema::setValue(_COL_TIME_REGISTERED      ,TimeRegistered   ); }
    void setTimeCanceled     (const String& TimeCanceled     ) { SQL_Schema::setValue(_COL_TIME_REG_CANCELED    ,TimeCanceled     ); }
    void setLastChanged      (const String& LastChanged      ) { SQL_Schema::setValue(_COL_TIME_REG_CHANGE      ,LastChanged      ); }
    void setIBM_Contact      (const String& IBM_Contact      ) { SQL_Schema::setValue(_COL_CNTCT                ,IBM_Contact      ); }
    void setChallengeQuestion(const String& ChallengeQuestion) { SQL_Schema::setValue(_COL_CHALLENGE_QUESTION   ,ChallengeQuestion); }
    void setChallengeAnswer  (const String& ChallengeAnswer  ) { SQL_Schema::setValue(_COL_CHALLENGE_ANSWER     ,ChallengeAnswer  ); }
    void setField1           (const String& Field1           ) { SQL_Schema::setValue(_COL_FIELD1               ,Field1           ); }
    void setField2           (const String& Field2           ) { SQL_Schema::setValue(_COL_FIELD2               ,Field2           ); }
    void setPreferredCurrency(const String& Currency         ) { SQL_Schema::setValue(_COL_PREFERRED_CURRENCY   ,Currency         ); }

   protected:
    String GenerateClearSession(void) const;

   public:
    int Refresh(void);

   public:
    //  Transfer all the "possessions" of user U (interest items, addresses, order item, orders)
    // to this user.
    bool TransferAllFrom(User& U);
    // Creates an encrypted Session token for the user. Can be used as a cookie etc....
    String GenerateEncryptedSession(const String& MerchantKey) const;
    // Given am encrypted Session, authenticates it is the current one for that user.
    bool CheckSession (const String& MerchantKey, const String& EncryptedSession) const;
 };




class __DLL_NCS_OBJ__ UserHome : public SQL_SchemaMap<User>
 {
   static const ClassName _STR_ThisClass;  // Strings used for tracing and debugging
   static const FuncName  _STR_GenerateNewUserID;

   public:
    UserHome(DataBase& DB) : SQL_SchemaMap<User>(DB) { }


   public:
    User* Create(const String& Name, const String& Type, const NVPHash& NameValuePairs);
    User* Create(const String& Name, const String& Type);

    User* Lookup(const String& RefNum, const NVPHash& NameValuePairs);
    User* Lookup(const String& RefNum);

    User* LookupByName(const String& Name, const NVPHash& NameValuePairs);
    User* LookupByName(const String& Name);

    User* LookupAndAuthenticate(const String& Name, const String& Password, const String& MerchantKey);
    bool  VerifyUserPassword(const String& UPassword, const String& VerifyPassword, const String& MerchantKey);

   protected:
    static bool   RegistrationCheck(DataBase& DB, const String& PartialWhereClause);
    static String GenerateNewUserID(const String& ShopperRefNum);

   public:
    static bool   CreateUser           (const HttpRequest& Req, HttpResponse& Res, NC_Environment& Env, User*& _Shopper);
    static bool   isRegistered         (DataBase& DB, const String& UserID);
    static bool   isRegistered         (DataBase& DB, long  UserRefNum    );
    static long   getUserRefNum        (DataBase& DB, const String& UserID);
    static String getUserID            (DataBase& DB, long  UserRefNum    );
    static long   getShopperGroupRefNum(DataBase& DB, long  UserRefNum, long MerchantRefNum);


  static User* Init(const String& VerifiedID, const String& UnverifiedID, NC_KeyManager& Keys);
 };


class __DLL_NCS_OBJ__ UserNVP : public NC_Void
 {
   public:
    static const StringWithOwnership NVP_logid      ;
    static const StringWithOwnership NVP_password   ;
    static const StringWithOwnership NVP_comm       ;
    static const StringWithOwnership NVP_challenge_q;
    static const StringWithOwnership NVP_challenge_r;
    static const StringWithOwnership NVP_field1     ;
    static const StringWithOwnership NVP_field2     ;

   public:
    static bool CreateSchemaNVP(const HttpRequest& Req, NC_Environment& Env,
                                const String& ErrorTask, const String& MerchantRefNum,
                                NVPHash& NameValuePairs);
    static void SetThroughNVP  (const HttpRequest& Req, User* U);
 };



#endif



