#ifndef _user_grp_schema_h_
#define _user_grp_schema_h_


/*********************************************************************/
/*                                                                   */
/* Licensed Materials - Property of IBM                              */
/*                                                                   */
/* 5697-D24                                                          */
/*                                                                   */
/* (C) Copyright IBM Corp. 1996, 1999. All Rights Reserved           */
/*                                                                   */
/* US Government Users Restricted Rights - Use, duplication or       */
/* disclosure restricted by GSA, ADP Schedule Contract with IBM Corp.*/
/*                                                                   */
/*********************************************************************/
//////////////////////////////////////////////////////////////////////////////////////////
// Change History
//////////////////////////////////////////////////////////////////////////////////////////
// YYMMDD  F/D#   WHO    Description
// ---------------------------------------------------------------------------------------
// 980727  d26082 lam    Catalog Architect.
//
//////////////////////////////////////////////////////////////////////////////////////////

class StaticSQL;

class __DLL_NCS_OBJ__ UserGroup : public SQL_Schema
 {
   // These two lines are for the static SQL implementation.  They must be put in
   // all files that use this.
   friend class StaticSQL;
   friend class UserGroupHome;

   #if !defined(AS400)
   static const ClassName _STR_ThisClass;  // Strings used for tracing and debugging
   #endif

   public:
    UserGroup(DataBase& DB);

   public: // Schema column names
    static const StringWithOwnership _COL_TNAME              ;
    static const StringWithOwnership _COL_REF_NUM            ;
    static const StringWithOwnership _COL_MERCHANT_REF_NUM   ;
    static const StringWithOwnership _COL_NAME               ;
    static const StringWithOwnership _COL_TEXT               ;
    static const StringWithOwnership _COL_FIELD1             ;
    static const StringWithOwnership _COL_FIELD2             ;
// d26082 start
    static const StringWithOwnership _COL_OBJECT_ID         ;
// d26082 end

   public: // Get functions
    const String& getRefNum        (bool Real=true) { return SQL_Schema::getValue(_COL_REF_NUM         , Real); }
    const String& getMerchantRefNum(bool Real=true) { return SQL_Schema::getValue(_COL_MERCHANT_REF_NUM, Real); }
    const String& getName          (bool Real=true) { return SQL_Schema::getValue(_COL_NAME            , Real); }
    const String& getText          (bool Real=true) { return SQL_Schema::getValue(_COL_TEXT            , Real); }
    const String& getField1        (bool Real=true) { return SQL_Schema::getValue(_COL_FIELD1          , Real); }
    const String& getField2        (bool Real=true) { return SQL_Schema::getValue(_COL_FIELD2          , Real); }
// d26082 start
    const String& getObjectid      (bool Real=true) { return SQL_Schema::getValue(_COL_OBJECT_ID		 , Real); }
// d26082 end

   public: // Set functions
    void setRefNum        (const String& RefNum        ) { SQL_Schema::setValue(_COL_REF_NUM            ,RefNum        ); }
    void setMerchantRefNum(const String& MerchantRefNum) { SQL_Schema::setValue(_COL_MERCHANT_REF_NUM   ,MerchantRefNum); }
    void setName          (const String& Name          ) { SQL_Schema::setValue(_COL_NAME               ,Name          ); }
    void setText          (const String& Text          ) { SQL_Schema::setValue(_COL_TEXT               ,Text          ); }
    void setField1        (const String& Field1        ) { SQL_Schema::setValue(_COL_FIELD1             ,Field1        ); }
    void setField2        (const String& Field2        ) { SQL_Schema::setValue(_COL_FIELD2             ,Field2        ); }
// d26082 start
    void setObjectid 	  (const String& Objectid	    ) { SQL_Schema::setValue(_COL_OBJECT_ID		     ,Objectid		  ); }
// d26082 end
 };



class __DLL_NCS_OBJ__ UserGroupHome : public SQL_SchemaMap<UserGroup>
 {
   #if !defined(AS400)
   static const ClassName _STR_ThisClass;  // Strings used for tracing and debugging
   #endif

   public:
    UserGroupHome(DataBase& DB)  : SQL_SchemaMap<UserGroup>(DB) { }


   public:
    // This method explicitely creates the object in the database on the spot.
    UserGroup* Create(const String& MerchantRefNum, const String& Name,
                      const NVPHash& NameValuePairs);
    // This method does not create the object in the database. Combine with Write for
    //same result or delay for better performance.
    UserGroup* Create(const String& MerchantRefNum, const String& Name);

    // This method explicitely selects the object in the database on the spot.
    UserGroup* Lookup(const String& RefNum, const NVPHash& NameValuePairs);
    // This method does not explicitely select the object in the database. Combine with Read
    //for same results
    UserGroup* Lookup(const String& RefNum);

    // This method explicitely selects the object in the database on the spot.
    UserGroup* Lookup(const String& MerchantRefNum, const String& Name,
                      const NVPHash& NameValuePairs);
    // This method does not explicitely select the object in the database. Combine with Read
    //for same results
    UserGroup* Lookup(const String& MerchantRefNum, const String& Name);
 };






class __DLL_NCS_OBJ__ MerchantUserInfo : public SQL_Schema
 {
   // These two lines are for the static SQL implementation.  They must be put in
   // all files that use this.
   friend class StaticSQL;
   friend class MerchantUserInfoHome;

   #if !defined(AS400)
   static const ClassName _STR_ThisClass;  // Strings used for tracing and debugging
   #endif

   public:
    MerchantUserInfo(DataBase& DB);

   public: // Schema column names
    static const StringWithOwnership _COL_TNAME                ;
    static const StringWithOwnership _COL_SHOPPER_REF_NUM      ;
    static const StringWithOwnership _COL_MERCHANT_REF_NUM     ;
    static const StringWithOwnership _COL_SHOPPER_GROUP_REF_NUM;
    static const StringWithOwnership _COL_ID                   ;
    static const StringWithOwnership _COL_FIELD1               ;
    #if !defined(AS400)
       static const StringWithOwnership _COL_FIELD2            ;
    #endif

   public: // Get functions
    const String& getShopperRefNum     (bool Real=true) { return SQL_Schema::getValue(_COL_SHOPPER_REF_NUM      , Real); }
    const String& getMerchantRefNum    (bool Real=true) { return SQL_Schema::getValue(_COL_MERCHANT_REF_NUM     , Real); }
    const String& getShopperGroupRefNum(bool Real=true) { return SQL_Schema::getValue(_COL_SHOPPER_GROUP_REF_NUM, Real); }
    const String& getId                (bool Real=true) { return SQL_Schema::getValue(_COL_ID                   , Real); }
    const String& getField1            (bool Real=true) { return SQL_Schema::getValue(_COL_FIELD1               , Real); }

   public: // Set functions
    void setShopperRefNum     (const String& ShopperRefNum     ) { SQL_Schema::setValue(_COL_SHOPPER_REF_NUM      ,ShopperRefNum     ); }
    void setMerchantRefNum    (const String& MerchantRefNum    ) { SQL_Schema::setValue(_COL_MERCHANT_REF_NUM     ,MerchantRefNum    ); }
    void setShopperGroupRefNum(const String& ShopperGroupRefNum) { SQL_Schema::setValue(_COL_SHOPPER_GROUP_REF_NUM,ShopperGroupRefNum); }
    void setId                (const String& Id                ) { SQL_Schema::setValue(_COL_ID                   ,Id                ); }
    void setField1            (const String& Field1            ) { SQL_Schema::setValue(_COL_FIELD1               ,Field1            ); }
 };



class __DLL_NCS_OBJ__ MerchantUserInfoHome : public SQL_SchemaMap<MerchantUserInfo>
 {
   #if !defined(AS400)
   static const ClassName _STR_ThisClass;  // Strings used for tracing and debugging
   #endif

   public:
    MerchantUserInfoHome(DataBase& DB) : SQL_SchemaMap<MerchantUserInfo>(DB) { }


   public:
    // This method explicitely creates the object in the database on the spot.
    MerchantUserInfo* Create(const String& MerchantRefNum, const String& ShopperRefNum,
                             const String& ShopperGroupRefNum, const NVPHash& NameValuePairs);
    // This method does not create the object in the database. Combine with Write for
    //same result or delay for better performance.
    MerchantUserInfo* Create(const String& MerchantRefNum, const String& ShopperRefNum,
                             const String& ShopperGroupRefNum);

    // This method explicitely selects the object in the database on the spot.
    MerchantUserInfo* Lookup(const String& MerchantRefNum, const String& ShopperRefNum,
                             const NVPHash& NameValuePairs);
    // This method does not explicitely select the object in the database. Combine with Read
    //for same results
    MerchantUserInfo* Lookup(const String& MerchantRefNum, const String& ShopperRefNum);
 };




#endif

